#!/usr/bin/env python
# SPDX-License-Identifier: AGPL-3.0-or-later
# lint: pylint
# pyright: basic
"""WebbApp

"""
# pylint: disable=use-dict-literal

import hashlib
import hmac
import json
import os
import sys
import base64
import requests
import markdown
import re
import datetime

from timeit import default_timer
from html import escape
from io import StringIO
import typing
from typing import List, Dict, Iterable

import urllib
import urllib.parse
from urllib.parse import urlencode, unquote

import httpx

from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter  # pylint: disable=no-name-in-module

import flask

from flask import (
    Flask,
    render_template,
    url_for,
    make_response,
    redirect,
    send_from_directory,
)
from flask.wrappers import Response
from flask.json import jsonify

from flask_babel import (
    Babel,
    gettext,
    format_decimal,
)

from searx import (
    logger,
    get_setting,
    settings,
    searx_debug,
)

from searx import infopage
from searx.data import ENGINE_DESCRIPTIONS
from searx.results import Timing, UnresponsiveEngine
from searx.settings_defaults import OUTPUT_FORMATS
from searx.settings_loader import get_default_settings_path
from searx.exceptions import SearxParameterException
from searx.engines import (
    OTHER_CATEGORY,
    categories,
    engines,
    engine_shortcuts,
)
from searx.webutils import (
    UnicodeWriter,
    highlight_content,
    get_static_files,
    get_result_templates,
    get_themes,
    prettify_url,
    new_hmac,
    is_hmac_of,
    is_flask_run_cmdline,
    group_engines_in_tab,
    searxng_l10n_timespan,
)
from searx.webadapter import (
    get_search_query_from_webapp,
    get_selected_categories,
)
from searx.utils import (
    html_to_text,
    gen_useragent,
    dict_subset,
    match_language,
)
from searx.version import VERSION_STRING, GIT_URL, GIT_BRANCH
from searx.query import RawTextQuery
from searx.plugins import Plugin, plugins, initialize as plugin_initialize
from searx.plugins.oa_doi_rewrite import get_doi_resolver
from searx.preferences import (
    Preferences,
    ValidationException,
)
from searx.answerers import (
    answerers,
    ask,
)
from searx.metrics import (
    get_engines_stats,
    get_engine_errors,
    get_reliabilities,
    histogram,
    counter,
)
from searx.flaskfix import patch_application

from searx.locales import (
    LOCALE_NAMES,
    RTL_LOCALES,
    localeselector,
    locales_initialize,
)

# renaming names from searx imports ...
from searx.autocomplete import search_autocomplete, backends as autocomplete_backends
from searx.languages import language_codes as languages
from searx.redisdb import initialize as redis_initialize
from searx.search import SearchWithPlugins, initialize as search_initialize
from searx.network import stream as http_stream, set_context_network_name
from searx.search.checker import get_result as checker_get_result

logger = logger.getChild('webapp')

# check secret_key
if not searx_debug and settings['server']['secret_key'] == 'ultrasecretkey':
    logger.error('server.secret_key is not changed. Please use something else instead of ultrasecretkey.')
    sys.exit(1)

# about static
logger.debug('static directory is %s', settings['ui']['static_path'])
static_files = get_static_files(settings['ui']['static_path'])

# about templates
logger.debug('templates directory is %s', settings['ui']['templates_path'])
default_theme = settings['ui']['default_theme']
templates_path = settings['ui']['templates_path']
themes = get_themes(templates_path)
result_templates = get_result_templates(templates_path)

STATS_SORT_PARAMETERS = {
    'name': (False, 'name', ''),
    'score': (True, 'score_per_result', 0),
    'result_count': (True, 'result_count', 0),
    'time': (False, 'total', 0),
    'reliability': (False, 'reliability', 100),
}

# Flask app
app = Flask(__name__, static_folder=settings['ui']['static_path'], template_folder=templates_path)

app.jinja_env.trim_blocks = True
app.jinja_env.lstrip_blocks = True
app.jinja_env.add_extension('jinja2.ext.loopcontrols')  # pylint: disable=no-member
app.jinja_env.filters['group_engines_in_tab'] = group_engines_in_tab  # pylint: disable=no-member
app.secret_key = settings['server']['secret_key']

timeout_text = gettext('timeout')
parsing_error_text = gettext('parsing error')
http_protocol_error_text = gettext('HTTP protocol error')
network_error_text = gettext('network error')
ssl_cert_error_text = gettext("SSL error: certificate validation has failed")
exception_classname_to_text = {
    None: gettext('unexpected crash'),
    'timeout': timeout_text,
    'asyncio.TimeoutError': timeout_text,
    'httpx.TimeoutException': timeout_text,
    'httpx.ConnectTimeout': timeout_text,
    'httpx.ReadTimeout': timeout_text,
    'httpx.WriteTimeout': timeout_text,
    'httpx.HTTPStatusError': gettext('HTTP error'),
    'httpx.ConnectError': gettext("HTTP connection error"),
    'httpx.RemoteProtocolError': http_protocol_error_text,
    'httpx.LocalProtocolError': http_protocol_error_text,
    'httpx.ProtocolError': http_protocol_error_text,
    'httpx.ReadError': network_error_text,
    'httpx.WriteError': network_error_text,
    'httpx.ProxyError': gettext("proxy error"),
    'searx.exceptions.SearxEngineCaptchaException': gettext("CAPTCHA"),
    'searx.exceptions.SearxEngineTooManyRequestsException': gettext("too many requests"),
    'searx.exceptions.SearxEngineAccessDeniedException': gettext("access denied"),
    'searx.exceptions.SearxEngineAPIException': gettext("server API error"),
    'searx.exceptions.SearxEngineXPathException': parsing_error_text,
    'KeyError': parsing_error_text,
    'json.decoder.JSONDecodeError': parsing_error_text,
    'lxml.etree.ParserError': parsing_error_text,
    'ssl.SSLCertVerificationError': ssl_cert_error_text,  # for Python > 3.7
    'ssl.CertificateError': ssl_cert_error_text,  # for Python 3.7
}


class ExtendedRequest(flask.Request):
    """This class is never initialized and only used for type checking."""

    preferences: Preferences
    errors: List[str]
    user_plugins: List[Plugin]
    form: Dict[str, str]
    start_time: float
    render_time: float
    timings: List[Timing]


request = typing.cast(ExtendedRequest, flask.request)


def get_locale():
    locale = localeselector()
    logger.debug("%s uses locale `%s`", urllib.parse.quote(request.url), locale)
    return locale


babel = Babel(app, locale_selector=get_locale)


def _get_browser_language(req, lang_list):
    for lang in req.headers.get("Accept-Language", "en").split(","):
        if ';' in lang:
            lang = lang.split(';')[0]
        if '-' in lang:
            lang_parts = lang.split('-')
            lang = "{}-{}".format(lang_parts[0], lang_parts[-1].upper())
        locale = match_language(lang, lang_list, fallback=None)
        if locale is not None:
            return locale
    return 'en'


def _get_locale_rfc5646(locale):
    """Get locale name for <html lang="...">
    Chrom* browsers don't detect the language when there is a subtag (ie a territory).
    For example "zh-TW" is detected but not "zh-Hant-TW".
    This function returns a locale without the subtag.
    """
    parts = locale.split('-')
    return parts[0].lower() + '-' + parts[-1].upper()


# code-highlighter
@app.template_filter('code_highlighter')
def code_highlighter(codelines, language=None):
    if not language:
        language = 'text'

    try:
        # find lexer by programming language
        lexer = get_lexer_by_name(language, stripall=True)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        # if lexer is not found, using default one
        lexer = get_lexer_by_name('text', stripall=True)

    html_code = ''
    tmp_code = ''
    last_line = None
    line_code_start = None

    # parse lines
    for line, code in codelines:
        if not last_line:
            line_code_start = line

        # new codeblock is detected
        if last_line is not None and last_line + 1 != line:

            # highlight last codepart
            formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
            html_code = html_code + highlight(tmp_code, lexer, formatter)

            # reset conditions for next codepart
            tmp_code = ''
            line_code_start = line

        # add codepart
        tmp_code += code + '\n'

        # update line
        last_line = line

    # highlight last codepart
    formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
    html_code = html_code + highlight(tmp_code, lexer, formatter)

    return html_code


def get_result_template(theme_name: str, template_name: str):
    themed_path = theme_name + '/result_templates/' + template_name
    if themed_path in result_templates:
        return themed_path
    return 'result_templates/' + template_name


def custom_url_for(endpoint: str, **values):
    suffix = ""
    if endpoint == 'static' and values.get('filename'):
        file_hash = static_files.get(values['filename'])
        if not file_hash:
            # try file in the current theme
            theme_name = request.preferences.get_value('theme')
            filename_with_theme = "themes/{}/{}".format(theme_name, values['filename'])
            file_hash = static_files.get(filename_with_theme)
            if file_hash:
                values['filename'] = filename_with_theme
        if get_setting('ui.static_use_hash') and file_hash:
            suffix = "?" + file_hash
    if endpoint == 'info' and 'locale' not in values:
        locale = request.preferences.get_value('locale')
        if _INFO_PAGES.get_page(values['pagename'], locale) is None:
            locale = _INFO_PAGES.locale_default
        values['locale'] = locale
    return url_for(endpoint, **values) + suffix


def morty_proxify(url: str):
    if url.startswith('//'):
        url = 'https:' + url

    if not settings['result_proxy']['url']:
        return url

    url_params = dict(mortyurl=url)

    if settings['result_proxy']['key']:
        url_params['mortyhash'] = hmac.new(settings['result_proxy']['key'], url.encode(), hashlib.sha256).hexdigest()

    return '{0}?{1}'.format(settings['result_proxy']['url'], urlencode(url_params))


def image_proxify(url: str):

    if url.startswith('//'):
        url = 'https:' + url

    if not request.preferences.get_value('image_proxy'):
        return url

    if url.startswith('data:image/'):
        # 50 is an arbitrary number to get only the beginning of the image.
        partial_base64 = url[len('data:image/') : 50].split(';')
        if (
            len(partial_base64) == 2
            and partial_base64[0] in ['gif', 'png', 'jpeg', 'pjpeg', 'webp', 'tiff', 'bmp']
            and partial_base64[1].startswith('base64,')
        ):
            return url
        return None

    if settings['result_proxy']['url']:
        return morty_proxify(url)

    h = new_hmac(settings['server']['secret_key'], url.encode())

    return '{0}?{1}'.format(url_for('image_proxy'), urlencode(dict(url=url.encode(), h=h)))


def get_translations():
    return {
        # when there is autocompletion
        'no_item_found': gettext('No item found'),
        # /preferences: the source of the engine description (wikipedata, wikidata, website)
        'Source': gettext('Source'),
        # infinite scroll
        'error_loading_next_page': gettext('Error loading the next page'),
    }


def _get_enable_categories(all_categories: Iterable[str]):
    disabled_engines = request.preferences.engines.get_disabled()
    enabled_categories = set(
        # pylint: disable=consider-using-dict-items
        category
        for engine_name in engines
        for category in engines[engine_name].categories
        if (engine_name, category) not in disabled_engines
    )
    return [x for x in all_categories if x in enabled_categories]


def get_pretty_url(parsed_url: urllib.parse.ParseResult):
    path = parsed_url.path
    path = path[:-1] if len(path) > 0 and path[-1] == '/' else path
    path = unquote(path.replace("/", " › "))
    return [parsed_url.scheme + "://" + parsed_url.netloc, path]


def get_client_settings():
    req_pref = request.preferences
    return {
        'autocomplete_provider': req_pref.get_value('autocomplete'),
        'autocomplete_min': get_setting('search.autocomplete_min'),
        'http_method': req_pref.get_value('method'),
        'infinite_scroll': req_pref.get_value('infinite_scroll'),
        'translations': get_translations(),
        'search_on_category_select': req_pref.plugins.choices['searx.plugins.search_on_category_select'],
        'hotkeys': req_pref.plugins.choices['searx.plugins.vim_hotkeys'],
        'theme_static_path': custom_url_for('static', filename='themes/simple'),
    }


def render(template_name: str, **kwargs):

    kwargs['client_settings'] = str(
        base64.b64encode(
            bytes(
                json.dumps(get_client_settings()),
                encoding='utf-8',
            )
        ),
        encoding='utf-8',
    )

    # values from the HTTP requests
    kwargs['endpoint'] = 'results' if 'q' in kwargs else request.endpoint
    kwargs['cookies'] = request.cookies
    kwargs['errors'] = request.errors

    # values from the preferences
    kwargs['preferences'] = request.preferences
    kwargs['autocomplete'] = request.preferences.get_value('autocomplete')
    kwargs['infinite_scroll'] = request.preferences.get_value('infinite_scroll')
    kwargs['results_on_new_tab'] = request.preferences.get_value('results_on_new_tab')
    kwargs['advanced_search'] = request.preferences.get_value('advanced_search')
    kwargs['query_in_title'] = request.preferences.get_value('query_in_title')
    kwargs['safesearch'] = str(request.preferences.get_value('safesearch'))
    kwargs['theme'] = request.preferences.get_value('theme')
    kwargs['method'] = request.preferences.get_value('method')
    kwargs['categories_as_tabs'] = list(settings['categories_as_tabs'].keys())
    kwargs['categories'] = _get_enable_categories(categories.keys())
    kwargs['OTHER_CATEGORY'] = OTHER_CATEGORY

    # i18n
    kwargs['language_codes'] = [l for l in languages if l[0] in settings['search']['languages']]

    locale = request.preferences.get_value('locale')
    kwargs['locale_rfc5646'] = _get_locale_rfc5646(locale)

    if locale in RTL_LOCALES and 'rtl' not in kwargs:
        kwargs['rtl'] = True
    if 'current_language' not in kwargs:
        kwargs['current_language'] = match_language(
            request.preferences.get_value('language'), settings['search']['languages']
        )

    # values from settings
    kwargs['search_formats'] = [x for x in settings['search']['formats'] if x != 'html']
    kwargs['instance_name'] = get_setting('general.instance_name')
    kwargs['searx_version'] = VERSION_STRING
    kwargs['searx_git_url'] = GIT_URL
    kwargs['enable_metrics'] = get_setting('general.enable_metrics')
    kwargs['get_setting'] = get_setting
    kwargs['get_pretty_url'] = get_pretty_url

    # values from settings: donation_url
    donation_url = get_setting('general.donation_url')
    if donation_url is True:
        donation_url = custom_url_for('info', pagename='donate')
    kwargs['donation_url'] = donation_url

    # helpers to create links to other pages
    kwargs['url_for'] = custom_url_for  # override url_for function in templates
    kwargs['image_proxify'] = image_proxify
    kwargs['proxify'] = morty_proxify if settings['result_proxy']['url'] is not None else None
    kwargs['proxify_results'] = settings['result_proxy']['proxify_results']
    kwargs['cache_url'] = settings['ui']['cache_url']
    kwargs['get_result_template'] = get_result_template
    kwargs['doi_resolver'] = get_doi_resolver(request.preferences)
    kwargs['opensearch_url'] = (
        url_for('opensearch')
        + '?'
        + urlencode(
            {
                'method': request.preferences.get_value('method'),
                'autocomplete': request.preferences.get_value('autocomplete'),
            }
        )
    )

    # scripts from plugins
    kwargs['scripts'] = set()
    for plugin in request.user_plugins:
        for script in plugin.js_dependencies:
            kwargs['scripts'].add(script)

    # styles from plugins
    kwargs['styles'] = set()
    for plugin in request.user_plugins:
        for css in plugin.css_dependencies:
            kwargs['styles'].add(css)

    start_time = default_timer()
    result = render_template('{}/{}'.format(kwargs['theme'], template_name), **kwargs)
    request.render_time += default_timer() - start_time  # pylint: disable=assigning-non-slot

    return result


@app.before_request
def pre_request():
    request.start_time = default_timer()  # pylint: disable=assigning-non-slot
    request.render_time = 0  # pylint: disable=assigning-non-slot
    request.timings = []  # pylint: disable=assigning-non-slot
    request.errors = []  # pylint: disable=assigning-non-slot

    preferences = Preferences(themes, list(categories.keys()), engines, plugins)  # pylint: disable=redefined-outer-name
    user_agent = request.headers.get('User-Agent', '').lower()
    if 'webkit' in user_agent and 'android' in user_agent:
        preferences.key_value_settings['method'].value = 'GET'
    request.preferences = preferences  # pylint: disable=assigning-non-slot

    try:
        preferences.parse_dict(request.cookies)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        request.errors.append(gettext('Invalid settings, please edit your preferences'))

    # merge GET, POST vars
    # request.form
    request.form = dict(request.form.items())  # pylint: disable=assigning-non-slot
    for k, v in request.args.items():
        if k not in request.form:
            request.form[k] = v

    if request.form.get('preferences'):
        preferences.parse_encoded_data(request.form['preferences'])
    else:
        try:
            preferences.parse_dict(request.form)
        except Exception as e:  # pylint: disable=broad-except
            logger.exception(e, exc_info=True)
            request.errors.append(gettext('Invalid settings'))

    # language is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("language"):
        language = _get_browser_language(request, settings['search']['languages'])
        preferences.parse_dict({"language": language})
        logger.debug('set language %s (from browser)', preferences.get_value("language"))

    # locale is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("locale"):
        locale = _get_browser_language(request, LOCALE_NAMES.keys())
        preferences.parse_dict({"locale": locale})
        logger.debug('set locale %s (from browser)', preferences.get_value("locale"))

    # request.user_plugins
    request.user_plugins = []  # pylint: disable=assigning-non-slot
    allowed_plugins = preferences.plugins.get_enabled()
    disabled_plugins = preferences.plugins.get_disabled()
    for plugin in plugins:
        if (plugin.default_on and plugin.id not in disabled_plugins) or plugin.id in allowed_plugins:
            request.user_plugins.append(plugin)


@app.after_request
def add_default_headers(response: flask.Response):
    # set default http headers
    for header, value in settings['server']['default_http_headers'].items():
        if header in response.headers:
            continue
        response.headers[header] = value
    return response


@app.after_request
def post_request(response: flask.Response):
    total_time = default_timer() - request.start_time
    timings_all = [
        'total;dur=' + str(round(total_time * 1000, 3)),
        'render;dur=' + str(round(request.render_time * 1000, 3)),
    ]
    if len(request.timings) > 0:
        timings = sorted(request.timings, key=lambda t: t.total)
        timings_total = [
            'total_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.total * 1000, 3)) for i, t in enumerate(timings)
        ]
        timings_load = [
            'load_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.load * 1000, 3))
            for i, t in enumerate(timings)
            if t.load
        ]
        timings_all = timings_all + timings_total + timings_load
    # response.headers.add('Server-Timing', ', '.join(timings_all))
    return response


def index_error(output_format: str, error_message: str):
    if output_format == 'json':
        return Response(json.dumps({'error': error_message}), mimetype='application/json')
    if output_format == 'csv':
        response = Response('', mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx.csv'
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=[],
            q=request.form['q'] if 'q' in request.form else '',
            number_of_results=0,
            error_message=error_message,
        )
        return Response(response_rss, mimetype='text/xml')

    # html
    request.errors.append(gettext('search error'))
    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        # fmt: on
    )


@app.route('/', methods=['GET', 'POST'])
def index():
    """Render index page."""

    # redirect to search if there's a query in the request
    if request.form.get('q'):
        query = ('?' + request.query_string.decode()) if request.query_string else ''
        return redirect(url_for('search') + query, 308)

    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        current_locale = request.preferences.get_value("locale"),
        # fmt: on
    )


@app.route('/healthz', methods=['GET'])
def health():
    return Response('OK', mimetype='text/plain')


@app.route('/search', methods=['GET', 'POST'])
def search():
    """Search query in q and return results.

    Supported outputs: html, json, csv, rss.
    """
    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # output_format
    output_format = request.form.get('format', 'html')
    if output_format not in OUTPUT_FORMATS:
        output_format = 'html'

    if output_format not in settings['search']['formats']:
        flask.abort(403)

    # check if there is query (not None and not an empty string)
    if not request.form.get('q'):
        if output_format == 'html':
            return render(
                # fmt: off
                'index.html',
                selected_categories=get_selected_categories(request.preferences, request.form),
                # fmt: on
            )
        return index_error(output_format, 'No query'), 400

    # search
    search_query = None
    raw_text_query = None
    result_container = None
    original_search_query = ""
    try:
        search_query, raw_text_query, _, _ = get_search_query_from_webapp(request.preferences, request.form)
        # search = Search(search_query) #  without plugins
        try:
            original_search_query = search_query.query
            if "请推荐" in search_query.query or "帮我" in search_query.query or "写一段" in search_query.query or "写一个" in search_query.query or "请问" in search_query.query or "请给" in search_query.query or "请你" in search_query.query  or "请推荐" in search_query.query or "是谁" in search_query.query or "能帮忙" in search_query.query or "介绍一下" in search_query.query or "为什么" in search_query.query or "什么是" in search_query.query or "有什么" in search_query.query or "怎样" in search_query.query or "给我" in search_query.query or "如何" in search_query.query or "谁是" in search_query.query or "查询" in search_query.query or "告诉我" in search_query.query or "查一下" in search_query.query or "找一个" in search_query.query or "什么样" in search_query.query or "哪个" in search_query.query or "哪些" in search_query.query or "哪一个" in search_query.query or "哪一些" in search_query.query  or "啥是" in search_query.query or "为啥" in search_query.query or "怎么" in search_query.query:
                if len(search_query.query)>5 and "谁是" in search_query.query:
                    search_query.query = search_query.query.replace("谁是","")
                if len(search_query.query)>5 and "是谁" in search_query.query:
                    search_query.query = search_query.query.replace("是谁","")
                if len(search_query.query)>5 and not "谁是" in search_query.query and not "是谁" in search_query.query:
                    prompt = search_query.query + "\n对以上问题生成一个Google搜索词：\n"
                    if "今年" in prompt or "今天" in prompt:
                        now = datetime.datetime.now()
                        prompt = prompt.replace("今年",now.strftime('%Y年'))
                        prompt = prompt.replace("今天",now.strftime('%Y年%m月%d日'))
                    gpt = ""
                    gpt_url = "https://api.openai.com/v1/engines/text-davinci-003/completions"
                    gpt_headers = {
                        "Authorization": "Bearer "+os.environ['GPTKEY'],
                        "Content-Type": "application/json",    
                    }
                    gpt_data = {
                        "prompt": prompt,
                        "max_tokens": 256,
                        "temperature": 0.9,
                        "top_p": 1,
                        "frequency_penalty": 0,
                        "presence_penalty": 0,
                        "best_of": 1,
                        "echo": False,
                        "logprobs": 0,
                        "stream": False
                    }
                    gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
                    gpt_json = gpt_response.json()
                    if 'choices' in gpt_json:
                        gpt = gpt_json['choices'][0]['text']
                    for word in gpt.split('\n'):
                        if word != "":
                            gpt = word.replace("\"","").replace("\'","").replace("“","").replace("”","").replace("‘","").replace("’","")
                            break
                    if gpt!="":
                        search_query.query = gpt
        except Exception as ee:
            logger.exception(ee, exc_info=True)
        search = SearchWithPlugins(search_query, request.user_plugins, request)  # pylint: disable=redefined-outer-name

        result_container = search.search()

    except SearxParameterException as e:
        logger.exception('search error: SearxParameterException')
        return index_error(output_format, e.message), 400
    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        return index_error(output_format, gettext('search error')), 500

    # results
    results = result_container.get_ordered_results()
    number_of_results = result_container.results_number()
    if number_of_results < result_container.results_length():
        number_of_results = 0

    # OPENAI GPT
    raws = []
    try:
        url_pair = []
        prompt = ""
        for res in results:
            if 'url' not in res: continue
            if 'content' not in res: continue
            if 'title' not in res: continue
            if res['content'] == '': continue
            new_url = 'https://url'+str(len(url_pair))
            url_pair.append(res['url'])
            res['title'] = res['title'].replace("التغريدات مع الردود بواسطة","")
            res['content'] = res['content'].replace("  "," ")
            res['content'] = res['content'].replace("Translate Tweet. ","")
            res['content'] = res['content'].replace("Learn more ","")
            res['content'] = res['content'].replace("Translate Tweet.","")
            res['content'] = res['content'].replace("Retweeted.","Reposted.")     
            res['content'] = res['content'].replace("Learn more.","")     
            res['content'] = res['content'].replace("Show replies.","")      
            res['content'] = res['content'].replace("See new Tweets. ","") 
            if "作者简介：金融学客座教授，硕士生导师" in res['content']:  res['content']=res['title']  
            res['content'] = res['content'].replace("You're unable to view this Tweet because this account owner limits who can view their Tweets.","Private Tweet.")      
            res['content'] = res['content'].replace("Twitter for Android · ","") 
            res['content'] = res['content'].replace("This Tweet was deleted by the Tweet author.","Deleted  Tweet.")
             
            tmp_prompt =  res['title'] +'\n'+  res['content'] + '\n' + new_url +'\n'
            
            if original_search_query == search_query.query and len( prompt + tmp_prompt +'\n' + "\n以上是关键词 " + original_search_query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：" ) <1600:
                raws.append(tmp_prompt)
                prompt += tmp_prompt +'\n'
            if len( prompt + tmp_prompt +'\n' + "\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：") <1600:
                prompt += tmp_prompt +'\n'
        if prompt != "":
            gpt = ""
            gpt_url = "https://search.kg/completions"
            gpt_headers = {
                "Content-Type": "application/json",
            }
            if original_search_query != search_query.query:
                gpt_data = {
                    "prompt": prompt+"\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            else:
                gpt_data = {
                    "prompt": prompt+"\n以上是关键词 " + search_query.query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            gpt = json.dumps({'data':gpt_data, 'url_pair':url_pair, 'raws': raws})
            gpt = '<div id="chat_intro"></div><div id="chat"></div>' + r'''<div id="chat_continue" style="display:none">
<div id="chat_more" style="display:none"></div>
<hr>
<textarea id="chat_input" style="margin: auto;display: block;background: rgb(209 219 250 / 30%);outline: 0px;color: var(--color-search-font);font-size: 1.2rem;border-radius: 3px;border: none;height: 3em;resize: vertical;width: 75%;"></textarea>
<button id="chat_send" onclick='send_chat()' style="
    width: 75%;
    display: block;
    margin: auto;
    margin-top: .8em;
    border-radius: .8rem;
    height: 2em;
    background: linear-gradient(81.62deg, #2870ea 8.72%, #1b4aef 85.01%);
    color: #fff;
    border: none;
    cursor: pointer;
">发送</button>
</div>
<style>
.chat_answer {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 3em 0.5em 0;
    padding: 8px 12px;
    color: white;
    background: rgba(27,74,239,0.7);
}
.chat_question {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 0 0.5em 3em;
    padding: 8px 12px;
    color: black;
    background: rgba(245, 245, 245, 0.7);
}

button.btn_more {
    min-height: 30px;
    text-align: left;
    background: rgb(209, 219, 250);
    border-radius: 8px;
    overflow: hidden;
    box-sizing: border-box;
    padding: 0px 12px;
    margin: 1px;
    cursor: pointer;
    font-weight: 500;
    line-height: 28px;
    border: 1px solid rgb(18, 59, 182);
    color: rgb(18, 59, 182);
}

::-webkit-scrollbar {
    width: 8px;
}

::-webkit-scrollbar-track {
    -webkit-box-shadow: rgba(0, 0, 0, 0.3);
    box-shadow: rgba(0, 0, 0, 0.3);
    border-radius: 10px;
}

::-webkit-scrollbar-thumb {
    border-radius: 10px;
    background: rgba(17, 16, 16, 0.13);
    -webkit-box-shadow: rgba(0, 0, 0, 0.9);
    box-shadow: rgba(0, 0, 0, 0.5);
}
::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(211, 173, 209, 0.4);
}
</style>
''' + '<div id="prompt" style="display:none">'  + (base64.b64encode(gpt.encode("utf-8")).decode('UTF-8') )  + '</div>' 
            # gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
            # gpt_json = gpt_response.json()
            # if 'choices' in gpt_json:
            #     gpt = gpt_json['choices'][0]['text']
            # gpt = gpt.replace("简报：","").replace("简报:","")
            # for i in range(len(url_pair)-1,-1,-1):
            #     gpt = gpt.replace("https://url"+str(i),url_pair[i])
            # rgpt = gpt

            if gpt and gpt!="":
                if original_search_query != search_query.query:
                    gpt = "Search 为您搜索：" + search_query.query + "\n\n" + gpt
                gpt = gpt + r'''<style>
                a.footnote {
                    position: relative;
                    display: inline-flex;
                    align-items: center;
                    justify-content: center;
                    font-size: 10px;
                    font-weight: 600;
                    vertical-align: top;
                    top: 0px;
                    margin: 1px 1px;
                    min-width: 14px;
                    height: 14px;
                    border-radius: 3px;
                    color: rgb(18, 59, 182);
                    background: rgb(209, 219, 250);
                    outline: transparent solid 1px;
                }
                </style>





                <script src="/static/themes/magi/markdown.js"></script>
                <script>
const original_search_query = "''' + original_search_query.replace('"',"") + r'''"
const search_queryquery = "''' + search_query.query.replace('"',"") + r'''"
</script><script>
const _0x476ffd=_0x54d4,_0x3dd906=_0x54d4,_0x49938f=_0x54d4,_0x2321d0=_0x54d4,_0x3aedc2=_0x54d4;(function(_0x543e94,_0x303a51){const _0xaadba6=_0x54d4,_0x4435ab=_0x54d4,_0x1257f2=_0x54d4,_0x2173b3=_0x54d4,_0x1705b2=_0x54d4,_0x4a2c64=_0x543e94();while(!![]){try{const _0x4c5d22=parseInt(_0xaadba6(0x5bd))/(0x1*0x2656+-0x1658+-0xffd*0x1)+parseInt(_0x4435ab(0x142))/(0x2361+-0x39a*0x7+0x33*-0x33)+parseInt(_0xaadba6(0x3b4))/(-0x17*-0x9c+0x2*-0x1a3+0xabb*-0x1)*(-parseInt(_0xaadba6(0x712))/(-0x1a74*0x1+-0xc32*-0x3+-0xa1e))+parseInt(_0xaadba6(0x52a))/(0x3a*-0xd+-0x89f+0xb96)+-parseInt(_0x1257f2(0x6f8))/(-0x4*0x5+-0x1*-0x65a+-0x4*0x190)+parseInt(_0x4435ab(0x37c))/(0x10*-0x5f+-0x218b+-0x2782*-0x1)+-parseInt(_0x4435ab(0x6c8))/(-0x1*0x1b9+0x2217+-0x2056);if(_0x4c5d22===_0x303a51)break;else _0x4a2c64['push'](_0x4a2c64['shift']());}catch(_0x5d00de){_0x4a2c64['push'](_0x4a2c64['shift']());}}}(_0x2617,0x2ba9e+0x35f7f+0x7ad01));function stringToArrayBuffer(_0x3037c9){const _0x41918a=_0x54d4,_0x141956=_0x54d4,_0x1ca793=_0x54d4,_0x492989=_0x54d4,_0x552423=_0x54d4,_0x1fa04e={'ZFUBZ':function(_0x22180e,_0x5c84f1){return _0x22180e(_0x5c84f1);},'Bhulp':_0x41918a(0x562)+_0x41918a(0x5ad),'JrFVN':function(_0xa432fa,_0x22893b){return _0xa432fa-_0x22893b;},'Brqkw':function(_0x2aeb1a,_0x204ab5){return _0x2aeb1a===_0x204ab5;},'mahId':_0x141956(0x312),'AqcXs':_0x141956(0x59d),'WWDbQ':function(_0xf9d693,_0x1eba84){return _0xf9d693<_0x1eba84;},'DBCZL':function(_0x4bfece,_0x375493){return _0x4bfece!==_0x375493;},'aGkDx':_0x552423(0x576)};if(!_0x3037c9)return;try{if(_0x1fa04e[_0x492989(0x51e)](_0x1fa04e[_0x552423(0x4f3)],_0x1fa04e[_0x41918a(0x2c3)]))try{_0x3f99a2=_0x1fa04e[_0x552423(0x235)](_0x119a28,_0x5c01fc);const _0x1ae0be={};return _0x1ae0be[_0x141956(0x60c)]=_0x1fa04e[_0x41918a(0x3b5)],_0x1f03f6[_0x1ca793(0x5ab)+'e'][_0x41918a(0x306)+'pt'](_0x1ae0be,_0x5d3b54,_0x451800);}catch(_0xdeae7f){}else{var _0x21eb35=new ArrayBuffer(_0x3037c9[_0x492989(0x36b)+'h']),_0x25306e=new Uint8Array(_0x21eb35);for(var _0x57e02c=0x2*0x11f8+-0x5ff*0x1+-0x1df1,_0x5e2017=_0x3037c9[_0x141956(0x36b)+'h'];_0x1fa04e[_0x552423(0x329)](_0x57e02c,_0x5e2017);_0x57e02c++){_0x1fa04e[_0x141956(0x3c6)](_0x1fa04e[_0x41918a(0x60d)],_0x1fa04e[_0x1ca793(0x60d)])?(_0x306395+=_0x309db2[0x695+-0xcd7+0x642][_0x552423(0x6d5)],_0x39701c=_0x26f28e[0x1a42+0x22ec+0x1*-0x3d2e][_0x1ca793(0x311)+_0x41918a(0x2af)][_0x552423(0x754)+_0x552423(0x536)+'t'][_0x1fa04e[_0x492989(0x59e)](_0x53d2d5[0x24e8+0x1*0x1526+-0x3a0e][_0x41918a(0x311)+_0x1ca793(0x2af)][_0x492989(0x754)+_0x41918a(0x536)+'t'][_0x41918a(0x36b)+'h'],-0x1*0x25f7+0x2*0xbb3+0xe92)]):_0x25306e[_0x57e02c]=_0x3037c9[_0x492989(0x5e6)+_0x141956(0x729)](_0x57e02c);}return _0x21eb35;}}catch(_0x17e6c3){}}function arrayBufferToString(_0x1222ba){const _0x190710=_0x54d4,_0x1b3804=_0x54d4,_0x47a5c5=_0x54d4,_0x48b525=_0x54d4,_0x5951f4=_0x54d4,_0x2bc04f={'POivD':function(_0x97193d,_0x1dcb9f){return _0x97193d(_0x1dcb9f);},'gtOVA':_0x190710(0x4d1)+_0x1b3804(0x66f),'aRlMw':function(_0xbcb7d4,_0x249297){return _0xbcb7d4+_0x249297;},'lFmWd':_0x190710(0x756)+_0x1b3804(0x6f0)+_0x190710(0x71f)+_0x47a5c5(0x1b8)+_0x1b3804(0x623)+_0x5951f4(0x53d)+_0x190710(0x45a)+_0x47a5c5(0x534)+_0x48b525(0x76d)+_0x1b3804(0x477)+_0x47a5c5(0x305),'wowVE':_0x5951f4(0x5de)+_0x5951f4(0x4ac),'OJofx':_0x5951f4(0x204),'bagkH':function(_0x595ce8,_0x304b24){return _0x595ce8(_0x304b24);},'YAkNB':function(_0x5e16f2,_0x26639b){return _0x5e16f2+_0x26639b;},'dTrYK':function(_0x18d0dd,_0x1e4492){return _0x18d0dd+_0x1e4492;},'kOIzT':_0x190710(0x4d1),'SPxZo':_0x190710(0x258),'ItiNg':_0x5951f4(0x4eb)+_0x190710(0x444)+_0x5951f4(0x283)+_0x190710(0x4d7)+_0x1b3804(0x6db)+_0x5951f4(0x788)+_0x48b525(0x270)+_0x1b3804(0x6ec)+_0x1b3804(0x285)+_0x47a5c5(0x6c1)+_0x190710(0x3e7)+_0x1b3804(0x5dc)+_0x5951f4(0x40e),'FtGZC':function(_0x3c6179,_0x193bbe){return _0x3c6179!=_0x193bbe;},'dcFkv':function(_0x2bb99f,_0x133ed1,_0x1c06e4){return _0x2bb99f(_0x133ed1,_0x1c06e4);},'nXksF':_0x190710(0x1bb)+_0x48b525(0x5b3)+_0x190710(0x14d)+_0x48b525(0x264)+_0x48b525(0x763)+_0x5951f4(0x3af),'PqzjL':function(_0x20cc16,_0x36722d){return _0x20cc16===_0x36722d;},'LlIAE':_0x5951f4(0x241),'crFSs':function(_0x4ee1e1,_0x13932b){return _0x4ee1e1<_0x13932b;},'VcGxZ':_0x48b525(0x351),'Afhey':_0x5951f4(0x2e7)};try{if(_0x2bc04f[_0x5951f4(0x350)](_0x2bc04f[_0x5951f4(0x1db)],_0x2bc04f[_0x48b525(0x1db)])){var _0x25c01f=new Uint8Array(_0x1222ba),_0x538aeb='';for(var _0x503fe0=0xb6+0x1*0xc28+0xb7*-0x12;_0x2bc04f[_0x190710(0x6a6)](_0x503fe0,_0x25c01f[_0x47a5c5(0x74c)+_0x5951f4(0x217)]);_0x503fe0++){_0x2bc04f[_0x47a5c5(0x350)](_0x2bc04f[_0x1b3804(0x40d)],_0x2bc04f[_0x5951f4(0x2be)])?LlluSa[_0x47a5c5(0x708)](_0x2ef3a4,-0xa83+-0x19c4*0x1+0x25*0xfb):_0x538aeb+=String[_0x47a5c5(0x6fa)+_0x5951f4(0x636)+_0x1b3804(0x1ad)](_0x25c01f[_0x503fe0]);}return _0x538aeb;}else{const _0x333c48={'ImFMd':_0x2bc04f[_0x190710(0x561)],'uRHgo':function(_0x562560,_0x51a36c){const _0x5758bc=_0x190710;return _0x2bc04f[_0x5758bc(0x45d)](_0x562560,_0x51a36c);},'RNJzV':_0x2bc04f[_0x190710(0x223)],'lcGlN':function(_0x47291a,_0x1c2429){const _0x4307ad=_0x190710;return _0x2bc04f[_0x4307ad(0x708)](_0x47291a,_0x1c2429);},'Sikpj':_0x2bc04f[_0x48b525(0x5f1)]},_0x3e72f7={'method':_0x2bc04f[_0x190710(0x391)],'headers':_0x58e48c,'body':_0x2bc04f[_0x190710(0x50e)](_0x5dcaa6,_0x57dc77[_0x5951f4(0x1d3)+_0x190710(0x5a2)]({'prompt':_0x2bc04f[_0x48b525(0x45d)](_0x2bc04f[_0x1b3804(0x4b9)](_0x2bc04f[_0x5951f4(0x5d7)](_0x2bc04f[_0x190710(0x45d)](_0x44e904[_0x48b525(0x33e)+_0x47a5c5(0x250)+_0x5951f4(0x748)](_0x2bc04f[_0x5951f4(0x4b2)])[_0x48b525(0x669)+_0x1b3804(0x17a)][_0x47a5c5(0x234)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x47a5c5(0x234)+'ce'](/<hr.*/gs,'')[_0x5951f4(0x234)+'ce'](/<[^>]+>/g,'')[_0x1b3804(0x234)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x2bc04f[_0x48b525(0x256)]),_0x47618b),_0x2bc04f[_0x190710(0x23f)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x2bc04f[_0x190710(0x4cd)](_0x536b84[_0x1b3804(0x33e)+_0x1b3804(0x250)+_0x1b3804(0x748)](_0x2bc04f[_0x190710(0x561)])[_0x1b3804(0x669)+_0x5951f4(0x17a)],''))return;_0x2bc04f[_0x190710(0x25c)](_0x5015fc,_0x2bc04f[_0x190710(0x6e0)],_0x3e72f7)[_0x47a5c5(0x4ad)](_0x5075e7=>_0x5075e7[_0x47a5c5(0x6c5)]())[_0x190710(0x4ad)](_0xbb50bb=>{const _0xbf8d0b=_0x48b525,_0x4d6328=_0x5951f4,_0x1482b7=_0x48b525,_0x3f92a=_0x48b525,_0x2b427e=_0x190710;_0x46b19d[_0xbf8d0b(0x21d)](_0xbb50bb[_0x4d6328(0x6e8)+'es'][-0x675+0x59a+0xdb][_0xbf8d0b(0x6d5)][_0x3f92a(0x234)+_0xbf8d0b(0x2ae)]('\x0a',''))[_0x4d6328(0x340)+'ch'](_0x30658f=>{const _0x2868cc=_0x1482b7,_0xef8dc=_0x2b427e,_0x28d85c=_0x4d6328,_0x4cc9f8=_0xbf8d0b,_0x5b238a=_0x3f92a;_0x3164b4[_0x2868cc(0x33e)+_0x2868cc(0x250)+_0x28d85c(0x748)](_0x333c48[_0x28d85c(0x4bd)])[_0x2868cc(0x669)+_0x2868cc(0x17a)]+=_0x333c48[_0xef8dc(0x71a)](_0x333c48[_0x28d85c(0x71a)](_0x333c48[_0x2868cc(0x34e)],_0x333c48[_0xef8dc(0x316)](_0x2744f7,_0x30658f)),_0x333c48[_0xef8dc(0x481)]);});})[_0x48b525(0x665)](_0x3dc307=>_0x2f7ca1[_0x5951f4(0x228)](_0x3dc307)),_0x31f914=_0x2bc04f[_0x47a5c5(0x4b9)](_0x3d776d,'\x0a\x0a'),_0x141784=-(-0x167c+0xc*0x2d4+-0xb73);}}catch(_0x1a4f0c){}}function importPrivateKey(_0x1904b8){const _0xfdfb9b=_0x54d4,_0x574af5=_0x54d4,_0x32f1bb=_0x54d4,_0xec5f09=_0x54d4,_0x38f677=_0x54d4,_0xf5486e={'kXbNZ':_0xfdfb9b(0x409)+_0x574af5(0x5db)+_0x574af5(0x149)+_0x32f1bb(0x436)+_0x574af5(0x63f)+'--','vHoZa':_0x38f677(0x409)+_0x38f677(0x2e5)+_0xec5f09(0x33b)+_0x32f1bb(0x19a)+_0xfdfb9b(0x409),'DMbWA':function(_0x7503ce,_0x1678ae){return _0x7503ce-_0x1678ae;},'lCesg':function(_0x895aba,_0x26a606){return _0x895aba(_0x26a606);},'xicYE':_0xec5f09(0x413),'vHoPh':_0x574af5(0x562)+_0x574af5(0x5ad),'LDHcy':_0x32f1bb(0x555)+'56','LyULY':_0x574af5(0x704)+'pt'},_0x3ccb46=_0xf5486e[_0x32f1bb(0x510)],_0x478c4b=_0xf5486e[_0xfdfb9b(0x51b)],_0x1b4848=_0x1904b8[_0xfdfb9b(0x214)+_0x38f677(0x575)](_0x3ccb46[_0xfdfb9b(0x36b)+'h'],_0xf5486e[_0x38f677(0x702)](_0x1904b8[_0x38f677(0x36b)+'h'],_0x478c4b[_0xec5f09(0x36b)+'h'])),_0x48904b=_0xf5486e[_0x38f677(0x165)](atob,_0x1b4848),_0x4c8a4e=_0xf5486e[_0xec5f09(0x165)](stringToArrayBuffer,_0x48904b);return crypto[_0xfdfb9b(0x5ab)+'e'][_0xfdfb9b(0x6d2)+_0x38f677(0x396)](_0xf5486e[_0xfdfb9b(0x588)],_0x4c8a4e,{'name':_0xf5486e[_0x32f1bb(0x374)],'hash':_0xf5486e[_0xec5f09(0x430)]},!![],[_0xf5486e[_0x32f1bb(0x2a5)]]);}(function(){const _0x3d96b0=_0x54d4,_0x5a833c=_0x54d4,_0x3a9559=_0x54d4,_0x2f11c0=_0x54d4,_0x1646cc=_0x54d4,_0x132a16={'hGHbn':function(_0x42c885,_0x3be60e){return _0x42c885+_0x3be60e;},'NRSsK':_0x3d96b0(0x1cf),'oXRMd':_0x5a833c(0x51d),'WXwBW':_0x3a9559(0x549)+'n','vzltk':_0x2f11c0(0x5b9)+':','DsGzu':function(_0x206bc9,_0x2e50ff){return _0x206bc9!==_0x2e50ff;},'aICbv':_0x2f11c0(0x557),'JqrRU':_0x3a9559(0x161),'EaUrK':function(_0x504429,_0x294106){return _0x504429===_0x294106;},'tHGQh':_0x5a833c(0x46d),'xAWFe':_0x3a9559(0x41e),'esfQv':function(_0x507a9f,_0x5df5b2){return _0x507a9f(_0x5df5b2);},'ljljQ':function(_0x4d1b23,_0x3e61cf){return _0x4d1b23+_0x3e61cf;},'ajYlr':_0x5a833c(0x43c)+_0x3a9559(0x3eb)+_0x3d96b0(0x6b3)+_0x3d96b0(0x284),'DJPuX':_0x1646cc(0x279)+_0x3a9559(0x4d2)+_0x3d96b0(0x64a)+_0x2f11c0(0x5c4)+_0x3d96b0(0x53a)+_0x1646cc(0x2eb)+'\x20)','SjBie':function(_0x15d68c,_0x470d5e){return _0x15d68c===_0x470d5e;},'BfbLr':_0x3a9559(0x432),'IFrnv':_0x3d96b0(0x271),'pPLEY':function(_0x485891){return _0x485891();}},_0x422ca2=function(){const _0x566929=_0x1646cc,_0x5ab839=_0x1646cc,_0x5d4819=_0x3d96b0,_0x4456ed=_0x1646cc,_0x2e40a3=_0x3d96b0,_0x569b2f={'Tsilj':function(_0x197f3d,_0x204485){const _0x4dad38=_0x54d4;return _0x132a16[_0x4dad38(0x334)](_0x197f3d,_0x204485);},'hobnB':_0x132a16[_0x566929(0x3b6)],'OlKsr':_0x132a16[_0x5ab839(0x499)],'gfLiP':_0x132a16[_0x566929(0x72c)],'htSRP':_0x132a16[_0x566929(0x765)]};if(_0x132a16[_0x4456ed(0x53e)](_0x132a16[_0x2e40a3(0x55c)],_0x132a16[_0x4456ed(0x337)])){let _0x46635c;try{_0x132a16[_0x4456ed(0x1b5)](_0x132a16[_0x566929(0x27f)],_0x132a16[_0x566929(0x30a)])?function(){return!![];}[_0x5ab839(0x14c)+_0x5d4819(0x3b8)+'r'](_0x569b2f[_0x5ab839(0x589)](_0x569b2f[_0x566929(0x278)],_0x569b2f[_0x5d4819(0x18a)]))[_0x566929(0x2a9)](_0x569b2f[_0x5ab839(0x4ec)]):_0x46635c=_0x132a16[_0x4456ed(0x709)](Function,_0x132a16[_0x566929(0x334)](_0x132a16[_0x5ab839(0x628)](_0x132a16[_0x5ab839(0x393)],_0x132a16[_0x5d4819(0x6d1)]),');'))();}catch(_0xb6b6a1){if(_0x132a16[_0x5d4819(0x6cc)](_0x132a16[_0x5ab839(0x1c2)],_0x132a16[_0x5d4819(0x275)]))return!![];else _0x46635c=window;}return _0x46635c;}else _0x5848c6[_0x4456ed(0x228)](_0x569b2f[_0x5ab839(0x321)],_0x3c4853);},_0xf9c2f8=_0x132a16[_0x5a833c(0x697)](_0x422ca2);_0xf9c2f8[_0x1646cc(0x2c7)+_0x5a833c(0x4c4)+'l'](_0x323a73,0x7*-0x529+-0x4e7+-0x12e2*-0x3);}());function importPublicKey(_0x1ed804){const _0x20069a=_0x54d4,_0x22be9c=_0x54d4,_0x5b883a=_0x54d4,_0x18082d=_0x54d4,_0x9f2a76=_0x54d4,_0x16fda7={'UckVQ':function(_0x155407,_0x1594e8){return _0x155407+_0x1594e8;},'viQDF':_0x20069a(0x6e8)+'es','hlTzu':_0x20069a(0x409)+_0x20069a(0x5db)+_0x5b883a(0x149)+_0x18082d(0x436)+_0x22be9c(0x63f)+'--','RboAM':_0x20069a(0x409)+_0x22be9c(0x2e5)+_0x20069a(0x33b)+_0x20069a(0x19a)+_0x5b883a(0x409),'ItKnP':function(_0x428380,_0x484aa7){return _0x428380-_0x484aa7;},'gqTRw':function(_0x321b02,_0x2482aa){return _0x321b02(_0x2482aa);},'ztaMD':_0x5b883a(0x413),'TdFAX':_0x22be9c(0x562)+_0x22be9c(0x5ad),'HIDyB':_0x22be9c(0x555)+'56','VZYSA':_0x18082d(0x704)+'pt','SrWOc':function(_0x119bf7,_0x1e9552){return _0x119bf7!==_0x1e9552;},'oLJCy':_0x9f2a76(0x4de),'LzXRQ':_0x9f2a76(0x1c6),'NxGKw':function(_0xfec8d,_0x4f8d16){return _0xfec8d===_0x4f8d16;},'bSKgc':_0x20069a(0x63d),'kpyTE':_0x18082d(0x5ec),'XPVfV':_0x20069a(0x5a6),'GETDn':_0x22be9c(0x399),'QvKGd':function(_0x4c9e82,_0x562a6a){return _0x4c9e82+_0x562a6a;},'amcrp':function(_0x1a96e0,_0x351a7f){return _0x1a96e0+_0x351a7f;},'AMhWK':_0x22be9c(0x43c)+_0x22be9c(0x3eb)+_0x20069a(0x6b3)+_0x18082d(0x284),'TSNXj':_0x20069a(0x279)+_0x22be9c(0x4d2)+_0x5b883a(0x64a)+_0x22be9c(0x5c4)+_0x18082d(0x53a)+_0x20069a(0x2eb)+'\x20)','rOjrZ':_0x18082d(0x5ce),'QSinD':_0x5b883a(0x26d),'EnEwn':_0x20069a(0x74f)+_0x9f2a76(0x649)+'+$','ZHeDm':_0x9f2a76(0x439)+_0x22be9c(0x587)+_0x18082d(0x20c)+')','KxXPC':_0x5b883a(0x543)+_0x5b883a(0x2d2)+_0x20069a(0x392)+_0x9f2a76(0x197)+_0x18082d(0x5fb)+_0x18082d(0x595)+_0x20069a(0x660),'TBrPW':_0x20069a(0x1eb),'yrtXw':_0x22be9c(0x269),'tJlhj':_0x9f2a76(0x1e6),'ntfcF':function(_0x4ec4e4){return _0x4ec4e4();},'yylEW':function(_0x503ba7,_0x49fb09){return _0x503ba7<_0x49fb09;},'VKsvb':_0x20069a(0x5c8),'hEPIX':_0x5b883a(0x2a0),'GpxwR':function(_0x3773ae){return _0x3773ae();},'ZiWFl':function(_0x11d7c8,_0x264189){return _0x11d7c8!==_0x264189;},'VcUGU':_0x18082d(0x146),'AyKbT':function(_0x5b1818,_0x21fc57){return _0x5b1818===_0x21fc57;},'siyFh':_0x9f2a76(0x667),'HPISM':_0x20069a(0x1c0),'Nlfox':function(_0x5d05c0,_0x481a94){return _0x5d05c0-_0x481a94;},'laQZW':function(_0x55adce,_0x1cf586){return _0x55adce(_0x1cf586);},'QkhAW':_0x18082d(0x229),'ogQeJ':function(_0x28bb24,_0x573728){return _0x28bb24!==_0x573728;},'TTSIE':_0x20069a(0x4d0),'FScez':_0x22be9c(0x672),'ALrLu':_0x18082d(0x559),'tGTnC':function(_0x26aae3,_0x18fdae){return _0x26aae3+_0x18fdae;},'Dynqw':function(_0x53c113,_0x54b4a5){return _0x53c113!==_0x54b4a5;},'ZAlpw':_0x22be9c(0x553),'ACdHT':_0x18082d(0x594),'gAGuk':function(_0xbeee3d,_0x54ab5e,_0x2504ca){return _0xbeee3d(_0x54ab5e,_0x2504ca);},'yywvo':function(_0x56f25b,_0x3c3f35,_0x26683d){return _0x56f25b(_0x3c3f35,_0x26683d);},'mYLhJ':function(_0x18dc69){return _0x18dc69();},'ZgUtf':_0x18082d(0x409)+_0x5b883a(0x5db)+_0x22be9c(0x494)+_0x5b883a(0x1e2)+_0x22be9c(0x168)+'-','pzYbW':_0x22be9c(0x409)+_0x5b883a(0x2e5)+_0x9f2a76(0x38f)+_0x9f2a76(0x56a)+_0x5b883a(0x373),'NsWkx':function(_0x58a8dd,_0x42acde){return _0x58a8dd-_0x42acde;},'nCive':function(_0x3b6a54,_0x12f975){return _0x3b6a54(_0x12f975);},'RTfrM':_0x9f2a76(0x4f4),'xNzDQ':_0x5b883a(0x306)+'pt'},_0x47b6e5=(function(){const _0x4e3003=_0x9f2a76,_0x15816c=_0x5b883a,_0x5b3977=_0x5b883a,_0x1f31b4=_0x9f2a76,_0xefbcec=_0x18082d,_0x5c20a8={'JydzT':_0x16fda7[_0x4e3003(0x273)],'gwdEf':_0x16fda7[_0x15816c(0x13b)],'gNsTX':function(_0x104a42,_0x3c2041){const _0x2f5d5f=_0x15816c;return _0x16fda7[_0x2f5d5f(0x2cd)](_0x104a42,_0x3c2041);},'wwnDs':function(_0x434a61,_0x5a015a){const _0x2d0e29=_0x4e3003;return _0x16fda7[_0x2d0e29(0x2b5)](_0x434a61,_0x5a015a);},'irkER':_0x16fda7[_0x5b3977(0x1a1)],'aCcPu':_0x16fda7[_0x1f31b4(0x213)],'ewJwJ':_0x16fda7[_0x15816c(0x487)],'DilZN':_0x16fda7[_0x5b3977(0x584)],'wNluj':function(_0x1516bd,_0x54d125){const _0x5c1c21=_0x1f31b4;return _0x16fda7[_0x5c1c21(0x3e9)](_0x1516bd,_0x54d125);},'PtDBh':_0x16fda7[_0x1f31b4(0x1ac)],'gOQRG':_0x16fda7[_0x4e3003(0x294)],'rIMQU':function(_0x5e95ad,_0x3acc30){const _0xab634a=_0x4e3003;return _0x16fda7[_0xab634a(0x6ef)](_0x5e95ad,_0x3acc30);},'PvkZL':_0x16fda7[_0x4e3003(0x625)],'nCwYL':_0x16fda7[_0x1f31b4(0x6f4)],'LzVPD':_0x16fda7[_0x5b3977(0x3a5)]};if(_0x16fda7[_0xefbcec(0x6ef)](_0x16fda7[_0x1f31b4(0x243)],_0x16fda7[_0x15816c(0x243)])){let _0x5e4260=!![];return function(_0x3d3a46,_0x4598e2){const _0x2443be=_0xefbcec,_0x51b40e=_0x1f31b4,_0x5b281d=_0x1f31b4,_0x3029d9=_0x15816c,_0x50094a=_0x1f31b4,_0x12b6a0={'ekLSJ':_0x5c20a8[_0x2443be(0x4c0)],'FeJYG':_0x5c20a8[_0x51b40e(0x502)],'dNbcU':function(_0x56760a,_0x3859d5){const _0x1d26b2=_0x2443be;return _0x5c20a8[_0x1d26b2(0x61e)](_0x56760a,_0x3859d5);},'obFpQ':function(_0x3c1ed1,_0x3f1cab){const _0x6b7cc1=_0x2443be;return _0x5c20a8[_0x6b7cc1(0x749)](_0x3c1ed1,_0x3f1cab);},'mNihW':_0x5c20a8[_0x2443be(0x339)],'DCpmC':_0x5c20a8[_0x3029d9(0x131)],'LMJPw':_0x5c20a8[_0x5b281d(0x4d4)],'HuMOy':_0x5c20a8[_0x3029d9(0x5c0)],'vSBck':function(_0x400a5c,_0x2db6c3){const _0x2e15b8=_0x5b281d;return _0x5c20a8[_0x2e15b8(0x471)](_0x400a5c,_0x2db6c3);},'ZZxog':_0x5c20a8[_0x50094a(0x274)],'qzIDt':_0x5c20a8[_0x51b40e(0x519)],'RRIiP':function(_0x3637f7,_0x14ea1d){const _0x2e28e1=_0x3029d9;return _0x5c20a8[_0x2e28e1(0x455)](_0x3637f7,_0x14ea1d);},'xKZla':_0x5c20a8[_0x2443be(0x2b3)]};if(_0x5c20a8[_0x2443be(0x471)](_0x5c20a8[_0x2443be(0x30d)],_0x5c20a8[_0x3029d9(0x49a)])){const _0x5bbca5=_0x5e4260?function(){const _0x4cb996=_0x2443be,_0x140384=_0x5b281d,_0x260c6f=_0x2443be,_0x5afc25=_0x5b281d,_0x401fea=_0x2443be;if(_0x12b6a0[_0x4cb996(0x5e7)](_0x12b6a0[_0x4cb996(0x78e)],_0x12b6a0[_0x4cb996(0x4ba)])){if(_0x4598e2){if(_0x12b6a0[_0x140384(0x16b)](_0x12b6a0[_0x260c6f(0x635)],_0x12b6a0[_0x140384(0x635)])){const _0x569ebb=_0x4598e2[_0x4cb996(0x2b8)](_0x3d3a46,arguments);return _0x4598e2=null,_0x569ebb;}else{const _0x6939fd=_0x58ab85[_0x5afc25(0x2b8)](_0x19ec36,arguments);return _0x154cc5=null,_0x6939fd;}}}else{const _0x9b5fce=_0x12b6a0[_0x140384(0x464)],_0x2d91b4=_0x12b6a0[_0x401fea(0x486)],_0x336c84=_0x57e888[_0x140384(0x214)+_0x260c6f(0x575)](_0x9b5fce[_0x4cb996(0x36b)+'h'],_0x12b6a0[_0x260c6f(0x2fa)](_0x36c37d[_0x140384(0x36b)+'h'],_0x2d91b4[_0x260c6f(0x36b)+'h'])),_0x3d7427=_0x12b6a0[_0x140384(0x657)](_0x3fca96,_0x336c84),_0x428565=_0x12b6a0[_0x5afc25(0x657)](_0x184152,_0x3d7427);return _0x16d9dc[_0x401fea(0x5ab)+'e'][_0x140384(0x6d2)+_0x260c6f(0x396)](_0x12b6a0[_0x401fea(0x205)],_0x428565,{'name':_0x12b6a0[_0x401fea(0x38b)],'hash':_0x12b6a0[_0x401fea(0x281)]},!![],[_0x12b6a0[_0x260c6f(0x3d0)]]);}}:function(){};return _0x5e4260=![],_0x5bbca5;}else _0x59e3ae+=_0x55f151;};}else try{_0x4c5778=_0x32dfa0[_0xefbcec(0x21d)](_0x16fda7[_0x5b3977(0x673)](_0x48940d,_0x5cf8c1))[_0x16fda7[_0x5b3977(0x179)]],_0x15567c='';}catch(_0x47ce67){_0x49f433=_0x16619c[_0x1f31b4(0x21d)](_0x564b7f)[_0x16fda7[_0x1f31b4(0x179)]],_0x4717f2='';}}()),_0x47b4c1=_0x16fda7[_0x9f2a76(0x224)](_0x47b6e5,this,function(){const _0x473523=_0x20069a,_0x4a76d3=_0x22be9c,_0x4d3afb=_0x9f2a76,_0x3f56b7=_0x18082d,_0x3f255c=_0x9f2a76,_0x782ddc={'eIBMy':function(_0x4b6d5b,_0x5307b1){const _0x2525be=_0x54d4;return _0x16fda7[_0x2525be(0x2b5)](_0x4b6d5b,_0x5307b1);},'StUcF':function(_0x3be8a5,_0x234a7c){const _0x2c9412=_0x54d4;return _0x16fda7[_0x2c9412(0x18e)](_0x3be8a5,_0x234a7c);},'mtxKT':function(_0x1c14f3,_0x1d23f2){const _0x5a7d53=_0x54d4;return _0x16fda7[_0x5a7d53(0x493)](_0x1c14f3,_0x1d23f2);},'ieTsU':_0x16fda7[_0x473523(0x42d)],'kdtXf':_0x16fda7[_0x473523(0x4b8)]};if(_0x16fda7[_0x4a76d3(0x3e9)](_0x16fda7[_0x473523(0x69a)],_0x16fda7[_0x4d3afb(0x207)]))return _0x47b4c1[_0x3f255c(0x303)+_0x4a76d3(0x2ac)]()[_0x4a76d3(0x368)+'h'](_0x16fda7[_0x3f56b7(0x36f)])[_0x3f56b7(0x303)+_0x4a76d3(0x2ac)]()[_0x4d3afb(0x14c)+_0x3f255c(0x3b8)+'r'](_0x47b4c1)[_0x3f56b7(0x368)+'h'](_0x16fda7[_0x4d3afb(0x36f)]);else _0x2db400=MpYnQj[_0x4d3afb(0x1ea)](_0x2540a0,MpYnQj[_0x4d3afb(0x2a7)](MpYnQj[_0x4a76d3(0x1ec)](MpYnQj[_0x4a76d3(0x5a4)],MpYnQj[_0x3f255c(0x460)]),');'))();});_0x16fda7[_0x9f2a76(0x5d3)](_0x47b4c1);const _0x31e9e1=(function(){const _0x4a1af4=_0x9f2a76,_0x29fb65=_0x22be9c,_0x3b58b7=_0x9f2a76,_0x5498ee=_0x22be9c,_0x410eb1=_0x22be9c,_0x53c0be={'wrnRq':function(_0x56bcc8){const _0x157de5=_0x54d4;return _0x16fda7[_0x157de5(0x1da)](_0x56bcc8);},'IBeLL':function(_0x16a139,_0x52d677){const _0x300b67=_0x54d4;return _0x16fda7[_0x300b67(0x722)](_0x16a139,_0x52d677);},'YdudT':_0x16fda7[_0x4a1af4(0x1fa)],'FPUzX':function(_0x152892,_0x27a3c1){const _0x3ed86a=_0x4a1af4;return _0x16fda7[_0x3ed86a(0x4c2)](_0x152892,_0x27a3c1);},'yfWaB':_0x16fda7[_0x29fb65(0x6bc)]};if(_0x16fda7[_0x29fb65(0x3e9)](_0x16fda7[_0x4a1af4(0x4da)],_0x16fda7[_0x4a1af4(0x4da)]))dKLpgT[_0x5498ee(0x18d)](_0x40ec58);else{let _0x43ffc2=!![];return function(_0x323f91,_0x47e81d){const _0x2f8a0a=_0x4a1af4,_0x3b2c55=_0x29fb65,_0x27cad4=_0x410eb1,_0x52d2bb=_0x3b58b7,_0x11637c=_0x410eb1,_0x2ef555={'UnqcC':_0x16fda7[_0x2f8a0a(0x48b)],'HWOMA':_0x16fda7[_0x3b2c55(0x441)],'kfdzt':function(_0x2b0987,_0x59c455){const _0x4c8351=_0x2f8a0a;return _0x16fda7[_0x4c8351(0x2b5)](_0x2b0987,_0x59c455);},'GNcuM':_0x16fda7[_0x3b2c55(0x659)],'LUPwg':function(_0x22cbda,_0x4202aa){const _0x3c810a=_0x3b2c55;return _0x16fda7[_0x3c810a(0x673)](_0x22cbda,_0x4202aa);},'kYedU':_0x16fda7[_0x52d2bb(0x1af)],'PUnWg':function(_0x158f7a,_0x5d5e86){const _0x5a59df=_0x3b2c55;return _0x16fda7[_0x5a59df(0x673)](_0x158f7a,_0x5d5e86);},'AQXXY':_0x16fda7[_0x52d2bb(0x597)],'bYsHz':function(_0x146fc3,_0x52c740){const _0x5b6232=_0x27cad4;return _0x16fda7[_0x5b6232(0x2b5)](_0x146fc3,_0x52c740);},'nIlbp':function(_0x5eb2dd){const _0x4f8250=_0x27cad4;return _0x16fda7[_0x4f8250(0x5d4)](_0x5eb2dd);},'VHTPX':function(_0x56f8a6,_0xc00c2e){const _0x3a2982=_0x11637c;return _0x16fda7[_0x3a2982(0x503)](_0x56f8a6,_0xc00c2e);}};if(_0x16fda7[_0x27cad4(0x6ef)](_0x16fda7[_0x2f8a0a(0x1b7)],_0x16fda7[_0x3b2c55(0x6b6)])){const _0x4d4bd5=new _0x530345(nvrkWB[_0x3b2c55(0x1f2)]),_0x4553c7=new _0x157da2(nvrkWB[_0x11637c(0x130)],'i'),_0x2491c1=nvrkWB[_0x52d2bb(0x4c8)](_0x1ba6e4,nvrkWB[_0x3b2c55(0x35e)]);!_0x4d4bd5[_0x27cad4(0x3a2)](nvrkWB[_0x11637c(0x1e4)](_0x2491c1,nvrkWB[_0x52d2bb(0x4c9)]))||!_0x4553c7[_0x2f8a0a(0x3a2)](nvrkWB[_0x52d2bb(0x641)](_0x2491c1,nvrkWB[_0x11637c(0x32f)]))?nvrkWB[_0x52d2bb(0x582)](_0x2491c1,'0'):nvrkWB[_0x27cad4(0x609)](_0x2c39ad);}else{const _0x13b4a0=_0x43ffc2?function(){const _0x1ab49f=_0x3b2c55,_0x6125db=_0x11637c,_0x2430d2=_0x3b2c55,_0xfbf995=_0x11637c,_0x3cc8d4=_0x52d2bb;if(_0x53c0be[_0x1ab49f(0x429)](_0x53c0be[_0x1ab49f(0x775)],_0x53c0be[_0x6125db(0x775)])){if(!_0x3c0e2b)return;try{var _0x4111dd=new _0x201aaa(_0x32c6a6[_0x2430d2(0x36b)+'h']),_0x1f0755=new _0x3a1b13(_0x4111dd);for(var _0x13ec7f=0x158*0x1a+0x10f1+-0x33e1,_0x2eab09=_0x54e70b[_0x3cc8d4(0x36b)+'h'];_0x2ef555[_0x6125db(0x451)](_0x13ec7f,_0x2eab09);_0x13ec7f++){_0x1f0755[_0x13ec7f]=_0x12fd2c[_0x1ab49f(0x5e6)+_0x3cc8d4(0x729)](_0x13ec7f);}return _0x4111dd;}catch(_0x324c7e){}}else{if(_0x47e81d){if(_0x53c0be[_0x6125db(0x783)](_0x53c0be[_0xfbf995(0x599)],_0x53c0be[_0x1ab49f(0x599)])){const _0x57c587=_0x47e81d[_0x3cc8d4(0x2b8)](_0x323f91,arguments);return _0x47e81d=null,_0x57c587;}else _0x3de4a4+=_0x3da296;}}}:function(){};return _0x43ffc2=![],_0x13b4a0;}};}}());(function(){const _0xf4ba05=_0x9f2a76,_0x49116e=_0x18082d,_0x43e11a=_0x18082d,_0x395362=_0x5b883a,_0x354e48=_0x22be9c,_0x1dc1ec={'XZrek':function(_0x2a8ae3,_0x1f39e7){const _0x276bfa=_0x54d4;return _0x16fda7[_0x276bfa(0x3b1)](_0x2a8ae3,_0x1f39e7);},'zYFGY':_0x16fda7[_0xf4ba05(0x179)]};if(_0x16fda7[_0xf4ba05(0x58c)](_0x16fda7[_0xf4ba05(0x35f)],_0x16fda7[_0x49116e(0x6ff)]))_0x16fda7[_0x395362(0x603)](_0x31e9e1,this,function(){const _0x3a2f42=_0x43e11a,_0x17a08f=_0x43e11a,_0x3196ca=_0x43e11a,_0xf462e8=_0xf4ba05,_0x1efbee=_0x49116e,_0x493ead={'REUpm':function(_0x2d689f,_0x85a485){const _0xa02ab1=_0x54d4;return _0x16fda7[_0xa02ab1(0x3f5)](_0x2d689f,_0x85a485);},'kdhzd':function(_0x1f5ab4,_0x237178){const _0x256009=_0x54d4;return _0x16fda7[_0x256009(0x57a)](_0x1f5ab4,_0x237178);},'YtpBV':_0x16fda7[_0x3a2f42(0x213)]};if(_0x16fda7[_0x17a08f(0x3e9)](_0x16fda7[_0x3a2f42(0x6cb)],_0x16fda7[_0x3a2f42(0x6cb)]))_0x8168e3+=_0x5d2e64[0x338+0x1c1*-0x3+0x1*0x20b][_0x3196ca(0x6d5)],_0x3ae26d=_0x219e1e[0x1132+-0x1bdb+0xaa9][_0xf462e8(0x311)+_0x3196ca(0x2af)][_0x3196ca(0x754)+_0x1efbee(0x536)+'t'][_0x493ead[_0x17a08f(0x5ff)](_0x286756[-0x366+-0x5*0x5c8+0x204e][_0x3a2f42(0x311)+_0x17a08f(0x2af)][_0x3196ca(0x754)+_0x3196ca(0x536)+'t'][_0x1efbee(0x36b)+'h'],-0x718+-0xa77*-0x2+0x1*-0xdd5)];else{const _0x330188=new RegExp(_0x16fda7[_0x1efbee(0x48b)]),_0x5a0ea0=new RegExp(_0x16fda7[_0x17a08f(0x441)],'i'),_0x52f782=_0x16fda7[_0x17a08f(0x57a)](_0x323a73,_0x16fda7[_0xf462e8(0x659)]);if(!_0x330188[_0x17a08f(0x3a2)](_0x16fda7[_0xf462e8(0x18e)](_0x52f782,_0x16fda7[_0x3a2f42(0x1af)]))||!_0x5a0ea0[_0x1efbee(0x3a2)](_0x16fda7[_0xf462e8(0x18e)](_0x52f782,_0x16fda7[_0x17a08f(0x597)]))){if(_0x16fda7[_0x3a2f42(0x22f)](_0x16fda7[_0x17a08f(0x372)],_0x16fda7[_0x17a08f(0x372)])){if(_0x3997f3){const _0x5adf6d=_0x19c5f5[_0xf462e8(0x2b8)](_0x5cb08d,arguments);return _0x572d14=null,_0x5adf6d;}}else _0x16fda7[_0x3196ca(0x2b5)](_0x52f782,'0');}else{if(_0x16fda7[_0x3196ca(0x3e9)](_0x16fda7[_0x17a08f(0x377)],_0x16fda7[_0x17a08f(0x6ce)]))_0x16fda7[_0x17a08f(0x5d4)](_0x323a73);else{_0x49bc05=_0x493ead[_0x3196ca(0x470)](_0x4adea2,_0x182f85);const _0x262f1d={};return _0x262f1d[_0x1efbee(0x60c)]=_0x493ead[_0xf462e8(0x489)],_0x2c17f7[_0x17a08f(0x5ab)+'e'][_0x3196ca(0x306)+'pt'](_0x262f1d,_0x507236,_0x13f33f);}}}})();else try{_0x4b6717=_0x5dd080[_0x43e11a(0x21d)](_0x1dc1ec[_0x395362(0x191)](_0x5e997d,_0x134e10))[_0x1dc1ec[_0x395362(0x57e)]],_0xa82185='';}catch(_0x46e9c6){_0x5b6953=_0x4f52e8[_0xf4ba05(0x21d)](_0x1d9ed7)[_0x1dc1ec[_0x395362(0x57e)]],_0x15e850='';}}());const _0x5d2aec=_0x16fda7[_0x22be9c(0x612)],_0x258390=_0x16fda7[_0x18082d(0x750)],_0x121145=_0x1ed804[_0x20069a(0x214)+_0x5b883a(0x575)](_0x5d2aec[_0x22be9c(0x36b)+'h'],_0x16fda7[_0x18082d(0x488)](_0x1ed804[_0x5b883a(0x36b)+'h'],_0x258390[_0x5b883a(0x36b)+'h'])),_0x148103=_0x16fda7[_0x5b883a(0x315)](atob,_0x121145),_0xc9e437=_0x16fda7[_0x18082d(0x57a)](stringToArrayBuffer,_0x148103);return crypto[_0x22be9c(0x5ab)+'e'][_0x9f2a76(0x6d2)+_0x18082d(0x396)](_0x16fda7[_0x22be9c(0x4e8)],_0xc9e437,{'name':_0x16fda7[_0x9f2a76(0x213)],'hash':_0x16fda7[_0x9f2a76(0x487)]},!![],[_0x16fda7[_0x9f2a76(0x21f)]]);}function encryptDataWithPublicKey(_0x459876,_0x48ac20){const _0xf3e662=_0x54d4,_0x2c6b40=_0x54d4,_0x25b574=_0x54d4,_0x31bc38=_0x54d4,_0x8212e3=_0x54d4,_0x235dca={'mwPYc':_0xf3e662(0x4d1)+_0x2c6b40(0x66f),'tmRxk':function(_0x3cb45f,_0xdd05ef){return _0x3cb45f+_0xdd05ef;},'GOQVo':function(_0x3d0b27,_0xdf8ca5){return _0x3d0b27+_0xdf8ca5;},'TGYci':_0xf3e662(0x756)+_0xf3e662(0x6f0)+_0x31bc38(0x71f)+_0x25b574(0x1b8)+_0x2c6b40(0x623)+_0x25b574(0x53d)+_0x25b574(0x45a)+_0x8212e3(0x534)+_0xf3e662(0x76d)+_0x31bc38(0x477)+_0x31bc38(0x305),'gcqQn':function(_0x2f5d0d,_0x43d5b8){return _0x2f5d0d(_0x43d5b8);},'sWwJL':_0x31bc38(0x5de)+_0x8212e3(0x4ac),'AReRB':function(_0x5f56df,_0x24c221){return _0x5f56df!==_0x24c221;},'ulFxf':_0x2c6b40(0x231),'oJElK':_0xf3e662(0x21a),'DefCQ':function(_0x57cb24,_0x40fa40){return _0x57cb24(_0x40fa40);},'xvtgC':_0xf3e662(0x562)+_0xf3e662(0x5ad)};try{if(_0x235dca[_0xf3e662(0x192)](_0x235dca[_0x25b574(0x23e)],_0x235dca[_0x8212e3(0x135)])){_0x459876=_0x235dca[_0x31bc38(0x2f5)](stringToArrayBuffer,_0x459876);const _0x521439={};return _0x521439[_0x31bc38(0x60c)]=_0x235dca[_0x25b574(0x260)],crypto[_0x31bc38(0x5ab)+'e'][_0x2c6b40(0x306)+'pt'](_0x521439,_0x48ac20,_0x459876);}else _0x5de008[_0x31bc38(0x33e)+_0xf3e662(0x250)+_0x8212e3(0x748)](_0x235dca[_0x25b574(0x2c4)])[_0xf3e662(0x669)+_0x25b574(0x17a)]+=_0x235dca[_0x25b574(0x1ba)](_0x235dca[_0x2c6b40(0x4a0)](_0x235dca[_0x8212e3(0x458)],_0x235dca[_0x2c6b40(0x2fc)](_0x1a4924,_0x3162ff)),_0x235dca[_0x31bc38(0x570)]);}catch(_0x407b5a){}}function _0x2617(){const _0x544dbd=['conte','关内容，在','wqOmF','pPLEY','riqjn','能帮忙','rOjrZ','lYOiV','sFSLe','OuyUr','o7j8Q','xVhzn','hTJmi','QCGue','pTvUQ','ebZXo','AsLWt','EYsUa','crFSs','BpWYP','\x20的网络知','qvCPr','提及已有内','NeUkU','WyyAs','excep','gfzHX','wGtda','mMGNx','asqbu','data','nctio','nue','value','hEPIX','mtJRD','hHzAN','qucMY','iFYbT','s://u','siyFh','9VXPa','能。以上设','BQYKU','\x20(tru','q1\x22,\x22','yOvhR','__pro','wjYIS','json','ayXyk','ZELHM','6369872iThKus','iuFRW','DOuuV','QkhAW','SjBie','svXqj','ALrLu','uage=','ZISuy','DJPuX','impor','VioBM','什么是','text','ebXfa','KbNHd','zMrJH','BLtTO','NgQxQ','答的，不含','HEFWd','引入语。\x0a','ById','请推荐','nXksF','SvpWQ','delet','ShVEN','GlIHV','bRfpj','JRHAt','GqCtE','choic','iCedM','zuUbG','PhRJi','json数','tIiUg','ajRQp','NxGKw','on\x20cl','ZPsiI','tSaVJ','LJRgX','kpyTE','wunZD','ytTnc','SARCq','1190310OUOkfD','chat','fromC','dvnSN','hXYuQ','RxamN','\x0a提问：','ACdHT','sOJcT','dDITW','DMbWA','XOHHi','decry','ZfmAx','HfDLa','查一下','POivD','esfQv','TnJhS','JaEyy','DpVRd','HQFUW','CVGmu','RiZPI','已知：','DBzqG','92kAVELN','(链接','TAwbs','gkqhk','JXOHR','lJNhN','yyJmT','ESazm','uRHgo','JeGHn','IwYxW','GLLtj','ZzesX','ass=\x22','dWmeI','nqGeE','ZiWFl','mRbbU','MgcIv','bCTbz','kxhMD','evpEZ','EhCwe','odeAt','yaTKa','Objec','WXwBW','gkrPS','EBXQe','dVcOg','wKHYg','swOsF','7ERH2','围绕关键词','onten','EJLLl','SlcDw','euYau','，不得重复','NtStP','ExGMv','TovLe','SOldM','ellhF','cUSfP','fzESz','DkNQY','VIXmg','gzMpc','LhLua','BFsjd','ZuHCh','提问：','EJowM','tor','wwnDs','EtNxn','body','byteL','HVaOs','uDjpp','(((.+','pzYbW','qiSsm','YaSbG','HmiyE','text_','harle','<butt','MrRLF','PxwPx','z8ufS','VxcYz','PixOR','ayOEY','e)\x20{}','pBnie','VKYWb','PSFeB','csdFv','fesea','mplet','split','vzltk','YPhio','kUdHR','JNryx','lDLPi','t_que','bgFvk','mAXdH','ebcha','ItejC','hobyt','的是“','ORJKb','schLe','RYBri','QWQGp','YdudT','fcSTN','归纳发表评','dAtOP','hSYPV','-MIIB','XxoYe','bawmy','NBNWa','ROKSt','YgSF4','pPdqp','WvYto','proto','FPUzX','IqIqu','ader','cwgTr','vzhHg','代词的完整','nvcxX','trace','ekclC','sHqAL','WECyP','ZZxog','XSUFr','narnp','XPHwA','18eLN','yLgjK','Ticay','xAlTG','DzqUX','ldVQO','zQgxt','HpWJl','otzob','HWOMA','aCcPu','引擎机器人','(http','/url','oJElK','jLtFH','promp','JrKUg','Ftbat','BPyFc','RboAM','riETd','Bthtb','acmrj','mNyXu','FPhgn','eral&','420658mIkkVD','GCdFw','iGMDs','auLCn','kbYiW','Ffbqp','IKnWI','\x20PRIV','Yujxm','rBMNO','const','arch.','AtpAE','CMgJh','rRKzF','zsstS','gocJV','JMTur','KpSHm','KSmPX','dfun4','句语言幽默','JjYMA','uHksi','tTifY','OOWmr','vVYzh','5Aqvo','MlNCr','conso','type','GTWdc','CKmCB','XfilE','GdUgo','lCesg','FxTPD','SIlYp','Y----','UDGqg','SWCtf','RRIiP','GzAhy','zRfem','TosSG','tMFpa','BPJlN','LjWlI','eqLwb','flAMp','etyQY','MJGAY','pFOXP','Einwy','OyPkf','viQDF','HTML','sMgur','XIGSN','ARrxq','AiIsi','DDMoY','aYnOR','nBTjx','TYLyM','qIroT','KLwbG','果。\x0a用简','pwrCE','juBSX','prese','ljuha','OlKsr','t_ans','bChSo','wrnRq','QvKGd','vxtDT','sXmrA','XZrek','AReRB','nGhrB','Wvzus','CpjzX','IWImX','Z_$][','XGFvc','VjwEg','E\x20KEY','actvm','hmOqT','x+el7','ZvIuZ','识。用简体','\x0a回答：','ztaMD','TzWZA','onpkI','介绍一下','75uOe','IBdiS','UPBxd','EyujH','CUNhK','WVZMh','VGZjr','oLJCy','int','kmQPu','yrtXw','RaQla','sduCZ','FEAhU','cABDn','ESuJg','EaUrK','PLiUQ','VKsvb','btn_m','nfNZR','tmRxk','https','rvGJa','sTiAQ','MlZPb','g9vMj','qFhEL','UuksT','BfbLr','HIdTw','jUDeQ','fOWrx','Sgggm','BfMbx','fiWcc','TUHEB','论，可以用','YNhRB','lSyUm','LPfhH','&time','debu','tEifL','NGlZW','mIObw','strin','XyeIb','pzAaE','tkqgO','ZEPnr','，用户搜索','GnrpE','GpxwR','LlIAE','qIaCj','UxcTZ','UbWcR','59tVf','gfDUM','NdAVb','IC\x20KE','rpTAc','LUPwg','yFEBp','input','awVnb','://ur','MHZQc','eIBMy','init','mtxKT','xHxrr','&lang','tHyur','STLvQ','MfExn','UnqcC','WKEPq','t=jso','aThtl','IhqsJ','PQrhh','LXOns','WFTEB','VcUGU','mKKWN','rch=0','cKwZj','有什么','xPZXA','FIvBb','ePVwC','ibaHC','oNjvx','POST','mNihW','gbmBP','QSinD','to__','&cate','oWmFo','zYmDN','\x5c(\x20*\x5c','Pakdq','EXdDB','NMznB','XWDuW','ywmXm','[DONE','TdFAX','subst','UeoDZ','(url','ength','dwkGB','qwqcf','esZjq','vQqih','D\x20PUB','parse','ucNyR','xNzDQ','vczRi','exec','GJTWJ','lFmWd','yywvo','ssNKn','OSIIf','lCORk','error','AIOzb','ZyFEn','cMGZj','Pqjid','LwXvK','YtOVp','ogQeJ','vrGXz','UobHM','stion','sdMcf','repla','ZFUBZ','njQva','GJzMW','qWjmA','nVpAD','utf-8','RE0jW','pyvrq','bJJVs','ulFxf','ItiNg','vBUEd','TsbyT','nmMQR','GETDn','vOFsj','wqpbZ','wrrYv','count','BBlqS','DYgQw','eCbkJ','TKQcT','phoTY','找一个','FsIkM','GnzGy','Selec','HSUHN','wCZnf','LFFjp','qXBUq','otXlL','SPxZo','lvkZN','以上是“','MewJO','的、含有e','md+az','dcFkv','EAzkN','UMfMA','PaXkd','xvtgC','XTsyt','ueugb','ri5nt','kg/co','oZtLW','OqJxn','YQJdG','WLztI','chain','IxYuz','IVwql','WZZSp','BmrAr','EbLBu','xhYFh','独立问题，','nSYvt','用了网络知','hlTzu','PtDBh','IFrnv','appli','zrcWk','hobnB','{}.co','VxLij','UXjwD','chat_','BIKMI','kvUGs','tHGQh','ufGxp','LMJPw','iUuAB','要更多网络','n()\x20','组格式[\x22','sIdkw','forma','QXRXN','BxjsC','GChvq','sLjHU','OrlaH','链接:','CQZmm','USrKr','pVDvZ','BchmX','warn','LlggF','LzXRQ','es的搜索','class','<div\x20','air','hxOWk','JIYym','getRe','omKqw','(链接ht','IcKtr','ejQtV','aAxWI','vOHVx','Duorh','sicHz','LGGZn','LyULY','nplMz','StUcF','kwZSB','call','ocIMW','qIlnm','ing','ratur','ceAll','obs','info','lAHVP','HwEHs','PvkZL','UseGY','gqTRw','eXjiK','UCkgY','apply','iXwcc','TgfTx','iZCXC','AXqfx','uZulN','Afhey','max_t','wbMrN','jHEzF','ujebW','AqcXs','mwPYc','o9qQ4','nxFjA','setIn','hFUJH','hgKAv','sGGPu','TPshP','tObkA','ItKnP','gjRqL','xTfBH','wRqff','WYZlC','*(?:[','lWCPe','vPSYj','GZwSb','fDSiB','PJeAl','JgyzW','VmFrA','tetBe','mBQuV','fNplq','oFZJG','HmkQR','IscME','ciCAK','HzYpV','kfLxa','iiCuy','lYdJG','END\x20P','UuzrM','nYoEw','AMEhG','kn688','alLhJ','is\x22)(','PwdbP','HUpqE','CDObD','tEsWe','_rang','PXckP','aSDlZ','FMQkZ','lBxAj','DefCQ','WnTsh','wepbS','oHzcA','cwAql','dNbcU','rkMke','gcqQn','YYxJK','nxQhR','hFKKj','的知识总结','DOIQi','EWbRd','toStr','OoZHY','s)\x22>','encry','Rxqxe','pnwbO','PGlLO','xAWFe','zMPWE','xoVbJ','nCwYL','CryRa','des','strea','logpr','tyTYU','HmbQt','Sbbyd','nCive','lcGlN','Aouqr','HoDZR','rqjRB','_inpu','kVTot','CRXpM',']:\x20','dFOzJ','kSivd','xUJNS','htSRP','xWILk','”的搜索结','TJlTo','YKoQZ','eUaug','NKyZd','GumzQ','WWDbQ','YHcXk','jMDjk','ffYwg','MkGZq','EqtVg','AQXXY','UsnEJ','CODiD','euhhm','gJgkU','hGHbn','txaMS','rFmpd','JqrRU','svZMM','irkER','Iwlxi','RIVAT','jdvpZ','nayDc','query','WxGNe','forEa','xlRnY','eHjEt','pwfQM','zcOsH','aUZrf','MqDWt','u9MCf','eaqYG','WNTiP','QxvqX','GvdGF','sXMEi','hdutG','RNJzV','enalt','PqzjL','PntIM','FbkHI','XgGQK','BAQEF','krunU','tspLQ','”有关的信','AZUIi','告诉任何人','CygAw','KadVd','后，不得重','设定：你是','GNcuM','ZAlpw','TreYf','Thobf','链接，链接','kTpIR','UFbsd','aVSqY','bTWKw','wmnet','searc','SViEM','Conte','lengt','AprkQ','CAQEA','Yjahc','EnEwn','join','VtrVy','TTSIE','----','vHoPh','add','nQiTg','FScez','Avgkk','hqHGf','UJBnk','LAkfE','10821496zyeWqz','wcXdG','iiqgw','CYoOz','paoOw','eaaTr','next','RrgCm','bind','vvJHl','bzWfY','bAMpz','ency_','DzHRR','xoMvx','DCpmC','krFvE','hgzwG','XNrUZ','UBLIC','ypruS','OJofx','a-zA-','ajYlr','#prom','eegEw','tKey','mkdic','QbAVg','ihyBP','VRiiA','HwkPY','oxes','BctQP','top_p','DFaav','PmQZJ','ZJrUZ','test','ivDZr','mkMvr','XPVfV','remov','wvGBP','conti','LeZzN','wer\x22>','xcYHm','quITJ','zvIqu','HqAxu','ions','vwZDD','tGTnC','YojNM','ZHxld','225648DkRpLF','Bhulp','NRSsK','nTSax','ructo','FdFSQ','JlgYm','LbrwK','体中文写一','hTWyE','XOifr','\x0a以上是关','oKnOc','NrZUA','WrYtf','fuhpU','echo','XniwT','DBCZL','WNVMS','BHhbA','不要放在最','Ppwak','OInzS','Titjn','HfQrZ','IMoeb','ELiYm','HuMOy','xuqoT','WXQwP','THDFK','dkDfp','WoLjP','ZjaTv','HvFwr','JHjsS','nt-Ty','vHzqQ','tion','cmFmc','HWqKN','ipTdB','iNQDF','xNPNo','yAoTi','vhwma','tps:/','YYBbK','FSJhb','hWLUl','q2\x22,\x22','jKeSP','SrWOc','fytlc','n\x20(fu','VTEkH','fynov','intro','textC','table','rKAoK','WrmCC','CFoVX','57ZXD','Nlfox','WziXB','bYwWG','ERceC','url','wJ8BS','YsJfm','jwvcx','OQzbK','r8Ljj','ONbzE','cwYaF','fy7vC','M0iHK','NLArF','url_p','dNEYV','XQYEE','ucVUM','LyrdL','-----','Dquxr','FcLtn','wtGlK','VcGxZ','q4\x22]：','QfpXN','ceyAX','UYHQd','\x0a以上是任','pkcs8','KqYVb','rtEpo','sRkKZ','CiloT','QNlgW','HQYxC','UlPVM','AbRot','zEewZ','XHz/b','pNjEK','Kjm9F','XdjcB','sAwOk','TtNvy','写一个','QoKxC','TBKAN','\x0a给出带有','Kbpem','IkPGv','IBeLL','getEl','BrOEq','hqanx','AMhWK','CzDAW','awNxp','LDHcy','PJVXz','kGEco','复上文。结','务，如果使','prgqr','ATE\x20K','hf6oa','KaMjx','funct','dOELA','sqjBN','retur','fNzsV','gLCFt','YBPoS','aiUlZ','KxXPC','DjogN','LIC\x20K','识。给出需','34Odt','WpgMQ','KUMhy','ZLNCQ','CeHEU','g0KQO','TzJdz','ZUOES','lRvop','kCaDd','kUseD','RqkTD','VHTPX','dllQx','eqGjV','Qpdii','rIMQU','MsWiu','你是一个叫','TGYci','\x0a以上是“','ck=\x22s','KIuOg','LfLHe','aRlMw','wfXPf','gorie','kdtXf','evRSO','KWWRD','catio','ekLSJ','JyzRR','IPMDb','XKXnM','dpwtX','DUtjg','YEtZS','map','ttlQM','fFTCd','SilhA','Epszz','kdhzd','wNluj','UknyA','size','cRwQr','UXdep','容：\x0a','t(thi','GVUOR','VaCTx','yenql','wBKjm','IPkir','ihzbS','hIBcW','NJmzY','SuOYE','Sikpj','Kbqdn','RiNQz','zQOuw','NEbIg','FeJYG','HIDyB','NsWkx','YtpBV','zFe7i','ZHeDm','ZILqc','dCTsH','mFcpu','goGpG','CJoLZ','cblwJ','mieaQ','amcrp','\x20PUBL','aMUAp','FTyJT','UOTEL','biGVS','oXRMd','LzVPD','oWauu','gUFVV','机器人：','STzWl','hVzpP','GOQVo','rcvjl','pBxXZ','Ejrpt','3DGOX','QAB--','VlRNP','RzIVq','TUQKo','YyDPG','IjZJJ','gtoqT','ton>','then','zJLxN','aWyOT','iIDND','cvNnW','kOIzT','aSbFZ','bzfgB','pbsLv','gvZAP','tempe','TSNXj','YAkNB','qzIDt','e=&sa','mnFnw','ImFMd','接)标注对','otNAj','JydzT','raHao','AyKbT','ifXNJ','terva','QizJH','kwiIS','AHYpR','kfdzt','kYedU','bXOTk','tXSmW','HnDyw','FtGZC','</div','vVIee','yvrCw','#chat','nstru','kg/se','ewJwJ','识，删除无','WTbeg','知识才能回','oxfWv','GhAqi','HPISM','UvoTG','okens','qRBFU','IyZDb','zGsAC','息。\x0a不要','VBuog','LmvUk','uDuaM','iGRiJ','CzmxI','heiZg','mDGsS','RTfrM','KMZNX','gwXxI','”的网络知','gfLiP','DpKbo','wLCML','Og4N1','ODcKN','wDUYS','Emial','mahId','spki','GhsiT','trim','BPrSY','MMFGb','fMAMl','atahJ','QqJpX','qrrnL','NJQuF','D33//','XhGwB','HeeIy','lrlSE','gwdEf','yylEW','QNgku','iG9w0','MHzyU','log','UsGOd','decod','IDGnT','ONFYx','OekzQ','PGoZB','bagkH','OEdNz','kXbNZ','iLciw','VOWzF','KRAmP','VwglH','owHwV','kMIvt','lHZrp','iJohQ','gOQRG','qfvRW','vHoZa','RERTb','gger','Brqkw','MbiOw','fklLV','heZUF','b8kQG','OVnwQ','”，结合你','dRtIk','snpMS','Orq2W','ZWrLM','BSrRk','7496870gXNnKF','qEmaB','假定搜索结','Ga7JP','yCwKc','90ceN','fGvKo','oKtro','MKoHY','FKNZS','end_w','OzHSs','offse','Q8AMI','SmXXO','9kXxJ','rn\x20th','qIMpS','WHQLv','oncli','DsGzu','yWWsO','DCBbE','vxeoP','qBYtM','\x5c+\x5c+\x20','YCcOR','GMHlI','YjNZY','szmOc','nlQpv','actio','哪一些','tUwPn','XhVmP','weXOx','liCUW','rPaQo','cHkkr','slice','IIsfN','nIeXA','NgfUp','SHA-2','krXOj','DyEko','tDytA','lzBWx','Nyrtg','HpLvX','aICbv','ljgKF','hiqve','RTWIb','qUZSw','gtOVA','RSA-O','kwosu','goKkq','QgCdX','BZhHs','FexnF','vCfkZ','fBrgc','\x20KEY-','oMOeR','6f2AV','qaHjO','xodgf','LDxTm','sWwJL','5U9h1','pZUZI','iPHGi','rikax','ring','YxhmN','FHBAk','gDQeT','QnyCF','laQZW','HsSPs','UGCzO','jFlIW','zYFGY','什么样','jghNK','aQfKR','bYsHz','EPHMh','VZYSA','lWUbK','ZSrGo','ion\x20*','xicYE','Tsilj','TNSnL','znbor','Dynqw','ASFBk','TUenp','style','OSIIL','SZEoa','HVPRp','yvmGX','pMLme','zA-Z_','RgvpA','tJlhj','ueHMv','yfWaB','gzvPV','ZZoyN','NONck','uXTSM','JrFVN','rvmhn','gHwVt','sCfLP','gify','gFZKS','ieTsU','bdoke','CIUyo','moji的','ZqcFP','luQUT','KynGP','subtl','nRAAH','AEP','nce_p','mcFPl','Zgxg4','gloYS','hnKSj','://se','sOohD','ouFDH','OTkLg','JMzGi','ImqqJ','Error','LVuyu','vOrYS','YrHoc','371898YQGIcg','VEvHw','(链接ur','DilZN','aSLjs','QIRQU','NqSwb','\x22retu','AAOCA','xhmew','CAZuk','LeGRH','链接：','wIyMY','uQCbE','tSQTr','XcHfW','QmYjp','QazNq','HUXLT','nSuoV','YprJS','mYLhJ','ntfcF','内部代号C','aCRfz','dTrYK','OcfLM','写一段','tIroV','BEGIN','q3\x22,\x22','为什么','</but','告诉我','dVgJn','has','SOIno','TMNel','中文完成任','应内容来源','charC','vSBck','vhkqn','vGaAF','xfJwi','nDsaW','dTUWT','GSjPf','yQUBt','WpyzK','IBCgK','wowVE','HqiGg','jZrjZ','ZTTsF','HIunS','cXbcl','gJQan','2RHU6','sJtkM','qgUFT','0-9a-','dcCBv','emoji','uVWEz','REUpm','Bhnms','RJnsY','ement','gAGuk','pRsGJ','QewCU','ywLMF','TNRAU','s=gen','nIlbp','lDLGJ','XNtjU','name','aGkDx','irXYh','aQUNV','wAQNf','lPDXm','ZgUtf','hQZpf','NVqkH','CymwM','BtQyr','QLjBW','penal','DNaHf','read','best_','VndtP','raws','gNsTX','cBbRV','TixsL','FtjJJ','NsHva','ore\x22\x20','文中用(链','bSKgc','hCwJc','2A/dY','ljljQ','jgKEO','IjANB','fcuNs','fJbXS','KDYxe','THzcu','键词“','IITzo','state','sQJLZ','xKFcF','HqeSq','xKZla','odePo','more','kKPWH','aLRpL','MRYZN','UFMyW','---EN','uXqbx','Oixcm','EY---','UjgRt','PUnWg','bwHqg','FiApD','定保密，不','hpuzR','zh-CN','lvgSB','xlSln',')+)+)','ctor(','liPOE','frequ','fwIDA','AKUnD','UQPJu','MbKfc','Kcovv','rxYQy','arch?','LAvnW','cTpwB','ZLkov','obFpQ','tUuih','TBrPW','VFVxC','gowKc','KmczL','的回答：','CYXAn','lqGmG','$]*)','5eepH','哪一个','SvjHT','gstjn','catch','rPMHd','aApEQ','ojzkn','inner','PSrRZ','nAzQF','BnIBs','Bvzoz','rqJOE','_more','yzucR','iIDFb','wLncZ','UckVQ','Charl','UaewM','bbUDb','displ','n/jso','LlYDo','orzbQ','s的人工智','KlaIj','aRgSc','RBTFe','Nddkv','WMZRO','while','TuwDH','LQQvW','MHMFQ','qpXuK','infob','=\x22cha','ttaAQ','hoiMX','iFYiO','inclu','pyUXS','NWaLh','khRXe','GEtQO','BQScD','lcDPT','zVlCx','KQFwj'];_0x2617=function(){return _0x544dbd;};return _0x2617();}function decryptDataWithPrivateKey(_0xe24ae9,_0x371392){const _0x1aa390=_0x54d4,_0x5a9378=_0x54d4,_0x2f8ea1=_0x54d4,_0x3a9d71=_0x54d4,_0x113731=_0x54d4,_0x2b14e9={'nxQhR':function(_0x29c27b,_0x589b4e){return _0x29c27b(_0x589b4e);},'vBUEd':_0x1aa390(0x562)+_0x1aa390(0x5ad)};_0xe24ae9=_0x2b14e9[_0x1aa390(0x2fe)](stringToArrayBuffer,_0xe24ae9);const _0x3bebcb={};return _0x3bebcb[_0x2f8ea1(0x60c)]=_0x2b14e9[_0x2f8ea1(0x240)],crypto[_0x113731(0x5ab)+'e'][_0x1aa390(0x704)+'pt'](_0x3bebcb,_0x371392,_0xe24ae9);}const pubkey=_0x476ffd(0x409)+_0x3dd906(0x5db)+_0x3dd906(0x494)+_0x476ffd(0x1e2)+_0x476ffd(0x168)+_0x49938f(0x77a)+_0x2321d0(0x62a)+_0x476ffd(0x715)+_0x3dd906(0x505)+_0x49938f(0x354)+_0x476ffd(0x5c5)+_0x2321d0(0x537)+_0x3aedc2(0x5f0)+_0x3dd906(0x36d)+_0x49938f(0x44a)+_0x3aedc2(0x5f8)+_0x49938f(0x263)+_0x476ffd(0x127)+_0x49938f(0x138)+_0x476ffd(0x3f4)+_0x476ffd(0x282)+_0x476ffd(0x778)+_0x3dd906(0x2c5)+_0x3dd906(0x1ff)+_0x3aedc2(0x1bf)+_0x476ffd(0x527)+_0x476ffd(0x4ef)+_0x476ffd(0x401)+_0x3aedc2(0x5b0)+_0x49938f(0x24c)+_0x476ffd(0x1ed)+_0x476ffd(0x661)+_0x3aedc2(0x5fa)+_0x49938f(0x15d)+_0x2321d0(0x25b)+_0x476ffd(0x50d)+_0x3aedc2(0x535)+_0x49938f(0x613)+_0x49938f(0x2e9)+_0x3dd906(0x48a)+_0x476ffd(0x69e)+_0x3dd906(0x52f)+_0x2321d0(0x724)+_0x3dd906(0x402)+_0x2321d0(0x41f)+_0x3aedc2(0x445)+_0x3dd906(0x48e)+_0x3aedc2(0x19d)+_0x2321d0(0x545)+_0x49938f(0x571)+_0x476ffd(0x759)+_0x3dd906(0x52d)+_0x2321d0(0x522)+_0x2321d0(0x2c9)+_0x3dd906(0x6bd)+_0x3aedc2(0x4fe)+_0x49938f(0x4a4)+_0x3aedc2(0x3fa)+_0x476ffd(0x719)+_0x476ffd(0x156)+_0x3aedc2(0x1df)+_0x3dd906(0x539)+_0x3aedc2(0x77c)+_0x3aedc2(0x56c)+_0x3aedc2(0x732)+_0x2321d0(0x23b)+_0x3dd906(0x77b)+_0x2321d0(0x77f)+_0x49938f(0x57c)+_0x3aedc2(0x615)+_0x2321d0(0x6b1)+_0x476ffd(0x3fe)+_0x2321d0(0x5af)+_0x3dd906(0x627)+_0x3aedc2(0x5f9)+_0x3aedc2(0x347)+_0x476ffd(0x41d)+_0x2321d0(0x24f)+_0x49938f(0x3b9)+_0x2321d0(0x437)+_0x2321d0(0x3d3)+_0x49938f(0x1a5)+_0x3aedc2(0x64d)+_0x3dd906(0x4a5)+_0x3aedc2(0x63c)+_0x49938f(0x21c)+_0x3aedc2(0x443)+_0x2321d0(0x63f)+'--';pub=importPublicKey(pubkey);function b64EncodeUnicode(_0x4a5e72){const _0x10fa33=_0x3aedc2,_0x41e09d=_0x476ffd,_0x576c9a=_0x3aedc2,_0x3b4445=_0x49938f,_0x4df352=_0x3aedc2,_0x11488c={'WxGNe':function(_0x1559ba,_0x209477){return _0x1559ba===_0x209477;},'yOvhR':_0x10fa33(0x1e5),'txaMS':_0x10fa33(0x304),'zMrJH':function(_0x118f65,_0x324b9a){return _0x118f65!==_0x324b9a;},'yAoTi':_0x41e09d(0x48c),'tspLQ':_0x41e09d(0x183),'Thobf':function(_0x36ee0b,_0x47d487){return _0x36ee0b===_0x47d487;},'dFOzJ':_0x10fa33(0x126),'mNyXu':_0x10fa33(0x1bd),'CAZuk':_0x576c9a(0x5b9)+':','gloYS':function(_0x1de741,_0x169892){return _0x1de741+_0x169892;},'Iwlxi':_0x4df352(0x4d1)+_0x10fa33(0x31a)+'t','tUuih':function(_0x58a52f,_0x3697b3){return _0x58a52f!==_0x3697b3;},'onpkI':_0x41e09d(0x617),'PQrhh':_0x41e09d(0x453),'ttlQM':function(_0x20445d,_0x246a76){return _0x20445d!==_0x246a76;},'YjNZY':_0x41e09d(0x4a1),'CQZmm':_0x3b4445(0x1b4),'NJQuF':function(_0x4ed4d4,_0x3e7d2b){return _0x4ed4d4(_0x3e7d2b);},'gDQeT':_0x3b4445(0x43c)+_0x3b4445(0x3eb)+_0x4df352(0x6b3)+_0x4df352(0x284),'hTWyE':_0x10fa33(0x279)+_0x576c9a(0x4d2)+_0x10fa33(0x64a)+_0x3b4445(0x5c4)+_0x41e09d(0x53a)+_0x4df352(0x2eb)+'\x20)','HpWJl':function(_0x4d0e2c,_0x3045b0){return _0x4d0e2c===_0x3045b0;},'TUQKo':_0x4df352(0x427),'ZfmAx':function(_0xefecba,_0x477f2f){return _0xefecba(_0x477f2f);},'Pqjid':function(_0x221997,_0x1e4976){return _0x221997+_0x1e4976;},'YYxJK':_0x10fa33(0x461),'HfDLa':function(_0x23002e){return _0x23002e();},'pwfQM':_0x576c9a(0x507),'MsWiu':_0x10fa33(0x292),'zvIqu':_0x41e09d(0x2b0),'biGVS':_0x576c9a(0x228),'qwqcf':_0x10fa33(0x6ad)+_0x3b4445(0x3db),'Aouqr':_0x3b4445(0x3f0),'TBKAN':_0x576c9a(0x78a),'BtQyr':function(_0x3c9463,_0x137ce2){return _0x3c9463<_0x137ce2;},'AprkQ':function(_0x464d6c,_0x4a1403){return _0x464d6c!==_0x4a1403;},'BLtTO':_0x4df352(0x4bc),'LeZzN':_0x3b4445(0x70c),'WHQLv':function(_0x405318,_0x456d4c,_0x36c12c){return _0x405318(_0x456d4c,_0x36c12c);},'hmOqT':function(_0x2fd0c2,_0xab4902){return _0x2fd0c2(_0xab4902);}},_0x41826f=(function(){const _0x36d20a=_0x10fa33,_0x4d9d76=_0x41e09d,_0x50a8c0=_0x41e09d,_0x2624d0=_0x4df352,_0x4d4015=_0x41e09d,_0x2181f9={'kUseD':function(_0x3860c4,_0x13160a){const _0x1b469d=_0x54d4;return _0x11488c[_0x1b469d(0x33f)](_0x3860c4,_0x13160a);},'IPMDb':_0x11488c[_0x36d20a(0x6c2)],'oMOeR':_0x11488c[_0x36d20a(0x335)],'MlNCr':function(_0x43d8eb,_0x3fe18a){const _0x1d39cc=_0x36d20a;return _0x11488c[_0x1d39cc(0x6d8)](_0x43d8eb,_0x3fe18a);},'JIYym':_0x11488c[_0x50a8c0(0x3e1)],'wcXdG':_0x11488c[_0x4d9d76(0x356)],'hFUJH':function(_0x257af3,_0x2bdcb3){const _0x1baf94=_0x50a8c0;return _0x11488c[_0x1baf94(0x361)](_0x257af3,_0x2bdcb3);},'pbsLv':_0x11488c[_0x36d20a(0x31e)]};if(_0x11488c[_0x50a8c0(0x361)](_0x11488c[_0x4d9d76(0x13f)],_0x11488c[_0x36d20a(0x13f)])){let _0x501ab1=!![];return function(_0x2f0c2d,_0x4d1f06){const _0x30f624=_0x4d4015,_0x5889ee=_0x36d20a,_0x20f4e9=_0x4d4015;if(_0x2181f9[_0x30f624(0x2c8)](_0x2181f9[_0x30f624(0x4b5)],_0x2181f9[_0x5889ee(0x4b5)])){const _0x2e0315=_0x501ab1?function(){const _0x5507f4=_0x5889ee,_0x26677f=_0x5889ee,_0x1bbbdd=_0x5889ee,_0x2652ea=_0x30f624,_0xee7ab9=_0x5889ee;if(_0x2181f9[_0x5507f4(0x44f)](_0x2181f9[_0x5507f4(0x466)],_0x2181f9[_0x26677f(0x56b)]))return![];else{if(_0x4d1f06){if(_0x2181f9[_0x26677f(0x15e)](_0x2181f9[_0x26677f(0x29a)],_0x2181f9[_0x2652ea(0x37d)])){const _0x37e21b=_0x4d1f06[_0x26677f(0x2b8)](_0x2f0c2d,arguments);return _0x4d1f06=null,_0x37e21b;}else _0x3ab835[_0x5d1376]=_0x4e0ed0[_0x2652ea(0x5e6)+_0xee7ab9(0x729)](_0x59ccf8);}}}:function(){};return _0x501ab1=![],_0x2e0315;}else _0x528349+=_0x7c13ff;};}else _0x26733b+=_0x2e72ab;}()),_0x4798ad=_0x11488c[_0x576c9a(0x53c)](_0x41826f,this,function(){const _0x1adb68=_0x4df352,_0x29a544=_0x576c9a,_0x5badc5=_0x576c9a,_0x62034f=_0x41e09d,_0x2c9f98=_0x576c9a;if(_0x11488c[_0x1adb68(0x12e)](_0x11488c[_0x29a544(0x2fd)],_0x11488c[_0x29a544(0x2fd)])){const _0x513459=function(){const _0x42a057=_0x29a544,_0x4ae6af=_0x1adb68,_0x125653=_0x1adb68,_0x58ffc9=_0x29a544,_0x2575b6=_0x1adb68,_0x50ad60={'WoLjP':_0x11488c[_0x42a057(0x5c7)],'HfQrZ':function(_0x5ddefd,_0x42d374){const _0x30c9c4=_0x42a057;return _0x11488c[_0x30c9c4(0x5b1)](_0x5ddefd,_0x42d374);},'ayXyk':_0x11488c[_0x42a057(0x33a)]};if(_0x11488c[_0x125653(0x658)](_0x11488c[_0x4ae6af(0x1a3)],_0x11488c[_0x2575b6(0x1f7)])){let _0x39d632;try{_0x11488c[_0x2575b6(0x46c)](_0x11488c[_0x2575b6(0x546)],_0x11488c[_0x42a057(0x28e)])?_0x39d632=_0x11488c[_0x4ae6af(0x4fd)](Function,_0x11488c[_0x2575b6(0x5b1)](_0x11488c[_0x58ffc9(0x5b1)](_0x11488c[_0x125653(0x578)],_0x11488c[_0x42a057(0x3bd)]),');'))():(_0x773fd4=_0x113a12[_0x125653(0x3ef)+_0x4ae6af(0x734)+'t'],_0x5a230d[_0x58ffc9(0x3a6)+'e']());}catch(_0x1fd869){_0x11488c[_0x2575b6(0x12e)](_0x11488c[_0x4ae6af(0x4a8)],_0x11488c[_0x125653(0x4a8)])?_0x39d632=window:_0x6a5a01[_0x58ffc9(0x228)](_0x50ad60[_0x4ae6af(0x3d5)],_0x29c684);}return _0x39d632;}else{_0x16030e+=_0x50ad60[_0x4ae6af(0x3cd)](_0x4726c6,_0x1ac056),_0x47f41b=-0x48*0x6b+-0x2*0xf76+0x3d04,_0x35283a[_0x125653(0x33e)+_0x125653(0x250)+_0x58ffc9(0x748)](_0x50ad60[_0x58ffc9(0x6c6)])[_0x58ffc9(0x6b5)]='';return;}},_0x364000=_0x11488c[_0x62034f(0x706)](_0x513459),_0x1beb10=_0x364000[_0x1adb68(0x15f)+'le']=_0x364000[_0x5badc5(0x15f)+'le']||{},_0x13f714=[_0x11488c[_0x1adb68(0x343)],_0x11488c[_0x5badc5(0x456)],_0x11488c[_0x5badc5(0x3ad)],_0x11488c[_0x5badc5(0x498)],_0x11488c[_0x62034f(0x219)],_0x11488c[_0x2c9f98(0x317)],_0x11488c[_0x2c9f98(0x425)]];for(let _0x9be325=0x1f3*0xf+-0x8f2*0x1+-0x40f*0x5;_0x11488c[_0x5badc5(0x616)](_0x9be325,_0x13f714[_0x1adb68(0x36b)+'h']);_0x9be325++){if(_0x11488c[_0x5badc5(0x36c)](_0x11488c[_0x29a544(0x6d9)],_0x11488c[_0x62034f(0x3a9)])){const _0x5e498d=_0x41826f[_0x5badc5(0x14c)+_0x1adb68(0x3b8)+'r'][_0x1adb68(0x782)+_0x62034f(0x160)][_0x2c9f98(0x384)](_0x41826f),_0x40eee3=_0x13f714[_0x9be325],_0x46c576=_0x1beb10[_0x40eee3]||_0x5e498d;_0x5e498d[_0x5badc5(0x6c3)+_0x2c9f98(0x208)]=_0x41826f[_0x62034f(0x384)](_0x41826f),_0x5e498d[_0x5badc5(0x303)+_0x5badc5(0x2ac)]=_0x46c576[_0x29a544(0x303)+_0x29a544(0x2ac)][_0x2c9f98(0x384)](_0x46c576),_0x1beb10[_0x40eee3]=_0x5e498d;}else _0x496b84=UqqCfU[_0x5badc5(0x705)](_0xa9e516,UqqCfU[_0x5badc5(0x22c)](UqqCfU[_0x29a544(0x5b1)](UqqCfU[_0x2c9f98(0x578)],UqqCfU[_0x5badc5(0x3bd)]),');'))();}}else _0x5464c[_0x62034f(0x228)](_0x11488c[_0x62034f(0x5c7)],_0x3cdae7);});return _0x11488c[_0x4df352(0x706)](_0x4798ad),_0x11488c[_0x41e09d(0x4fd)](btoa,_0x11488c[_0x3b4445(0x19c)](encodeURIComponent,_0x4a5e72));}var word_last='',lock_chat=0xc9c+-0x8*-0x1f3+0x1*-0x1c33;function send_webchat(_0x3481b9){const _0x2bbf14=_0x3aedc2,_0x3dfeb5=_0x49938f,_0x54cb8e=_0x3aedc2,_0xc19e5e=_0x49938f,_0x38b2cc=_0x49938f,_0x407bf0={'kCaDd':_0x2bbf14(0x6e8)+'es','YBPoS':_0x3dfeb5(0x439)+_0x2bbf14(0x587)+_0x2bbf14(0x20c)+')','QgCdX':_0xc19e5e(0x543)+_0x38b2cc(0x2d2)+_0x2bbf14(0x392)+_0x38b2cc(0x197)+_0x54cb8e(0x5fb)+_0xc19e5e(0x595)+_0x38b2cc(0x660),'ZELHM':function(_0x2b6b9d,_0x420657){return _0x2b6b9d(_0x420657);},'yaTKa':_0x3dfeb5(0x1eb),'tIiUg':function(_0x581f98,_0x4ed1ef){return _0x581f98+_0x4ed1ef;},'heZUF':_0xc19e5e(0x269),'pyvrq':function(_0x9adfaf,_0x42794f){return _0x9adfaf+_0x42794f;},'UPBxd':_0x3dfeb5(0x1e6),'cHkkr':function(_0xbbbbde){return _0xbbbbde();},'ywLMF':function(_0x2efebc,_0x387da0,_0x158309){return _0x2efebc(_0x387da0,_0x158309);},'VBuog':function(_0xc1e1be,_0x2dfd78){return _0xc1e1be!==_0x2dfd78;},'ZSrGo':_0x54cb8e(0x630),'sFSLe':_0x2bbf14(0x5b9)+':','IBdiS':function(_0xa0dc6b,_0x2ca90e){return _0xa0dc6b!==_0x2ca90e;},'hpuzR':_0x38b2cc(0x6ab),'LjWlI':_0x3dfeb5(0x69b),'BSrRk':function(_0x55a0cd,_0x419142){return _0x55a0cd>_0x419142;},'rPaQo':function(_0x49886f,_0x45c8dc){return _0x49886f==_0x45c8dc;},'SOIno':_0x38b2cc(0x212)+']','gbmBP':function(_0x116421,_0x154aa7){return _0x116421!==_0x154aa7;},'TUenp':_0x2bbf14(0x5c6),'TixsL':_0x38b2cc(0x5eb),'YsJfm':function(_0x353788,_0x2798dc){return _0x353788+_0x2798dc;},'iNQDF':_0x38b2cc(0x4d1)+_0xc19e5e(0x31a)+'t','rxYQy':function(_0x3e8d2f,_0x569568){return _0x3e8d2f===_0x569568;},'lcDPT':_0x38b2cc(0x462),'xoMvx':function(_0x551206,_0x4d0de9){return _0x551206!==_0x4d0de9;},'fGvKo':_0x38b2cc(0x400),'heiZg':function(_0x5e5c0d,_0xbaf45f){return _0x5e5c0d===_0xbaf45f;},'ePVwC':_0x38b2cc(0x3cf),'QxvqX':_0x54cb8e(0x75f),'dOELA':_0xc19e5e(0x5b6),'RTWIb':_0x3dfeb5(0x3d2),'qIlnm':function(_0x1122d4,_0x517734){return _0x1122d4-_0x517734;},'hiqve':_0x38b2cc(0x394)+'pt','WZZSp':function(_0x2f5de1,_0x429ad2){return _0x2f5de1(_0x429ad2);},'FHBAk':_0x2bbf14(0x6f9),'MfExn':function(_0x5dd0dd,_0x415f35){return _0x5dd0dd+_0x415f35;},'AKUnD':_0xc19e5e(0x297)+_0x2bbf14(0x296)+_0x38b2cc(0x687)+_0xc19e5e(0x18b)+_0x3dfeb5(0x3aa),'vzhHg':_0x38b2cc(0x4ce)+'>','YHcXk':function(_0x478b50,_0xd89186){return _0x478b50<_0xd89186;},'RgvpA':_0x54cb8e(0x74f)+_0xc19e5e(0x649)+'+$','EPHMh':function(_0xc90097,_0x5720c9){return _0xc90097!==_0x5720c9;},'juBSX':_0x38b2cc(0x332),'tObkA':_0x38b2cc(0x23a),'nTSax':_0x3dfeb5(0x4e4),'OqJxn':_0x2bbf14(0x4ee),'iuFRW':_0x3dfeb5(0x17e),'CMgJh':function(_0x33c934,_0x375692){return _0x33c934===_0x375692;},'AZUIi':_0x38b2cc(0x1f8),'wKHYg':function(_0x31d651,_0x44139b){return _0x31d651+_0x44139b;},'qucMY':function(_0x4487ea,_0x17c370){return _0x4487ea+_0x17c370;},'OSIIf':function(_0xc878f9,_0x396956){return _0xc878f9+_0x396956;},'YEtZS':_0x54cb8e(0x412)+'务\x20','CiloT':_0x3dfeb5(0x6a8)+_0xc19e5e(0x19f)+_0x38b2cc(0x5e4)+_0x3dfeb5(0x434)+_0x3dfeb5(0x272)+_0x3dfeb5(0x4d5)+_0x3dfeb5(0x695)+_0x2bbf14(0x624)+_0x38b2cc(0x4be)+_0xc19e5e(0x5e5)+_0x54cb8e(0x362)+_0x54cb8e(0x3c9)+_0x2bbf14(0x35c)+_0x38b2cc(0x433)+'果：','tXSmW':function(_0x12b87a,_0x170c9a){return _0x12b87a+_0x170c9a;},'dwkGB':_0x54cb8e(0x204),'dVgJn':function(_0x27634d,_0x38e26b){return _0x27634d(_0x38e26b);},'NdAVb':_0x38b2cc(0x746),'DDMoY':_0x38b2cc(0x1a0),'XSUFr':function(_0x573da4,_0x284d01){return _0x573da4+_0x284d01;},'nSuoV':_0x54cb8e(0x297)+_0x38b2cc(0x296)+_0x2bbf14(0x687)+_0x3dfeb5(0x76a)+_0x38b2cc(0x232)+'\x22>','STzWl':function(_0x2be4d1,_0x34a8a5,_0x237e1a){return _0x2be4d1(_0x34a8a5,_0x237e1a);},'Nddkv':_0x3dfeb5(0x1bb)+_0x38b2cc(0x5b3)+_0x54cb8e(0x14d)+_0x2bbf14(0x264)+_0x38b2cc(0x763)+_0x54cb8e(0x3af),'awVnb':function(_0x3c46d9,_0x402df5){return _0x3c46d9!=_0x402df5;},'hnKSj':_0x54cb8e(0x4d1),'BpWYP':function(_0x17e1f2,_0x12da51){return _0x17e1f2+_0x12da51;},'EJowM':function(_0x120938,_0x4f6e49){return _0x120938+_0x4f6e49;},'TAwbs':_0x2bbf14(0x459),'GzAhy':_0x2bbf14(0x323)+'果\x0a','YQJdG':_0x38b2cc(0x2ee),'BxjsC':_0x54cb8e(0x233),'lSyUm':function(_0x30d690,_0x4c0ad8){return _0x30d690>_0x4c0ad8;},'YtOVp':function(_0x17b097,_0x3d866e){return _0x17b097+_0x3d866e;},'TJlTo':function(_0x17de1f,_0x2008aa){return _0x17de1f+_0x2008aa;},'PSrRZ':_0x38b2cc(0x1bb)+_0x54cb8e(0x5b3)+_0x2bbf14(0x14d)+_0x38b2cc(0x4d3)+_0xc19e5e(0x653)+'q=','CpjzX':_0x38b2cc(0x1ee)+_0x2bbf14(0x6cf)+_0x3dfeb5(0x646)+_0x38b2cc(0x1ce)+_0x3dfeb5(0x2f0)+_0x2bbf14(0x4bb)+_0x3dfeb5(0x762)+_0xc19e5e(0x1fc)+_0x54cb8e(0x209)+_0x38b2cc(0x45f)+_0xc19e5e(0x608)+_0x54cb8e(0x141)+_0x3dfeb5(0x287)+_0x2bbf14(0x1f4)+'n'};if(_0x407bf0[_0x2bbf14(0x1e7)](lock_chat,-0x256a+0x1a35+0xb35))return;lock_chat=0x15ab*0x1+-0x846+0x2*-0x6b2,knowledge=document[_0x54cb8e(0x33e)+_0x3dfeb5(0x250)+_0x3dfeb5(0x748)](_0x407bf0[_0x54cb8e(0x5b2)])[_0x38b2cc(0x669)+_0x54cb8e(0x17a)][_0x2bbf14(0x234)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x3dfeb5(0x234)+'ce'](/<hr.*/gs,'')[_0xc19e5e(0x234)+'ce'](/<[^>]+>/g,'')[_0xc19e5e(0x234)+'ce'](/\n\n/g,'\x0a');if(_0x407bf0[_0x2bbf14(0x529)](knowledge[_0x54cb8e(0x36b)+'h'],-0x10bb+-0x17*-0x3+0x1206))knowledge[_0x54cb8e(0x551)](-0x2*0xbf0+-0x71d+-0xd*-0x281);knowledge+=_0x407bf0[_0x38b2cc(0x6a7)](_0x407bf0[_0x54cb8e(0x747)](_0x407bf0[_0x38b2cc(0x714)],original_search_query),_0x407bf0[_0xc19e5e(0x16c)]);let _0x59efd1=document[_0x38b2cc(0x33e)+_0x3dfeb5(0x250)+_0x54cb8e(0x748)](_0x407bf0[_0x3dfeb5(0x3df)])[_0x3dfeb5(0x6b5)];_0x3481b9&&(_0x407bf0[_0x38b2cc(0x1a6)](_0x407bf0[_0xc19e5e(0x267)],_0x407bf0[_0x2bbf14(0x289)])?(_0x59efd1=_0x3481b9[_0x3dfeb5(0x3ef)+_0x38b2cc(0x734)+'t'],_0x3481b9[_0xc19e5e(0x3a6)+'e'](),_0x407bf0[_0x2bbf14(0x550)](chatmore)):_0x58960d+=_0x36ab77[_0x38b2cc(0x6fa)+_0x3dfeb5(0x636)+_0x3dfeb5(0x1ad)](_0x299566[_0x29f8f3]));if(_0x407bf0[_0x3dfeb5(0x54f)](_0x59efd1[_0x38b2cc(0x36b)+'h'],-0x2*0x1+-0x1eae+0x1eb0)||_0x407bf0[_0x2bbf14(0x1cc)](_0x59efd1[_0x3dfeb5(0x36b)+'h'],0x94a*0x1+-0x82d*0x4+-0xbfb*-0x2))return;_0x407bf0[_0xc19e5e(0x5e0)](fetch,_0x407bf0[_0x3dfeb5(0x22e)](_0x407bf0[_0x3dfeb5(0x324)](_0x407bf0[_0xc19e5e(0x66a)],_0x407bf0[_0x38b2cc(0x6c7)](encodeURIComponent,_0x59efd1)),_0x407bf0[_0xc19e5e(0x195)]))[_0x2bbf14(0x4ad)](_0x2efa16=>_0x2efa16[_0x54cb8e(0x6c5)]())[_0x38b2cc(0x4ad)](_0x4d06b5=>{const _0x4ccd88=_0x3dfeb5,_0x22e63f=_0x38b2cc,_0x3e65ab=_0x54cb8e,_0x16becc=_0xc19e5e,_0x5c6a0a=_0x3dfeb5,_0x12c7fb={'TUHEB':function(_0x11141a,_0x2148da){const _0x163f1f=_0x54d4;return _0x407bf0[_0x163f1f(0x6c7)](_0x11141a,_0x2148da);},'UlPVM':function(_0x38a7e1,_0x325922){const _0x72b46f=_0x54d4;return _0x407bf0[_0x72b46f(0x1a6)](_0x38a7e1,_0x325922);},'kwZSB':_0x407bf0[_0x4ccd88(0x645)],'pBnie':_0x407bf0[_0x4ccd88(0x171)],'bgFvk':function(_0x4071f4,_0x332403){const _0x33d459=_0x22e63f;return _0x407bf0[_0x33d459(0x529)](_0x4071f4,_0x332403);},'EXdDB':function(_0x563641,_0x198067){const _0x24e2a7=_0x4ccd88;return _0x407bf0[_0x24e2a7(0x54f)](_0x563641,_0x198067);},'lDLPi':_0x407bf0[_0x3e65ab(0x5e2)],'sqjBN':function(_0x29a773,_0x485ead){const _0x4a590f=_0x3e65ab;return _0x407bf0[_0x4a590f(0x206)](_0x29a773,_0x485ead);},'wvGBP':_0x407bf0[_0x16becc(0x58e)],'ljuha':_0x407bf0[_0x22e63f(0x620)],'DOIQi':function(_0x496443,_0x58c118){const _0x505b36=_0x16becc;return _0x407bf0[_0x505b36(0x3fb)](_0x496443,_0x58c118);},'TgfTx':_0x407bf0[_0x5c6a0a(0x3df)],'HVPRp':function(_0x367968,_0x111bcd){const _0x37e18d=_0x4ccd88;return _0x407bf0[_0x37e18d(0x652)](_0x367968,_0x111bcd);},'paoOw':_0x407bf0[_0x4ccd88(0x691)],'vvJHl':function(_0xb917b8,_0x24c4d0){const _0x40f583=_0x22e63f;return _0x407bf0[_0x40f583(0x38a)](_0xb917b8,_0x24c4d0);},'IPkir':_0x407bf0[_0x22e63f(0x530)],'LmvUk':_0x407bf0[_0x4ccd88(0x44e)],'wepbS':function(_0x1f77f6,_0x56994f){const _0x5e2474=_0x5c6a0a;return _0x407bf0[_0x5e2474(0x4e6)](_0x1f77f6,_0x56994f);},'ZWrLM':_0x407bf0[_0x22e63f(0x201)],'JgyzW':_0x407bf0[_0x16becc(0x34a)],'VndtP':function(_0x1590d9,_0xca47){const _0x580186=_0x3e65ab;return _0x407bf0[_0x580186(0x1a6)](_0x1590d9,_0xca47);},'gzvPV':_0x407bf0[_0x22e63f(0x43a)],'pBxXZ':_0x407bf0[_0x5c6a0a(0x55f)],'kSivd':function(_0x2940d7,_0x400293){const _0x2bf9c3=_0x3e65ab;return _0x407bf0[_0x2bf9c3(0x2ab)](_0x2940d7,_0x400293);},'STLvQ':_0x407bf0[_0x16becc(0x55e)],'aLRpL':function(_0x50be4a,_0x205f2c,_0xc7c0f6){const _0x4b21e4=_0x5c6a0a;return _0x407bf0[_0x4b21e4(0x606)](_0x50be4a,_0x205f2c,_0xc7c0f6);},'QWQGp':function(_0x1dbb65,_0x168bb5){const _0x4b783e=_0x3e65ab;return _0x407bf0[_0x4b783e(0x26c)](_0x1dbb65,_0x168bb5);},'NJmzY':_0x407bf0[_0x22e63f(0x577)],'pFOXP':function(_0x443381,_0x38f07c){const _0x5319b5=_0x3e65ab;return _0x407bf0[_0x5319b5(0x1f1)](_0x443381,_0x38f07c);},'TNSnL':_0x407bf0[_0x22e63f(0x64e)],'Dquxr':_0x407bf0[_0x5c6a0a(0x787)],'ihzbS':_0x407bf0[_0x3e65ab(0x69c)],'IxYuz':function(_0x36f77,_0xb362fd){const _0x980c37=_0x3e65ab;return _0x407bf0[_0x980c37(0x23c)](_0x36f77,_0xb362fd);},'gUFVV':function(_0xb41c9f,_0x454ed4){const _0x5ccf95=_0x3e65ab;return _0x407bf0[_0x5ccf95(0x32a)](_0xb41c9f,_0x454ed4);},'PLiUQ':_0x407bf0[_0x22e63f(0x596)],'BFsjd':function(_0x3755f0,_0x289fe8){const _0x28cfa3=_0x5c6a0a;return _0x407bf0[_0x28cfa3(0x583)](_0x3755f0,_0x289fe8);},'iCedM':_0x407bf0[_0x22e63f(0x187)],'jZrjZ':_0x407bf0[_0x5c6a0a(0x2cc)],'ouFDH':function(_0x3d1daa,_0x1d6193){const _0x1ee27a=_0x5c6a0a;return _0x407bf0[_0x1ee27a(0x206)](_0x3d1daa,_0x1d6193);},'CJoLZ':_0x407bf0[_0x5c6a0a(0x3b7)]};if(_0x407bf0[_0x22e63f(0x4e6)](_0x407bf0[_0x5c6a0a(0x266)],_0x407bf0[_0x5c6a0a(0x6c9)]))_0x5a1e71=_0xcdc755[_0x16becc(0x21d)](_0x1a81bf)[_0x407bf0[_0x3e65ab(0x44e)]],_0x2e6b69='';else{prompt=JSON[_0x5c6a0a(0x21d)](_0x407bf0[_0x4ccd88(0x6c7)](atob,/<div id="prompt" style="display:none">(.*?)<\/div>/[_0x5c6a0a(0x221)](_0x4d06b5[_0x3e65ab(0x686)+_0x5c6a0a(0x39c)][0x1*-0xb23+-0x10e1+0x4*0x701][_0x22e63f(0x694)+'nt'])[-0x1fc0+0x1bbb+0x406])),prompt[_0x16becc(0x6b2)][_0x22e63f(0x137)+'t']=knowledge,prompt[_0x22e63f(0x6b2)][_0x3e65ab(0x188)+_0x4ccd88(0x5ae)+_0x16becc(0x34f)+'y']=0xe9b+0x14cf+-0x25*0xf5,prompt[_0x4ccd88(0x6b2)][_0x16becc(0x4b7)+_0x16becc(0x2ad)+'e']=0x1130+-0x232a+0x4e*0x3b+0.9;for(tmp_prompt in prompt[_0x3e65ab(0x61d)]){if(_0x407bf0[_0x4ccd88(0x14f)](_0x407bf0[_0x5c6a0a(0x358)],_0x407bf0[_0x4ccd88(0x358)])){if(_0x407bf0[_0x4ccd88(0x32a)](_0x407bf0[_0x16becc(0x1f1)](_0x407bf0[_0x3e65ab(0x1f1)](_0x407bf0[_0x22e63f(0x730)](_0x407bf0[_0x22e63f(0x6b9)](_0x407bf0[_0x5c6a0a(0x226)](prompt[_0x16becc(0x6b2)][_0x3e65ab(0x137)+'t'],tmp_prompt),'\x0a'),_0x407bf0[_0x5c6a0a(0x46a)]),_0x59efd1),_0x407bf0[_0x16becc(0x417)])[_0x22e63f(0x36b)+'h'],-0x1f7*-0xb+-0x1*0xfb+-0xe62))prompt[_0x16becc(0x6b2)][_0x4ccd88(0x137)+'t']+=_0x407bf0[_0x22e63f(0x4cb)](tmp_prompt,'\x0a');}else{const _0x5f5636={'hqHGf':IhiVtr[_0x4ccd88(0x43f)],'sOohD':IhiVtr[_0x22e63f(0x565)],'QewCU':function(_0x52a9d0,_0x3fb3f2){const _0x3b3a23=_0x3e65ab;return IhiVtr[_0x3b3a23(0x6c7)](_0x52a9d0,_0x3fb3f2);},'TNRAU':IhiVtr[_0x5c6a0a(0x72a)],'QoKxC':function(_0x49e681,_0x4ef451){const _0x59e4cb=_0x3e65ab;return IhiVtr[_0x59e4cb(0x6ed)](_0x49e681,_0x4ef451);},'BfMbx':IhiVtr[_0x22e63f(0x521)],'xKFcF':function(_0x50cd6e,_0x4ed1a9){const _0x440419=_0x5c6a0a;return IhiVtr[_0x440419(0x23c)](_0x50cd6e,_0x4ed1a9);},'Nyrtg':IhiVtr[_0x16becc(0x1a7)],'aQfKR':function(_0x3d6afa,_0x342804){const _0x202977=_0x4ccd88;return IhiVtr[_0x202977(0x6c7)](_0x3d6afa,_0x342804);},'WnTsh':function(_0x2ffaa){const _0x559397=_0x5c6a0a;return IhiVtr[_0x559397(0x550)](_0x2ffaa);}};IhiVtr[_0x22e63f(0x606)](_0x44925b,this,function(){const _0x43817e=_0x4ccd88,_0x4b581c=_0x4ccd88,_0x20fd66=_0x5c6a0a,_0x467d9f=_0x3e65ab,_0x3708ab=_0x3e65ab,_0x273839=new _0x5e4928(_0x5f5636[_0x43817e(0x379)]),_0x231b52=new _0x5230b2(_0x5f5636[_0x43817e(0x5b4)],'i'),_0x4617b3=_0x5f5636[_0x20fd66(0x605)](_0x4f5054,_0x5f5636[_0x20fd66(0x607)]);!_0x273839[_0x467d9f(0x3a2)](_0x5f5636[_0x20fd66(0x424)](_0x4617b3,_0x5f5636[_0x4b581c(0x1c7)]))||!_0x231b52[_0x467d9f(0x3a2)](_0x5f5636[_0x467d9f(0x633)](_0x4617b3,_0x5f5636[_0x3708ab(0x55a)]))?_0x5f5636[_0x3708ab(0x581)](_0x4617b3,'0'):_0x5f5636[_0x467d9f(0x2f6)](_0x5954d8);})();}}prompt[_0x22e63f(0x6b2)][_0x3e65ab(0x137)+'t']+=_0x407bf0[_0x22e63f(0x6b9)](_0x407bf0[_0x16becc(0x23c)](_0x407bf0[_0x4ccd88(0x46a)],_0x59efd1),_0x407bf0[_0x3e65ab(0x417)]),optionsweb={'method':_0x407bf0[_0x4ccd88(0x218)],'headers':headers,'body':_0x407bf0[_0x5c6a0a(0x6c7)](b64EncodeUnicode,JSON[_0x22e63f(0x1d3)+_0x4ccd88(0x5a2)](prompt[_0x16becc(0x6b2)]))},document[_0x3e65ab(0x33e)+_0x5c6a0a(0x250)+_0x16becc(0x748)](_0x407bf0[_0x4ccd88(0x55e)])[_0x22e63f(0x669)+_0x16becc(0x17a)]='',_0x407bf0[_0x5c6a0a(0x606)](markdownToHtml,_0x407bf0[_0x22e63f(0x5e0)](beautify,_0x59efd1),document[_0x4ccd88(0x33e)+_0x3e65ab(0x250)+_0x3e65ab(0x748)](_0x407bf0[_0x3e65ab(0x55e)])),chatTextRaw=_0x407bf0[_0x3e65ab(0x4cb)](_0x407bf0[_0x5c6a0a(0x730)](_0x407bf0[_0x16becc(0x1e1)],_0x59efd1),_0x407bf0[_0x4ccd88(0x17f)]),chatTemp='',text_offset=-(0x2149+-0x2354+0x20c),prev_chat=document[_0x3e65ab(0x42a)+_0x16becc(0x602)+_0x4ccd88(0x6de)](_0x407bf0[_0x16becc(0x577)])[_0x4ccd88(0x669)+_0x4ccd88(0x17a)],prev_chat=_0x407bf0[_0x16becc(0x78f)](_0x407bf0[_0x5c6a0a(0x4cb)](_0x407bf0[_0x22e63f(0x4cb)](prev_chat,_0x407bf0[_0x22e63f(0x5d1)]),document[_0x16becc(0x33e)+_0x4ccd88(0x250)+_0x16becc(0x748)](_0x407bf0[_0x22e63f(0x55e)])[_0x16becc(0x669)+_0x4ccd88(0x17a)]),_0x407bf0[_0x4ccd88(0x787)]),_0x407bf0[_0x4ccd88(0x49e)](fetch,_0x407bf0[_0x3e65ab(0x67f)],optionsweb)[_0x5c6a0a(0x4ad)](_0x43955a=>{const _0x4b61b3=_0x16becc,_0x176ecd=_0x5c6a0a,_0x146982=_0x16becc,_0x3c5e2c=_0x5c6a0a,_0x3c4611=_0x3e65ab,_0x57932c={'ldVQO':function(_0xd83483,_0x57e79a){const _0x5f3ecc=_0x54d4;return _0x12c7fb[_0x5f3ecc(0x41a)](_0xd83483,_0x57e79a);},'UMfMA':_0x12c7fb[_0x4b61b3(0x2a8)],'BPJlN':_0x12c7fb[_0x176ecd(0x75e)],'tkqgO':function(_0x260c45,_0x5224fa){const _0x47afb5=_0x4b61b3;return _0x12c7fb[_0x47afb5(0x76b)](_0x260c45,_0x5224fa);},'FIvBb':function(_0x3072c3,_0x9d1ef9){const _0x24d2c0=_0x176ecd;return _0x12c7fb[_0x24d2c0(0x20e)](_0x3072c3,_0x9d1ef9);},'IhqsJ':_0x12c7fb[_0x4b61b3(0x769)],'PXckP':function(_0x4160f8,_0x521c22){const _0x2e6699=_0x176ecd;return _0x12c7fb[_0x2e6699(0x43b)](_0x4160f8,_0x521c22);},'BPyFc':_0x12c7fb[_0x4b61b3(0x3a7)],'yenql':_0x12c7fb[_0x3c5e2c(0x189)],'ONFYx':function(_0x25e5b6,_0x16dc39){const _0x3f96cb=_0x4b61b3;return _0x12c7fb[_0x3f96cb(0x301)](_0x25e5b6,_0x16dc39);},'NgfUp':_0x12c7fb[_0x3c5e2c(0x2ba)],'SvjHT':function(_0x335887,_0x2d0542){const _0x9dec67=_0x3c4611;return _0x12c7fb[_0x9dec67(0x592)](_0x335887,_0x2d0542);},'riqjn':_0x12c7fb[_0x176ecd(0x380)],'AsLWt':function(_0x55a9ae,_0x441e40){const _0x3d84fb=_0x176ecd;return _0x12c7fb[_0x3d84fb(0x385)](_0x55a9ae,_0x441e40);},'VlRNP':_0x12c7fb[_0x176ecd(0x47c)],'Bvzoz':function(_0x54136d,_0x51ea77){const _0x2cb13b=_0x3c4611;return _0x12c7fb[_0x2cb13b(0x301)](_0x54136d,_0x51ea77);},'hWLUl':_0x12c7fb[_0x146982(0x4e2)],'ZqcFP':function(_0x1904d,_0x4e9dfa){const _0x1f0851=_0x4b61b3;return _0x12c7fb[_0x1f0851(0x2f7)](_0x1904d,_0x4e9dfa);},'UknyA':_0x12c7fb[_0x3c4611(0x528)],'DOuuV':_0x12c7fb[_0x4b61b3(0x2d8)],'iGMDs':function(_0x30b0d8,_0x57f9c4){const _0x1c0cc3=_0x3c4611;return _0x12c7fb[_0x1c0cc3(0x61c)](_0x30b0d8,_0x57f9c4);},'FxTPD':_0x12c7fb[_0x146982(0x59a)],'cmFmc':function(_0x2c7d41,_0xf26238){const _0x24b356=_0x176ecd;return _0x12c7fb[_0x24b356(0x76b)](_0x2c7d41,_0xf26238);},'xfJwi':function(_0xa09714,_0x4872b3){const _0x48d10e=_0x146982;return _0x12c7fb[_0x48d10e(0x2f7)](_0xa09714,_0x4872b3);},'GdUgo':_0x12c7fb[_0x176ecd(0x4a2)],'bwHqg':function(_0xff0519,_0x45bc71){const _0x1aa987=_0x146982;return _0x12c7fb[_0x1aa987(0x31f)](_0xff0519,_0x45bc71);},'goKkq':_0x12c7fb[_0x4b61b3(0x1f0)],'Bhnms':function(_0xa0f0c2,_0x282f31,_0x102427){const _0x1f43c1=_0x176ecd;return _0x12c7fb[_0x1f43c1(0x639)](_0xa0f0c2,_0x282f31,_0x102427);},'VEvHw':function(_0x210098,_0x31f0b0){const _0x275bcb=_0x176ecd;return _0x12c7fb[_0x275bcb(0x774)](_0x210098,_0x31f0b0);},'gzMpc':_0x12c7fb[_0x3c4611(0x47f)],'uQCbE':function(_0x827997,_0x713184){const _0x3a8ee1=_0x4b61b3;return _0x12c7fb[_0x3a8ee1(0x301)](_0x827997,_0x713184);},'UvoTG':function(_0x48b2cb,_0x30a497){const _0xb254fd=_0x3c4611;return _0x12c7fb[_0xb254fd(0x176)](_0x48b2cb,_0x30a497);},'EtNxn':_0x12c7fb[_0x3c5e2c(0x58a)],'WyyAs':_0x12c7fb[_0x3c4611(0x40a)],'jghNK':_0x12c7fb[_0x3c4611(0x47d)],'hHzAN':function(_0x5aa7ae,_0x55533f){const _0x528569=_0x176ecd;return _0x12c7fb[_0x528569(0x26a)](_0x5aa7ae,_0x55533f);},'aRgSc':function(_0x2d67b8,_0x1ff3a9){const _0x2d44e2=_0x3c4611;return _0x12c7fb[_0x2d44e2(0x49c)](_0x2d67b8,_0x1ff3a9);},'eaaTr':_0x12c7fb[_0x3c5e2c(0x1b6)],'otzob':function(_0x3f2473,_0x128038){const _0x55978f=_0x3c5e2c;return _0x12c7fb[_0x55978f(0x744)](_0x3f2473,_0x128038);},'kwosu':_0x12c7fb[_0x3c4611(0x6e9)],'OSIIL':_0x12c7fb[_0x146982(0x5f3)]};if(_0x12c7fb[_0x146982(0x5b5)](_0x12c7fb[_0x3c5e2c(0x490)],_0x12c7fb[_0x3c5e2c(0x490)]))oxhwSV[_0x3c4611(0x1c9)](_0x35ddd4,'0');else{const _0x29dd40=_0x43955a[_0x3c5e2c(0x74b)][_0x176ecd(0x29b)+_0x176ecd(0x785)]();let _0x39d553='',_0x30c96d='';_0x29dd40[_0x146982(0x61a)]()[_0x176ecd(0x4ad)](function _0x44df4f({done:_0x374ed5,value:_0x195c3c}){const _0x45fa34=_0x4b61b3,_0x1f92a2=_0x4b61b3,_0x9e06b=_0x176ecd,_0x3a8061=_0x176ecd,_0x340556=_0x176ecd,_0x309714={'QnyCF':_0x57932c[_0x45fa34(0x580)],'fDSiB':_0x57932c[_0x1f92a2(0x3e6)],'ZTTsF':function(_0x1e4913,_0x3ab832){const _0x1d3d1f=_0x45fa34;return _0x57932c[_0x1d3d1f(0x6b8)](_0x1e4913,_0x3ab832);},'xodgf':function(_0x230a57,_0x557229){const _0x4c7f81=_0x1f92a2;return _0x57932c[_0x4c7f81(0x67d)](_0x230a57,_0x557229);},'oHzcA':_0x57932c[_0x9e06b(0x381)]};if(_0x57932c[_0x45fa34(0x12f)](_0x57932c[_0x340556(0x563)],_0x57932c[_0x3a8061(0x563)]))_0x5d6e38[_0x340556(0x228)](_0x309714[_0x3a8061(0x579)],_0x2d59eb);else{if(_0x374ed5)return;const _0xf55c44=new TextDecoder(_0x57932c[_0x9e06b(0x590)])[_0x340556(0x509)+'e'](_0x195c3c);return _0xf55c44[_0x3a8061(0x4f6)]()[_0x1f92a2(0x764)]('\x0a')[_0x45fa34(0x340)+'ch'](function(_0x403770){const _0x33de3c=_0x1f92a2,_0x5e246d=_0x45fa34,_0x32d602=_0x340556,_0x55aa03=_0x9e06b,_0x58a6e3=_0x3a8061;if(_0x57932c[_0x33de3c(0x12c)](_0x57932c[_0x33de3c(0x25e)],_0x57932c[_0x5e246d(0x170)])){if(_0x57932c[_0x32d602(0x1d6)](_0x403770[_0x55aa03(0x36b)+'h'],-0x9ff+0x11ae*-0x2+0x2d61))_0x39d553=_0x403770[_0x55aa03(0x551)](0x599*0x5+0x24d9+-0x2068*0x2);if(_0x57932c[_0x55aa03(0x200)](_0x39d553,_0x57932c[_0x5e246d(0x1f6)])){if(_0x57932c[_0x32d602(0x2f1)](_0x57932c[_0x58a6e3(0x13a)],_0x57932c[_0x58a6e3(0x47a)])){word_last+=_0x57932c[_0x58a6e3(0x50b)](chatTextRaw,chatTemp),lock_chat=0x1740+0x3*0x405+-0xbc5*0x3,document[_0x5e246d(0x33e)+_0x33de3c(0x250)+_0x55aa03(0x748)](_0x57932c[_0x5e246d(0x554)])[_0x5e246d(0x6b5)]='';return;}else _0x353939=_0x3f7ce8[_0x55aa03(0x21d)](_0x5a96fa)[_0x309714[_0x58a6e3(0x2d6)]],_0x90a5c2='';}let _0x5f8fe2;try{if(_0x57932c[_0x5e246d(0x663)](_0x57932c[_0x32d602(0x698)],_0x57932c[_0x32d602(0x698)]))try{_0x57932c[_0x58a6e3(0x6a4)](_0x57932c[_0x58a6e3(0x4a6)],_0x57932c[_0x5e246d(0x4a6)])?_0x25fc2e+=_0x15fc7b:(_0x5f8fe2=JSON[_0x5e246d(0x21d)](_0x57932c[_0x33de3c(0x66d)](_0x30c96d,_0x39d553))[_0x57932c[_0x33de3c(0x3e6)]],_0x30c96d='');}catch(_0x290ec0){_0x57932c[_0x33de3c(0x5a8)](_0x57932c[_0x33de3c(0x472)],_0x57932c[_0x55aa03(0x6ca)])?_0x2dcaf2[_0x33de3c(0x228)](_0x309714[_0x55aa03(0x579)],_0x1e35f7):(_0x5f8fe2=JSON[_0x55aa03(0x21d)](_0x39d553)[_0x57932c[_0x5e246d(0x3e6)]],_0x30c96d='');}else _0x282ddd=_0xf3f7f7[_0x5e246d(0x21d)](_0x309714[_0x5e246d(0x5f4)](_0x55717b,_0x9328f9))[_0x309714[_0x58a6e3(0x2d6)]],_0x1e5458='';}catch(_0x395e82){if(_0x57932c[_0x58a6e3(0x144)](_0x57932c[_0x33de3c(0x166)],_0x57932c[_0x33de3c(0x166)]))try{var _0x220275=new _0x3b1141(_0x5bf9f5),_0x50f3ed='';for(var _0x12ac46=-0xd*0x286+-0x8ad*-0x3+0x1*0x6c7;_0x309714[_0x33de3c(0x56e)](_0x12ac46,_0x220275[_0x32d602(0x74c)+_0x32d602(0x217)]);_0x12ac46++){_0x50f3ed+=_0x24ddcd[_0x58a6e3(0x6fa)+_0x5e246d(0x636)+_0x32d602(0x1ad)](_0x220275[_0x12ac46]);}return _0x50f3ed;}catch(_0x484aff){}else _0x30c96d+=_0x39d553;}if(_0x5f8fe2&&_0x57932c[_0x32d602(0x1d6)](_0x5f8fe2[_0x33de3c(0x36b)+'h'],0xc9f+-0x54c+-0x753)&&_0x57932c[_0x32d602(0x3dc)](_0x5f8fe2[0x2bb*-0x2+-0xbf9+0x1*0x116f][_0x33de3c(0x311)+_0x5e246d(0x2af)][_0x55aa03(0x754)+_0x33de3c(0x536)+'t'][-0x1db3+0x24fb+-0x4*0x1d2],text_offset)){if(_0x57932c[_0x58a6e3(0x5ea)](_0x57932c[_0x5e246d(0x164)],_0x57932c[_0x33de3c(0x164)]))chatTemp+=_0x5f8fe2[-0x1522+-0x3b*-0xf+0x1*0x11ad][_0x5e246d(0x6d5)],text_offset=_0x5f8fe2[0x1a0f+0x227e+0x142f*-0x3][_0x32d602(0x311)+_0x55aa03(0x2af)][_0x58a6e3(0x754)+_0x5e246d(0x536)+'t'][_0x57932c[_0x55aa03(0x642)](_0x5f8fe2[-0x26b7*0x1+0x4f*-0x71+0x4996][_0x33de3c(0x311)+_0x5e246d(0x2af)][_0x58a6e3(0x754)+_0x55aa03(0x536)+'t'][_0x32d602(0x36b)+'h'],0x2*-0x7d6+-0x186+-0x7*-0x275)];else return _0x226115[_0x55aa03(0x303)+_0x32d602(0x2ac)]()[_0x58a6e3(0x368)+'h'](AjzSsw[_0x5e246d(0x2f8)])[_0x5e246d(0x303)+_0x5e246d(0x2ac)]()[_0x5e246d(0x14c)+_0x5e246d(0x3b8)+'r'](_0x410f8e)[_0x33de3c(0x368)+'h'](AjzSsw[_0x33de3c(0x2f8)]);}chatTemp=chatTemp[_0x33de3c(0x234)+_0x5e246d(0x2ae)]('\x0a\x0a','\x0a')[_0x33de3c(0x234)+_0x32d602(0x2ae)]('\x0a\x0a','\x0a'),document[_0x32d602(0x33e)+_0x5e246d(0x250)+_0x55aa03(0x748)](_0x57932c[_0x5e246d(0x564)])[_0x33de3c(0x669)+_0x55aa03(0x17a)]='',_0x57932c[_0x58a6e3(0x600)](markdownToHtml,_0x57932c[_0x33de3c(0x5be)](beautify,chatTemp),document[_0x58a6e3(0x33e)+_0x58a6e3(0x250)+_0x55aa03(0x748)](_0x57932c[_0x5e246d(0x564)])),document[_0x55aa03(0x42a)+_0x33de3c(0x602)+_0x33de3c(0x6de)](_0x57932c[_0x33de3c(0x742)])[_0x58a6e3(0x669)+_0x32d602(0x17a)]=_0x57932c[_0x5e246d(0x5cb)](_0x57932c[_0x58a6e3(0x4db)](_0x57932c[_0x5e246d(0x4db)](prev_chat,_0x57932c[_0x5e246d(0x74a)]),document[_0x33de3c(0x33e)+_0x58a6e3(0x250)+_0x33de3c(0x748)](_0x57932c[_0x5e246d(0x564)])[_0x55aa03(0x669)+_0x32d602(0x17a)]),_0x57932c[_0x32d602(0x6ac)]);}else{const _0x307158=_0x14fe17?function(){const _0x29f3be=_0x32d602;if(_0x1a09e1){const _0x4425d7=_0x1aced7[_0x29f3be(0x2b8)](_0x94aaca,arguments);return _0x4c15ea=null,_0x4425d7;}}:function(){};return _0x5ea4d7=![],_0x307158;}}),_0x29dd40[_0x1f92a2(0x61a)]()[_0x340556(0x4ad)](_0x44df4f);}});}})[_0x3e65ab(0x665)](_0x23d068=>{const _0x2de7cd=_0x16becc,_0x3a1bc2=_0x4ccd88,_0x31fb53=_0x3e65ab,_0x3dd58c=_0x22e63f,_0x39628e=_0x5c6a0a;_0x407bf0[_0x2de7cd(0x4e1)](_0x407bf0[_0x3a1bc2(0x586)],_0x407bf0[_0x31fb53(0x586)])?(_0x2af965+=_0x4df2cd[0x114+-0x12*0x122+-0x135*-0x10][_0x3dd58c(0x6d5)],_0x4989a3=_0x226638[0x1e43+0x1074+-0x2eb7][_0x3dd58c(0x311)+_0x2de7cd(0x2af)][_0x2de7cd(0x754)+_0x3a1bc2(0x536)+'t'][_0x12c7fb[_0x3a1bc2(0x31f)](_0x1662d0[0x16a6*0x1+0xfd*-0xe+-0x8d0][_0x2de7cd(0x311)+_0x39628e(0x2af)][_0x3dd58c(0x754)+_0x3a1bc2(0x536)+'t'][_0x2de7cd(0x36b)+'h'],0xafd*-0x2+0x1b29+-0x52e)]):console[_0x3dd58c(0x228)](_0x407bf0[_0x3dd58c(0x69c)],_0x23d068);});}});}function send_chat(_0x57e168){const _0x3fad7b=_0x476ffd,_0x2d951a=_0x3dd906,_0x538709=_0x3aedc2,_0x1d816b=_0x3aedc2,_0x2e8fe6=_0x3dd906,_0x325acf={'tTifY':function(_0x1a5f7e,_0xc0d0e0){return _0x1a5f7e<_0xc0d0e0;},'Titjn':function(_0x3098ce,_0x18c3d3){return _0x3098ce(_0x18c3d3);},'UbWcR':_0x3fad7b(0x562)+_0x2d951a(0x5ad),'GhsiT':_0x2d951a(0x4d1)+_0x538709(0x66f),'qvCPr':function(_0x30b0ab,_0x231bcc){return _0x30b0ab+_0x231bcc;},'XIGSN':_0x1d816b(0x756)+_0x2d951a(0x6f0)+_0x2d951a(0x71f)+_0x1d816b(0x1b8)+_0x538709(0x623)+_0x2e8fe6(0x53d)+_0x1d816b(0x45a)+_0x1d816b(0x534)+_0x1d816b(0x76d)+_0x2d951a(0x477)+_0x538709(0x305),'bdoke':function(_0x5f55a5,_0x335fbc){return _0x5f55a5(_0x335fbc);},'aSbFZ':_0x3fad7b(0x5de)+_0x538709(0x4ac),'oWauu':_0x2d951a(0x1bb)+_0x538709(0x1e8)+'l','nxFjA':_0x538709(0x1bb)+_0x538709(0x3f9),'wbMrN':function(_0x3b63ca,_0x548d40){return _0x3b63ca(_0x548d40);},'OuyUr':_0x2d951a(0x3f9),'HzYpV':function(_0x4e1581,_0x1eb831){return _0x4e1581!==_0x1eb831;},'zQgxt':_0x1d816b(0x1fb),'vHzqQ':function(_0xf579f8,_0x4a1aed){return _0xf579f8>_0x4a1aed;},'aUZrf':function(_0x7eb757,_0x5999af){return _0x7eb757==_0x5999af;},'bzWfY':_0x2e8fe6(0x212)+']','qaHjO':function(_0xe8f05e,_0x412870){return _0xe8f05e!==_0x412870;},'dpwtX':_0x2d951a(0x3c0),'HUpqE':_0x538709(0x4d1)+_0x538709(0x31a)+'t','cTpwB':_0x2d951a(0x5a9),'liPOE':_0x538709(0x145),'hTJmi':_0x2d951a(0x514),'jgKEO':function(_0x246bb4,_0x3a31cc){return _0x246bb4+_0x3a31cc;},'tDytA':_0x1d816b(0x6e8)+'es','WvYto':function(_0x4f4e55,_0x5aa576){return _0x4f4e55===_0x5aa576;},'yvmGX':_0x538709(0x6e4),'wunZD':_0x1d816b(0x2e8),'Duorh':_0x538709(0x4f8),'IqIqu':_0x3fad7b(0x407),'Kbqdn':_0x538709(0x27b),'aCRfz':_0x538709(0x767),'XfilE':function(_0x3b2478,_0x4cc4ff){return _0x3b2478-_0x4cc4ff;},'ojzkn':_0x2e8fe6(0x394)+'pt','ebXfa':function(_0x3a8c30,_0x678fdc,_0x2dc27e){return _0x3a8c30(_0x678fdc,_0x2dc27e);},'Kcovv':_0x2d951a(0x6f9),'gfzHX':function(_0x2c8995,_0x272bbf){return _0x2c8995+_0x272bbf;},'GChvq':_0x1d816b(0x297)+_0x2e8fe6(0x296)+_0x2e8fe6(0x687)+_0x1d816b(0x18b)+_0x2e8fe6(0x3aa),'VRiiA':_0x3fad7b(0x4ce)+'>','TYLyM':function(_0x3309ba,_0x477f96){return _0x3309ba<_0x477f96;},'EqtVg':function(_0x4b0370,_0x286f11){return _0x4b0370+_0x286f11;},'Wvzus':_0x1d816b(0x412)+'务\x20','HEFWd':_0x3fad7b(0x6a8)+_0x1d816b(0x19f)+_0x3fad7b(0x5e4)+_0x3fad7b(0x434)+_0x1d816b(0x272)+_0x538709(0x4d5)+_0x2e8fe6(0x695)+_0x3fad7b(0x624)+_0x2e8fe6(0x4be)+_0x2e8fe6(0x5e5)+_0x2e8fe6(0x362)+_0x2d951a(0x3c9)+_0x2e8fe6(0x35c)+_0x3fad7b(0x433)+'果：','NsHva':function(_0x548dfa,_0x245b6a){return _0x548dfa+_0x245b6a;},'lqGmG':_0x3fad7b(0x28d),'cABDn':_0x538709(0x5c9),'tMFpa':function(_0x5a95a1,_0x214ce8){return _0x5a95a1>=_0x214ce8;},'IMoeb':_0x1d816b(0x216),'FEAhU':_0x538709(0x133)+_0x3fad7b(0x6bb)+'rl','alLhJ':function(_0x3bfc7a,_0x4535d8){return _0x3bfc7a(_0x4535d8);},'xcYHm':function(_0x5d500a,_0x60abab){return _0x5d500a+_0x60abab;},'hgzwG':_0x2d951a(0x5bf)+'l','fytlc':function(_0x514993,_0x31252c){return _0x514993(_0x31252c);},'DBzqG':_0x3fad7b(0x29d)+_0x2e8fe6(0x3e3)+_0x2d951a(0x134),'vOFsj':_0x3fad7b(0x713),'JHjsS':function(_0x3642f8,_0x39daad){return _0x3642f8+_0x39daad;},'EYsUa':function(_0x258097,_0x1bdc53){return _0x258097(_0x1bdc53);},'KpSHm':_0x3fad7b(0x508),'RrgCm':_0x3fad7b(0x23a),'TosSG':_0x3fad7b(0x789),'snpMS':function(_0x18fe9d,_0x1e6b39){return _0x18fe9d<_0x1e6b39;},'dCTsH':function(_0x16ff77,_0x33f78b){return _0x16ff77!==_0x33f78b;},'eqLwb':_0x3fad7b(0x5cf),'JRHAt':_0x1d816b(0x5b9)+':','cMGZj':function(_0x164a64,_0x38c978){return _0x164a64===_0x38c978;},'USrKr':_0x538709(0x330),'xlRnY':_0x3fad7b(0x752),'pZUZI':function(_0x5280a2,_0x2c3974){return _0x5280a2>_0x2c3974;},'TzWZA':_0x2e8fe6(0x6df),'jMDjk':_0x3fad7b(0x5d9),'yWWsO':_0x3fad7b(0x423),'LDxTm':_0x3fad7b(0x699),'BQScD':_0x3fad7b(0x1a4),'hFKKj':_0x1d816b(0x5dd),'ZJrUZ':_0x3fad7b(0x6d4),'ZUOES':_0x2d951a(0x1fe),'MJGAY':_0x3fad7b(0x5df),'NqSwb':_0x538709(0x707),'ibaHC':_0x2d951a(0x24d),'oFZJG':_0x1d816b(0x57f),'aMUAp':_0x3fad7b(0x662),'NWaLh':_0x3fad7b(0x54a),'XGFvc':function(_0x10ec81,_0x2cf663){return _0x10ec81(_0x2cf663);},'QIRQU':function(_0x1d64e0,_0x37db97){return _0x1d64e0!=_0x37db97;},'mtJRD':function(_0x501884,_0x3b738b){return _0x501884+_0x3b738b;},'HmbQt':function(_0x1e30ec,_0x23bf66){return _0x1e30ec+_0x23bf66;},'CzDAW':_0x2e8fe6(0x4d1),'xlSln':_0x538709(0x3bf)+_0x2d951a(0x62f),'krFvE':_0x2d951a(0x323)+'果\x0a','HQYxC':function(_0x5512c0,_0x204fad){return _0x5512c0+_0x204fad;},'RBTFe':function(_0x1e64c2,_0x43f397){return _0x1e64c2+_0x43f397;},'rqJOE':function(_0x9f0fe2,_0x327e72){return _0x9f0fe2+_0x327e72;},'IWImX':function(_0x2b4c91,_0x5e8d3d){return _0x2b4c91+_0x5e8d3d;},'lvkZN':_0x1d816b(0x35d)+_0x3fad7b(0x5d5)+_0x2e8fe6(0x755)+_0x538709(0x67b)+_0x1d816b(0x6be)+_0x2d951a(0x644)+_0x3fad7b(0x359)+'\x0a','ERceC':_0x538709(0x710),'NEbIg':_0x2e8fe6(0x6fe),'KDYxe':_0x2d951a(0x426)+_0x1d816b(0x5fd)+_0x538709(0x65d),'ORJKb':_0x2d951a(0x204),'rBMNO':function(_0x399eb3,_0x4484ed){return _0x399eb3(_0x4484ed);},'bChSo':function(_0x44cf61,_0x1412d1){return _0x44cf61(_0x1412d1);},'EyujH':function(_0x2b80ea,_0x13455d){return _0x2b80ea+_0x13455d;},'dDITW':function(_0x21f1df,_0x406a97){return _0x21f1df+_0x406a97;},'szmOc':_0x2e8fe6(0x746),'euYau':_0x2d951a(0x1a0),'gstjn':function(_0x25c50c,_0x4d75a5){return _0x25c50c+_0x4d75a5;},'MrRLF':function(_0x1d2013,_0x3eb499){return _0x1d2013+_0x3eb499;},'qBYtM':_0x3fad7b(0x297)+_0x2e8fe6(0x296)+_0x1d816b(0x687)+_0x3fad7b(0x76a)+_0x3fad7b(0x232)+'\x22>','OEdNz':_0x2d951a(0x1bb)+_0x538709(0x5b3)+_0x538709(0x14d)+_0x1d816b(0x264)+_0x2d951a(0x763)+_0x3fad7b(0x3af)};let _0x4a6dde=document[_0x2e8fe6(0x33e)+_0x1d816b(0x250)+_0x2e8fe6(0x748)](_0x325acf[_0x1d816b(0x2ed)])[_0x2d951a(0x6b5)];if(_0x57e168){if(_0x325acf[_0x538709(0x22b)](_0x325acf[_0x2d951a(0x28f)],_0x325acf[_0x3fad7b(0x341)])){var _0x26230a=new _0x2b2dd4(_0x92ca23[_0x538709(0x36b)+'h']),_0x1d35f4=new _0x73cf70(_0x26230a);for(var _0x321504=0x1*-0x39d+-0x1eee+0xef*0x25,_0x2bae13=_0x2248e1[_0x2d951a(0x36b)+'h'];_0x325acf[_0x1d816b(0x15a)](_0x321504,_0x2bae13);_0x321504++){_0x1d35f4[_0x321504]=_0x102284[_0x3fad7b(0x5e6)+_0x538709(0x729)](_0x321504);}return _0x26230a;}else _0x4a6dde=_0x57e168[_0x2e8fe6(0x3ef)+_0x1d816b(0x734)+'t'],_0x57e168[_0x1d816b(0x3a6)+'e']();}if(_0x325acf[_0x1d816b(0x345)](_0x4a6dde[_0x2e8fe6(0x36b)+'h'],-0x1dd1*-0x1+-0x1666+-0x76b)||_0x325acf[_0x2e8fe6(0x572)](_0x4a6dde[_0x538709(0x36b)+'h'],-0x1*-0x33f+0xb*0x224+-0x1a3f))return;if(_0x325acf[_0x1d816b(0x3da)](word_last[_0x2e8fe6(0x36b)+'h'],-0x2459*-0x1+0x819*-0x1+-0x1a4c))word_last[_0x1d816b(0x551)](0x4b*0x62+-0x9*-0xab+-0x20c5);if(_0x4a6dde[_0x538709(0x68b)+_0x538709(0x30f)]('扮演')||_0x4a6dde[_0x2d951a(0x68b)+_0x2d951a(0x30f)]('模仿')||_0x4a6dde[_0x2e8fe6(0x68b)+_0x538709(0x30f)](_0x325acf[_0x2d951a(0x1a2)])||_0x4a6dde[_0x2d951a(0x68b)+_0x538709(0x30f)]('帮我')||_0x4a6dde[_0x538709(0x68b)+_0x2e8fe6(0x30f)](_0x325acf[_0x1d816b(0x32b)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x3fad7b(0x30f)](_0x325acf[_0x3fad7b(0x53f)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x538709(0x30f)]('请问')||_0x4a6dde[_0x538709(0x68b)+_0x538709(0x30f)]('请给')||_0x4a6dde[_0x538709(0x68b)+_0x538709(0x30f)]('请你')||_0x4a6dde[_0x3fad7b(0x68b)+_0x538709(0x30f)](_0x325acf[_0x2e8fe6(0x1a2)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x538709(0x30f)](_0x325acf[_0x2e8fe6(0x56f)])||_0x4a6dde[_0x3fad7b(0x68b)+_0x2d951a(0x30f)](_0x325acf[_0x3fad7b(0x690)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x538709(0x30f)](_0x325acf[_0x3fad7b(0x2ff)])||_0x4a6dde[_0x3fad7b(0x68b)+_0x1d816b(0x30f)](_0x325acf[_0x3fad7b(0x3a1)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x2d951a(0x30f)](_0x325acf[_0x2e8fe6(0x44c)])||_0x4a6dde[_0x1d816b(0x68b)+_0x3fad7b(0x30f)]('怎样')||_0x4a6dde[_0x1d816b(0x68b)+_0x3fad7b(0x30f)]('给我')||_0x4a6dde[_0x538709(0x68b)+_0x538709(0x30f)]('如何')||_0x4a6dde[_0x1d816b(0x68b)+_0x2e8fe6(0x30f)]('谁是')||_0x4a6dde[_0x2d951a(0x68b)+_0x538709(0x30f)]('查询')||_0x4a6dde[_0x2e8fe6(0x68b)+_0x1d816b(0x30f)](_0x325acf[_0x3fad7b(0x175)])||_0x4a6dde[_0x3fad7b(0x68b)+_0x538709(0x30f)](_0x325acf[_0x2d951a(0x5c3)])||_0x4a6dde[_0x2d951a(0x68b)+_0x538709(0x30f)](_0x325acf[_0x3fad7b(0x202)])||_0x4a6dde[_0x538709(0x68b)+_0x2d951a(0x30f)](_0x325acf[_0x538709(0x2dd)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x2e8fe6(0x30f)]('哪个')||_0x4a6dde[_0x1d816b(0x68b)+_0x3fad7b(0x30f)]('哪些')||_0x4a6dde[_0x538709(0x68b)+_0x2e8fe6(0x30f)](_0x325acf[_0x1d816b(0x495)])||_0x4a6dde[_0x1d816b(0x68b)+_0x3fad7b(0x30f)](_0x325acf[_0x3fad7b(0x68d)])||_0x4a6dde[_0x2e8fe6(0x68b)+_0x2e8fe6(0x30f)]('啥是')||_0x4a6dde[_0x2e8fe6(0x68b)+_0x1d816b(0x30f)]('为啥')||_0x4a6dde[_0x2d951a(0x68b)+_0x538709(0x30f)]('怎么'))return _0x325acf[_0x2d951a(0x198)](send_webchat,_0x57e168);if(_0x325acf[_0x2d951a(0x5c2)](lock_chat,0x2325+-0x2531+0x83*0x4))return;lock_chat=-0x124f+0x206*-0xc+0x2a98;const _0x194456=_0x325acf[_0x3fad7b(0x3d8)](_0x325acf[_0x538709(0x6b7)](_0x325acf[_0x2e8fe6(0x313)](document[_0x538709(0x33e)+_0x538709(0x250)+_0x2d951a(0x748)](_0x325acf[_0x538709(0x42e)])[_0x2e8fe6(0x669)+_0x2d951a(0x17a)][_0x2e8fe6(0x234)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x2d951a(0x234)+'ce'](/<hr.*/gs,'')[_0x3fad7b(0x234)+'ce'](/<[^>]+>/g,'')[_0x2e8fe6(0x234)+'ce'](/\n\n/g,'\x0a'),_0x325acf[_0x538709(0x648)]),search_queryquery),_0x325acf[_0x2d951a(0x38c)]);let _0x452f2d=_0x325acf[_0x1d816b(0x6ae)](_0x325acf[_0x1d816b(0x419)](_0x325acf[_0x2d951a(0x629)](_0x325acf[_0x538709(0x629)](_0x325acf[_0x2d951a(0x67e)](_0x325acf[_0x2d951a(0x66e)](_0x325acf[_0x538709(0x196)](_0x325acf[_0x2d951a(0x257)],_0x325acf[_0x2d951a(0x3f8)]),_0x194456),'\x0a'),word_last),_0x325acf[_0x1d816b(0x485)]),_0x4a6dde),_0x325acf[_0x2e8fe6(0x62d)]);const _0x1e6435={};_0x1e6435[_0x2d951a(0x137)+'t']=_0x452f2d,_0x1e6435[_0x2e8fe6(0x2bf)+_0x1d816b(0x4dc)]=0x3e8,_0x1e6435[_0x2e8fe6(0x4b7)+_0x2e8fe6(0x2ad)+'e']=0.9,_0x1e6435[_0x538709(0x39e)]=0x1,_0x1e6435[_0x538709(0x64c)+_0x1d816b(0x388)+_0x538709(0x618)+'ty']=0x0,_0x1e6435[_0x2e8fe6(0x188)+_0x538709(0x5ae)+_0x538709(0x34f)+'y']=0x1,_0x1e6435[_0x538709(0x61b)+'of']=0x1,_0x1e6435[_0x1d816b(0x3c4)]=![],_0x1e6435[_0x3fad7b(0x311)+_0x3fad7b(0x2af)]=0x0,_0x1e6435[_0x2e8fe6(0x310)+'m']=!![];const _0x271637={'method':_0x325acf[_0x538709(0x771)],'headers':headers,'body':_0x325acf[_0x2e8fe6(0x14b)](b64EncodeUnicode,JSON[_0x538709(0x1d3)+_0x1d816b(0x5a2)](_0x1e6435))};_0x4a6dde=_0x4a6dde[_0x2d951a(0x234)+_0x3fad7b(0x2ae)]('\x0a\x0a','\x0a')[_0x1d816b(0x234)+_0x2e8fe6(0x2ae)]('\x0a\x0a','\x0a'),document[_0x2e8fe6(0x33e)+_0x1d816b(0x250)+_0x2d951a(0x748)](_0x325acf[_0x2d951a(0x668)])[_0x2e8fe6(0x669)+_0x538709(0x17a)]='',_0x325acf[_0x2d951a(0x6d6)](markdownToHtml,_0x325acf[_0x2d951a(0x18c)](beautify,_0x4a6dde),document[_0x2e8fe6(0x33e)+_0x1d816b(0x250)+_0x2d951a(0x748)](_0x325acf[_0x538709(0x668)])),chatTextRaw=_0x325acf[_0x538709(0x1a8)](_0x325acf[_0x1d816b(0x701)](_0x325acf[_0x2e8fe6(0x547)],_0x4a6dde),_0x325acf[_0x2d951a(0x737)]),chatTemp='',text_offset=-(-0x10b1+-0x2*-0xaf1+-0x530),prev_chat=document[_0x1d816b(0x42a)+_0x2d951a(0x602)+_0x3fad7b(0x6de)](_0x325acf[_0x1d816b(0x651)])[_0x3fad7b(0x669)+_0x3fad7b(0x17a)],prev_chat=_0x325acf[_0x2e8fe6(0x67e)](_0x325acf[_0x3fad7b(0x664)](_0x325acf[_0x3fad7b(0x757)](prev_chat,_0x325acf[_0x538709(0x542)]),document[_0x2e8fe6(0x33e)+_0x1d816b(0x250)+_0x2e8fe6(0x748)](_0x325acf[_0x2d951a(0x668)])[_0x538709(0x669)+_0x2e8fe6(0x17a)]),_0x325acf[_0x3fad7b(0x39a)]),_0x325acf[_0x3fad7b(0x6d6)](fetch,_0x325acf[_0x2d951a(0x50f)],_0x271637)[_0x1d816b(0x4ad)](_0x395fe9=>{const _0x40114b=_0x2d951a,_0x58efe5=_0x538709,_0x3cb284=_0x3fad7b,_0x412251=_0x538709,_0xbf8b64=_0x2d951a,_0x29f501={'CFoVX':function(_0x4fe394,_0x2be145){const _0x3cc9dd=_0x54d4;return _0x325acf[_0x3cc9dd(0x3cc)](_0x4fe394,_0x2be145);},'XgGQK':_0x325acf[_0x40114b(0x1de)],'svZMM':_0x325acf[_0x58efe5(0x4f5)],'nGhrB':function(_0xdd262,_0x22a10f){const _0x3297fa=_0x58efe5;return _0x325acf[_0x3297fa(0x6a9)](_0xdd262,_0x22a10f);},'sXmrA':_0x325acf[_0x3cb284(0x17c)],'ytTnc':function(_0x4ef379,_0x2dd4ee){const _0x2af21e=_0x3cb284;return _0x325acf[_0x2af21e(0x5a5)](_0x4ef379,_0x2dd4ee);},'xhYFh':_0x325acf[_0x412251(0x4b3)],'bRfpj':_0x325acf[_0x40114b(0x49b)],'ShVEN':function(_0x214163,_0x1dd435){const _0x1540a0=_0xbf8b64;return _0x325acf[_0x1540a0(0x6a9)](_0x214163,_0x1dd435);},'mDGsS':_0x325acf[_0x40114b(0x2c6)],'ZuHCh':function(_0x1e628c,_0x5c16e6){const _0x5d14eb=_0x412251;return _0x325acf[_0x5d14eb(0x2c0)](_0x1e628c,_0x5c16e6);},'eaqYG':_0x325acf[_0x58efe5(0x69d)],'VmFrA':function(_0x4166dc,_0x35572a){const _0x67fd3=_0xbf8b64;return _0x325acf[_0x67fd3(0x2e1)](_0x4166dc,_0x35572a);},'HqiGg':_0x325acf[_0xbf8b64(0x12d)],'aVSqY':function(_0x18bb53,_0x5750e5){const _0x35dda4=_0xbf8b64;return _0x325acf[_0x35dda4(0x3da)](_0x18bb53,_0x5750e5);},'DCBbE':function(_0xfe268e,_0x50878b){const _0x265b54=_0x3cb284;return _0x325acf[_0x265b54(0x345)](_0xfe268e,_0x50878b);},'ekclC':_0x325acf[_0xbf8b64(0x386)],'eHjEt':function(_0x472f65,_0x40d5f8){const _0x340913=_0x412251;return _0x325acf[_0x340913(0x56d)](_0x472f65,_0x40d5f8);},'sIdkw':_0x325acf[_0x3cb284(0x468)],'GvdGF':_0x325acf[_0x58efe5(0x2ed)],'krXOj':_0x325acf[_0x40114b(0x655)],'wIyMY':function(_0xf81566,_0x640932){const _0x287860=_0x3cb284;return _0x325acf[_0x287860(0x56d)](_0xf81566,_0x640932);},'pVDvZ':_0x325acf[_0x412251(0x64b)],'ItejC':_0x325acf[_0x3cb284(0x6a0)],'zRfem':function(_0x51ef03,_0xc4a9f0){const _0x240b69=_0x58efe5;return _0x325acf[_0x240b69(0x629)](_0x51ef03,_0xc4a9f0);},'cBbRV':_0x325acf[_0x58efe5(0x558)],'qiSsm':function(_0x456b9d,_0x407fd1){const _0x4b652e=_0xbf8b64;return _0x325acf[_0x4b652e(0x781)](_0x456b9d,_0x407fd1);},'OOWmr':_0x325acf[_0x412251(0x593)],'cXbcl':_0x325acf[_0x40114b(0x6f5)],'oKtro':_0x325acf[_0x58efe5(0x2a2)],'ywmXm':_0x325acf[_0xbf8b64(0x784)],'XNtjU':function(_0x47dbb6,_0x7ba209){const _0x2e3cba=_0x412251;return _0x325acf[_0x2e3cba(0x3da)](_0x47dbb6,_0x7ba209);},'VxcYz':_0x325acf[_0x40114b(0x482)],'dcCBv':_0x325acf[_0x58efe5(0x5d6)],'jwvcx':function(_0x487eac,_0x37f303){const _0x3a8b1b=_0x40114b;return _0x325acf[_0x3a8b1b(0x163)](_0x487eac,_0x37f303);},'WMZRO':_0x325acf[_0x58efe5(0x668)],'FtjJJ':function(_0x4a9dc1,_0x313297,_0x16d915){const _0x1b5eb6=_0x58efe5;return _0x325acf[_0x1b5eb6(0x6d6)](_0x4a9dc1,_0x313297,_0x16d915);},'eXjiK':function(_0x3bedf8,_0x27d931){const _0x562b1a=_0xbf8b64;return _0x325acf[_0x562b1a(0x3cc)](_0x3bedf8,_0x27d931);},'FexnF':_0x325acf[_0x412251(0x651)],'iLciw':function(_0x3dd0a1,_0x33e909){const _0xe641a5=_0x3cb284;return _0x325acf[_0xe641a5(0x6ae)](_0x3dd0a1,_0x33e909);},'irXYh':_0x325acf[_0x58efe5(0x28a)],'sXMEi':_0x325acf[_0xbf8b64(0x39a)],'BchmX':function(_0x28cfc2,_0x210292){const _0x1fa646=_0x58efe5;return _0x325acf[_0x1fa646(0x182)](_0x28cfc2,_0x210292);},'ffYwg':function(_0x50e0b9,_0x39f074){const _0x37ee91=_0x412251;return _0x325acf[_0x37ee91(0x32e)](_0x50e0b9,_0x39f074);},'ebZXo':function(_0x4eec51,_0x35b21d){const _0x392244=_0xbf8b64;return _0x325acf[_0x392244(0x32e)](_0x4eec51,_0x35b21d);},'Sbbyd':_0x325acf[_0xbf8b64(0x194)],'LlggF':_0x325acf[_0x412251(0x6dc)],'Yjahc':function(_0x4cdb6b,_0x571f81){const _0x12adf9=_0x3cb284;return _0x325acf[_0x12adf9(0x622)](_0x4cdb6b,_0x571f81);},'ZzesX':function(_0x1b8991,_0x55a504){const _0x33eecc=_0xbf8b64;return _0x325acf[_0x33eecc(0x163)](_0x1b8991,_0x55a504);},'NKyZd':_0x325acf[_0xbf8b64(0x65f)],'YrHoc':_0x325acf[_0xbf8b64(0x1b3)],'gJgkU':function(_0x6a2c15,_0x4af903){const _0x4cc320=_0x412251;return _0x325acf[_0x4cc320(0x16f)](_0x6a2c15,_0x4af903);},'GhAqi':function(_0x5938b1,_0x5da6a8){const _0x1f4576=_0x3cb284;return _0x325acf[_0x1f4576(0x629)](_0x5938b1,_0x5da6a8);},'SOldM':_0x325acf[_0x58efe5(0x3ce)],'vPSYj':_0x325acf[_0x58efe5(0x1b2)],'pnwbO':function(_0xfe813f,_0x5621b2){const _0x1cf805=_0x3cb284;return _0x325acf[_0x1cf805(0x2ea)](_0xfe813f,_0x5621b2);},'XOifr':function(_0x333690,_0x2a6645){const _0x4e9a10=_0x412251;return _0x325acf[_0x4e9a10(0x3ab)](_0x333690,_0x2a6645);},'ASFBk':_0x325acf[_0x40114b(0x38d)],'JMTur':function(_0x2866c0,_0x322ac1){const _0x17dd6f=_0xbf8b64;return _0x325acf[_0x17dd6f(0x3ea)](_0x2866c0,_0x322ac1);},'kMIvt':_0x325acf[_0x58efe5(0x711)],'ocIMW':_0x325acf[_0x58efe5(0x244)],'sOJcT':function(_0x1ca4bf,_0x1ed471){const _0x477d27=_0xbf8b64;return _0x325acf[_0x477d27(0x3cc)](_0x1ca4bf,_0x1ed471);},'zGsAC':function(_0x5a3ef7,_0x50d1ac){const _0x1e2b71=_0x412251;return _0x325acf[_0x1e2b71(0x3d8)](_0x5a3ef7,_0x50d1ac);},'FcLtn':function(_0x42eedb,_0x3266f7){const _0x5cf547=_0x3cb284;return _0x325acf[_0x5cf547(0x6a5)](_0x42eedb,_0x3266f7);},'bAMpz':function(_0x17075c,_0x571b2f){const _0x3749e4=_0x40114b;return _0x325acf[_0x3749e4(0x3cc)](_0x17075c,_0x571b2f);},'lCORk':function(_0x3358a1,_0x1b7c22){const _0x7f2ab2=_0x40114b;return _0x325acf[_0x7f2ab2(0x781)](_0x3358a1,_0x1b7c22);},'hIBcW':_0x325acf[_0x3cb284(0x154)],'PhRJi':_0x325acf[_0xbf8b64(0x383)]};if(_0x325acf[_0x412251(0x56d)](_0x325acf[_0x40114b(0x16e)],_0x325acf[_0x58efe5(0x16e)])){_0x284b5a=_0x29f501[_0xbf8b64(0x3f3)](_0x1f5b7a,_0x264969);const _0x5543ad={};return _0x5543ad[_0x40114b(0x60c)]=_0x29f501[_0xbf8b64(0x353)],_0x38d03f[_0x58efe5(0x5ab)+'e'][_0x40114b(0x704)+'pt'](_0x5543ad,_0x329ecf,_0x404bc0);}else{const _0x28a0a1=_0x395fe9[_0xbf8b64(0x74b)][_0x58efe5(0x29b)+_0x40114b(0x785)]();let _0x38fabb='',_0x2e4574='';_0x28a0a1[_0x412251(0x61a)]()[_0x412251(0x4ad)](function _0x19a93b({done:_0x3c25d4,value:_0x22eaf8}){const _0x438cd8=_0x412251,_0x3606e5=_0x412251,_0x5f1dc9=_0x3cb284,_0x52e0eb=_0x3cb284,_0xed1cee=_0xbf8b64,_0x14b18d={'rvGJa':function(_0x1bf507,_0x46768b){const _0x35235f=_0x54d4;return _0x29f501[_0x35235f(0x71e)](_0x1bf507,_0x46768b);},'XOHHi':function(_0x2472ef,_0x1100d4){const _0x1eada3=_0x54d4;return _0x29f501[_0x1eada3(0x32c)](_0x2472ef,_0x1100d4);},'wrrYv':_0x29f501[_0x438cd8(0x61f)],'OekzQ':_0x29f501[_0x3606e5(0x327)],'IcKtr':_0x29f501[_0x438cd8(0x5bc)],'QCGue':function(_0x285913,_0x18bb94){const _0x11bbcf=_0x438cd8;return _0x29f501[_0x11bbcf(0x333)](_0x285913,_0x18bb94);},'UCkgY':function(_0x3ee6aa,_0x2ec6cf){const _0x546953=_0x5f1dc9;return _0x29f501[_0x546953(0x4d9)](_0x3ee6aa,_0x2ec6cf);},'sRkKZ':_0x29f501[_0x5f1dc9(0x73c)],'CygAw':function(_0x301d7d,_0x55b096){const _0x592c6e=_0x52e0eb;return _0x29f501[_0x592c6e(0x3f3)](_0x301d7d,_0x55b096);},'vCfkZ':function(_0x136c35,_0x4af990){const _0x198e86=_0x3606e5;return _0x29f501[_0x198e86(0x4d9)](_0x136c35,_0x4af990);},'fNplq':_0x29f501[_0x52e0eb(0x2d4)],'EAzkN':function(_0x4f1f28,_0x207403){const _0x21673d=_0x52e0eb;return _0x29f501[_0x21673d(0x308)](_0x4f1f28,_0x207403);},'GVUOR':function(_0x873995,_0x4b693b){const _0x45c2c4=_0x52e0eb;return _0x29f501[_0x45c2c4(0x3be)](_0x873995,_0x4b693b);},'KIuOg':_0x29f501[_0x5f1dc9(0x58d)],'iFYiO':function(_0x168782,_0x6876c7){const _0xa93fc9=_0x52e0eb;return _0x29f501[_0xa93fc9(0x3f3)](_0x168782,_0x6876c7);},'Ffbqp':function(_0x6d6446,_0x23fee8){const _0x397168=_0xed1cee;return _0x29f501[_0x397168(0x16d)](_0x6d6446,_0x23fee8);},'NtStP':function(_0x4f9245,_0x2b2aa9){const _0x3e4190=_0x52e0eb;return _0x29f501[_0x3e4190(0x153)](_0x4f9245,_0x2b2aa9);},'CeHEU':function(_0x78dff5,_0x177426){const _0x120bdf=_0x3606e5;return _0x29f501[_0x120bdf(0x4d9)](_0x78dff5,_0x177426);},'BBlqS':_0x29f501[_0x52e0eb(0x516)],'yQUBt':function(_0x1fe0d0,_0x24fd76){const _0x40af42=_0x3606e5;return _0x29f501[_0x40af42(0x4d9)](_0x1fe0d0,_0x24fd76);},'gkrPS':_0x29f501[_0xed1cee(0x2aa)],'JXOHR':function(_0x2e6085,_0x5d139a){const _0x40a019=_0xed1cee;return _0x29f501[_0x40a019(0x700)](_0x2e6085,_0x5d139a);},'UDGqg':function(_0x242932,_0x38b72e){const _0x389e83=_0x52e0eb;return _0x29f501[_0x389e83(0x4df)](_0x242932,_0x38b72e);},'bXOTk':function(_0x33e28a,_0x331d0a){const _0x46a293=_0x52e0eb;return _0x29f501[_0x46a293(0x40b)](_0x33e28a,_0x331d0a);},'UeoDZ':function(_0x4825d5,_0x1e3617){const _0x2ba73b=_0x3606e5;return _0x29f501[_0x2ba73b(0x308)](_0x4825d5,_0x1e3617);},'pzAaE':function(_0x565ccb,_0x540294){const _0x5dcfcf=_0x3606e5;return _0x29f501[_0x5dcfcf(0x333)](_0x565ccb,_0x540294);},'GumzQ':_0x29f501[_0x5f1dc9(0x6e5)],'CKmCB':function(_0x31bd0c,_0x576266){const _0x41d7cc=_0xed1cee;return _0x29f501[_0x41d7cc(0x6a3)](_0x31bd0c,_0x576266);},'PJVXz':_0x29f501[_0x52e0eb(0x4e7)],'LJRgX':function(_0x280394,_0x4ec664){const _0x7c0507=_0x5f1dc9;return _0x29f501[_0x7c0507(0x387)](_0x280394,_0x4ec664);},'eCbkJ':_0x29f501[_0x52e0eb(0x348)]};if(_0x29f501[_0x438cd8(0x227)](_0x29f501[_0x3606e5(0x47e)],_0x29f501[_0xed1cee(0x47e)])){if(_0x3c25d4)return;const _0x17ca9f=new TextDecoder(_0x29f501[_0xed1cee(0x6eb)])[_0x52e0eb(0x509)+'e'](_0x22eaf8);return _0x17ca9f[_0x3606e5(0x4f6)]()[_0x438cd8(0x764)]('\x0a')[_0x52e0eb(0x340)+'ch'](function(_0x1b7b6f){const _0x103a29=_0xed1cee,_0x1b8938=_0xed1cee,_0x79df1c=_0x438cd8,_0x30a9d5=_0x3606e5,_0x4f00c9=_0x52e0eb,_0x2fea99={'XniwT':_0x29f501[_0x103a29(0x338)],'uDuaM':function(_0x1d482e,_0x3db869){const _0x19bcdc=_0x103a29;return _0x29f501[_0x19bcdc(0x193)](_0x1d482e,_0x3db869);},'iIDND':_0x29f501[_0x103a29(0x190)],'iZCXC':function(_0x4c1be3,_0x928a5c){const _0x56b6e0=_0x1b8938;return _0x29f501[_0x56b6e0(0x6f6)](_0x4c1be3,_0x928a5c);},'fBrgc':_0x29f501[_0x1b8938(0x26f)],'OInzS':function(_0x264a5e,_0xb0e1e5){const _0x4f203c=_0x103a29;return _0x29f501[_0x4f203c(0x193)](_0x264a5e,_0xb0e1e5);},'YCcOR':_0x29f501[_0x1b8938(0x6e5)],'ZEPnr':function(_0x2233d8,_0x24f5e7){const _0x38b046=_0x30a9d5;return _0x29f501[_0x38b046(0x6e3)](_0x2233d8,_0x24f5e7);},'UQPJu':_0x29f501[_0x30a9d5(0x4e7)],'sGGPu':function(_0x373e20,_0x4ef1ed){const _0x59c297=_0x1b8938;return _0x29f501[_0x59c297(0x745)](_0x373e20,_0x4ef1ed);},'XhGwB':_0x29f501[_0x1b8938(0x348)],'LVuyu':function(_0x382c57,_0x4fd76f){const _0x4d1f3a=_0x30a9d5;return _0x29f501[_0x4d1f3a(0x6f6)](_0x382c57,_0x4fd76f);}};if(_0x29f501[_0x103a29(0x2d9)](_0x29f501[_0x4f00c9(0x5f2)],_0x29f501[_0x79df1c(0x5f2)]))_0x2f43cf+=_0x330034[-0x4b9*0x8+-0x3*-0x6ee+0x32*0x57][_0x4f00c9(0x6d5)],_0x5daa22=_0x8a4059[-0x1111*0x1+-0x1836+-0x1*-0x2947][_0x79df1c(0x311)+_0x4f00c9(0x2af)][_0x103a29(0x754)+_0x1b8938(0x536)+'t'][_0x14b18d[_0x79df1c(0x1bc)](_0x39c3ca[-0x5a2+0x1bd*0x7+-0x689*0x1][_0x79df1c(0x311)+_0x30a9d5(0x2af)][_0x30a9d5(0x754)+_0x4f00c9(0x536)+'t'][_0x30a9d5(0x36b)+'h'],-0x28d+-0x1*0x246d+0x26fb*0x1)];else{if(_0x29f501[_0x103a29(0x365)](_0x1b7b6f[_0x30a9d5(0x36b)+'h'],-0x9ef*-0x1+-0x112a+0x3*0x26b))_0x38fabb=_0x1b7b6f[_0x79df1c(0x551)](-0xeda*-0x2+-0xc49*0x1+-0x1*0x1165);if(_0x29f501[_0x4f00c9(0x540)](_0x38fabb,_0x29f501[_0x1b8938(0x78b)])){if(_0x29f501[_0x1b8938(0x342)](_0x29f501[_0x79df1c(0x286)],_0x29f501[_0x79df1c(0x286)]))try{_0x17be0f=_0x55dbff[_0x1b8938(0x21d)](_0x14b18d[_0x4f00c9(0x703)](_0x44317e,_0x7de7f5))[_0x14b18d[_0x79df1c(0x246)]],_0xd206a7='';}catch(_0x2dc65b){_0x1b6cc6=_0x565676[_0x4f00c9(0x21d)](_0x2a3f54)[_0x14b18d[_0x30a9d5(0x246)]],_0x398803='';}else{word_last+=_0x29f501[_0x79df1c(0x193)](chatTextRaw,chatTemp),lock_chat=0x17db+-0x679+-0xb2*0x19,document[_0x30a9d5(0x33e)+_0x30a9d5(0x250)+_0x1b8938(0x748)](_0x29f501[_0x4f00c9(0x34b)])[_0x103a29(0x6b5)]='';return;}}let _0x545fd3;try{if(_0x29f501[_0x4f00c9(0x342)](_0x29f501[_0x79df1c(0x556)],_0x29f501[_0x79df1c(0x556)])){const _0x21a550={'iPHGi':_0x2fea99[_0x30a9d5(0x3c5)],'KynGP':function(_0x10456d,_0x27a974){const _0x3feec1=_0x30a9d5;return _0x2fea99[_0x3feec1(0x4e3)](_0x10456d,_0x27a974);},'GJzMW':function(_0x320f48,_0x2ad6b4){const _0x4edae2=_0x1b8938;return _0x2fea99[_0x4edae2(0x4e3)](_0x320f48,_0x2ad6b4);},'flAMp':_0x2fea99[_0x4f00c9(0x4b0)],'fiWcc':function(_0x35ab0e,_0x4147b8){const _0x186821=_0x30a9d5;return _0x2fea99[_0x186821(0x2bb)](_0x35ab0e,_0x4147b8);},'FKNZS':_0x2fea99[_0x103a29(0x569)]};_0x387408[_0x4f00c9(0x21d)](_0x3d9703[_0x1b8938(0x6e8)+'es'][0x340+0xd9e+-0x22*0x7f][_0x79df1c(0x6d5)][_0x4f00c9(0x234)+_0x4f00c9(0x2ae)]('\x0a',''))[_0x79df1c(0x340)+'ch'](_0x1156c1=>{const _0x1bd10b=_0x4f00c9,_0x44b55a=_0x79df1c,_0x5d7059=_0x4f00c9,_0x48c47f=_0x1b8938,_0x30e4ad=_0x30a9d5;_0x53f145[_0x1bd10b(0x33e)+_0x1bd10b(0x250)+_0x5d7059(0x748)](_0x21a550[_0x1bd10b(0x573)])[_0x1bd10b(0x669)+_0x30e4ad(0x17a)]+=_0x21a550[_0x30e4ad(0x5aa)](_0x21a550[_0x5d7059(0x237)](_0x21a550[_0x30e4ad(0x173)],_0x21a550[_0x30e4ad(0x1c8)](_0x386f75,_0x1156c1)),_0x21a550[_0x1bd10b(0x533)]);});}else try{if(_0x29f501[_0x79df1c(0x5ca)](_0x29f501[_0x30a9d5(0x290)],_0x29f501[_0x30a9d5(0x76e)]))_0x545fd3=JSON[_0x79df1c(0x21d)](_0x29f501[_0x30a9d5(0x16d)](_0x2e4574,_0x38fabb))[_0x29f501[_0x1b8938(0x61f)]],_0x2e4574='';else{const _0x57f673=_0x4646cd[_0x4f00c9(0x2b8)](_0xb09e33,arguments);return _0x37f18a=null,_0x57f673;}}catch(_0x354fb0){_0x29f501[_0x79df1c(0x751)](_0x29f501[_0x79df1c(0x15b)],_0x29f501[_0x30a9d5(0x5f6)])?(_0x47c885=_0x190064[_0x79df1c(0x21d)](_0x2d91c4)[_0x14b18d[_0x4f00c9(0x246)]],_0x566bd4=''):(_0x545fd3=JSON[_0x79df1c(0x21d)](_0x38fabb)[_0x29f501[_0x103a29(0x61f)]],_0x2e4574='');}}catch(_0x4c1290){if(_0x29f501[_0x79df1c(0x5ca)](_0x29f501[_0x4f00c9(0x531)],_0x29f501[_0x30a9d5(0x211)]))_0x2e4574+=_0x38fabb;else{_0x4d664d=_0x3e8970[_0x30a9d5(0x234)+_0x4f00c9(0x2ae)]('（','(')[_0x103a29(0x234)+_0x79df1c(0x2ae)]('）',')')[_0x79df1c(0x234)+_0x1b8938(0x2ae)](',\x20',',')[_0x30a9d5(0x234)+_0x4f00c9(0x2ae)](_0x14b18d[_0x4f00c9(0x50c)],'')[_0x30a9d5(0x234)+_0x79df1c(0x2ae)](_0x14b18d[_0x4f00c9(0x29e)],'');for(let _0xd100ac=_0x52b9b5[_0x103a29(0x404)+_0x103a29(0x298)][_0x1b8938(0x36b)+'h'];_0x14b18d[_0x103a29(0x6a1)](_0xd100ac,-0x23ef*-0x1+-0x199a+-0xa55);--_0xd100ac){_0x405f77=_0x496f84[_0x4f00c9(0x234)+_0x79df1c(0x2ae)](_0x14b18d[_0x30a9d5(0x2b7)](_0x14b18d[_0x4f00c9(0x416)],_0x14b18d[_0x103a29(0x35a)](_0x292d98,_0xd100ac)),_0x14b18d[_0x1b8938(0x568)](_0x14b18d[_0x30a9d5(0x2dc)],_0x14b18d[_0x103a29(0x25d)](_0x4e8293,_0xd100ac))),_0x4ce9ce=_0x206285[_0x4f00c9(0x234)+_0x4f00c9(0x2ae)](_0x14b18d[_0x4f00c9(0x478)](_0x14b18d[_0x4f00c9(0x45b)],_0x14b18d[_0x30a9d5(0x68a)](_0x242746,_0xd100ac)),_0x14b18d[_0x103a29(0x147)](_0x14b18d[_0x103a29(0x2dc)],_0x14b18d[_0x30a9d5(0x739)](_0x3e8500,_0xd100ac))),_0x488921=_0x2c3d70[_0x79df1c(0x234)+_0x79df1c(0x2ae)](_0x14b18d[_0x4f00c9(0x449)](_0x14b18d[_0x30a9d5(0x248)],_0x14b18d[_0x1b8938(0x68a)](_0x18cf42,_0xd100ac)),_0x14b18d[_0x103a29(0x5ee)](_0x14b18d[_0x30a9d5(0x2dc)],_0x14b18d[_0x4f00c9(0x739)](_0x333c1b,_0xd100ac))),_0x16c890=_0x18e131[_0x1b8938(0x234)+_0x30a9d5(0x2ae)](_0x14b18d[_0x103a29(0x478)](_0x14b18d[_0x30a9d5(0x72d)],_0x14b18d[_0x4f00c9(0x716)](_0x2b732f,_0xd100ac)),_0x14b18d[_0x30a9d5(0x169)](_0x14b18d[_0x1b8938(0x2dc)],_0x14b18d[_0x30a9d5(0x4ca)](_0x495433,_0xd100ac)));}_0x3eccf0=_0x14b18d[_0x4f00c9(0x215)](_0x402ab3,_0x19d4b3);for(let _0x2a09a3=_0x3f4aa5[_0x103a29(0x404)+_0x4f00c9(0x298)][_0x1b8938(0x36b)+'h'];_0x14b18d[_0x1b8938(0x1d5)](_0x2a09a3,-0x1990+-0x1ab*0x6+0x2392);--_0x2a09a3){_0x1f4856=_0x1d95fc[_0x79df1c(0x234)+'ce'](_0x14b18d[_0x4f00c9(0x147)](_0x14b18d[_0x1b8938(0x328)],_0x14b18d[_0x79df1c(0x25d)](_0x4e6b0b,_0x2a09a3)),_0x258859[_0x79df1c(0x404)+_0x30a9d5(0x298)][_0x2a09a3]),_0x2fcf9a=_0xc6a4e6[_0x103a29(0x234)+'ce'](_0x14b18d[_0x4f00c9(0x162)](_0x14b18d[_0x30a9d5(0x431)],_0x14b18d[_0x1b8938(0x6f3)](_0x50e638,_0x2a09a3)),_0x17cac9[_0x103a29(0x404)+_0x103a29(0x298)][_0x2a09a3]),_0x51187c=_0x1044f0[_0x1b8938(0x234)+'ce'](_0x14b18d[_0x1b8938(0x169)](_0x14b18d[_0x79df1c(0x24a)],_0x14b18d[_0x4f00c9(0x215)](_0x356708,_0x2a09a3)),_0xc3ce81[_0x79df1c(0x404)+_0x4f00c9(0x298)][_0x2a09a3]);}return _0x309bc1;}}_0x545fd3&&_0x29f501[_0x4f00c9(0x60b)](_0x545fd3[_0x103a29(0x36b)+'h'],0x1aae+0x81*0x27+-0x1d*0x199)&&_0x29f501[_0x30a9d5(0x365)](_0x545fd3[-0x1ae4+0xff9+-0xd7*-0xd][_0x79df1c(0x311)+_0x4f00c9(0x2af)][_0x1b8938(0x754)+_0x79df1c(0x536)+'t'][0xeb2+0x14*0x153+-0xdba*0x3],text_offset)&&(_0x29f501[_0x4f00c9(0x2d9)](_0x29f501[_0x79df1c(0x75a)],_0x29f501[_0x1b8938(0x5fc)])?(chatTemp+=_0x545fd3[0x1a51+0xa5e+-0x1*0x24af][_0x79df1c(0x6d5)],text_offset=_0x545fd3[-0x250f+0x25bf*0x1+-0xb0][_0x103a29(0x311)+_0x103a29(0x2af)][_0x30a9d5(0x754)+_0x30a9d5(0x536)+'t'][_0x29f501[_0x4f00c9(0x3fc)](_0x545fd3[0x5*-0x392+-0x53*-0x17+0xa65][_0x4f00c9(0x311)+_0x30a9d5(0x2af)][_0x30a9d5(0x754)+_0x1b8938(0x536)+'t'][_0x103a29(0x36b)+'h'],-0x798+-0xacc+0x1265)]):(_0x143c87=_0xb6d5f8[_0x103a29(0x234)+'ce'](_0x2fea99[_0x30a9d5(0x3cb)](_0x2fea99[_0x4f00c9(0x544)],_0x2fea99[_0x4f00c9(0x2bb)](_0x20656b,_0x45004f)),_0x41df00[_0x79df1c(0x404)+_0x30a9d5(0x298)][_0x4c1b43]),_0x43e1c7=_0x425fe2[_0x4f00c9(0x234)+'ce'](_0x2fea99[_0x4f00c9(0x1d7)](_0x2fea99[_0x79df1c(0x64f)],_0x2fea99[_0x30a9d5(0x2ca)](_0x40d4c5,_0x445b38)),_0x2a3d58[_0x4f00c9(0x404)+_0x30a9d5(0x298)][_0x538e42]),_0x7f1e82=_0x2d22d5[_0x4f00c9(0x234)+'ce'](_0x2fea99[_0x79df1c(0x1d7)](_0x2fea99[_0x4f00c9(0x4ff)],_0x2fea99[_0x103a29(0x5ba)](_0x285e2a,_0x56fd8b)),_0x5a1223[_0x30a9d5(0x404)+_0x30a9d5(0x298)][_0x11529f]))),chatTemp=chatTemp[_0x30a9d5(0x234)+_0x30a9d5(0x2ae)]('\x0a\x0a','\x0a')[_0x4f00c9(0x234)+_0x1b8938(0x2ae)]('\x0a\x0a','\x0a'),document[_0x79df1c(0x33e)+_0x79df1c(0x250)+_0x4f00c9(0x748)](_0x29f501[_0x103a29(0x680)])[_0x1b8938(0x669)+_0x79df1c(0x17a)]='',_0x29f501[_0x4f00c9(0x621)](markdownToHtml,_0x29f501[_0x30a9d5(0x2b6)](beautify,chatTemp),document[_0x30a9d5(0x33e)+_0x1b8938(0x250)+_0x79df1c(0x748)](_0x29f501[_0x4f00c9(0x680)])),document[_0x1b8938(0x42a)+_0x103a29(0x602)+_0x79df1c(0x6de)](_0x29f501[_0x1b8938(0x567)])[_0x103a29(0x669)+_0x103a29(0x17a)]=_0x29f501[_0x1b8938(0x16d)](_0x29f501[_0x30a9d5(0x16d)](_0x29f501[_0x1b8938(0x511)](prev_chat,_0x29f501[_0x30a9d5(0x60e)]),document[_0x1b8938(0x33e)+_0x79df1c(0x250)+_0x30a9d5(0x748)](_0x29f501[_0x103a29(0x680)])[_0x1b8938(0x669)+_0x4f00c9(0x17a)]),_0x29f501[_0x4f00c9(0x34c)]);}}),_0x28a0a1[_0x3606e5(0x61a)]()[_0x438cd8(0x4ad)](_0x19a93b);}else{if(_0x29f501[_0x52e0eb(0x291)](_0x29f501[_0xed1cee(0x16d)](_0x29f501[_0x52e0eb(0x32c)](_0x29f501[_0xed1cee(0x6e3)](_0x29f501[_0x5f1dc9(0x6e3)](_0x29f501[_0xed1cee(0x6a3)](_0x2b6691[_0x5f1dc9(0x6b2)][_0x438cd8(0x137)+'t'],_0x2d4c7b),'\x0a'),_0x29f501[_0x52e0eb(0x314)]),_0x48ae80),_0x29f501[_0xed1cee(0x293)])[_0x5f1dc9(0x36b)+'h'],-0x1*-0x1763+-0x3*-0x60a+-0x2341))_0x56b142[_0x5f1dc9(0x6b2)][_0x3606e5(0x137)+'t']+=_0x29f501[_0x52e0eb(0x36e)](_0x1bede1,'\x0a');}});}})[_0x2e8fe6(0x665)](_0x3492a3=>{const _0x575c6b=_0x2d951a,_0x3d7580=_0x2d951a,_0x7810e6=_0x2e8fe6,_0x3c3a2b=_0x2d951a,_0x10dec0=_0x538709,_0x74bcf2={'lYdJG':function(_0x1861ba,_0x4e376e){const _0x1abde6=_0x54d4;return _0x325acf[_0x1abde6(0x526)](_0x1861ba,_0x4e376e);}};if(_0x325acf[_0x575c6b(0x48d)](_0x325acf[_0x3d7580(0x172)],_0x325acf[_0x3d7580(0x172)])){var _0x10fb50=new _0xd2cfc3(_0x51aa1c),_0x4ffb1a='';for(var _0x214790=0x730+-0x52f*0x1+-0x201;_0x74bcf2[_0x7810e6(0x2e4)](_0x214790,_0x10fb50[_0x10dec0(0x74c)+_0x575c6b(0x217)]);_0x214790++){_0x4ffb1a+=_0x5e1345[_0x10dec0(0x6fa)+_0x3c3a2b(0x636)+_0x3c3a2b(0x1ad)](_0x10fb50[_0x214790]);}return _0x4ffb1a;}else console[_0x575c6b(0x228)](_0x325acf[_0x575c6b(0x6e6)],_0x3492a3);});}function replaceUrlWithFootnote(_0x1c2839){const _0x1e6992=_0x2321d0,_0x26667=_0x2321d0,_0x287515=_0x49938f,_0x4fc96a=_0x49938f,_0x5e1800=_0x2321d0,_0x4b1699={};_0x4b1699[_0x1e6992(0x3b0)]=function(_0x46ee1c,_0x1051ff){return _0x46ee1c-_0x1051ff;},_0x4b1699[_0x1e6992(0x63a)]=function(_0x4feb05,_0x2542b2){return _0x4feb05+_0x2542b2;},_0x4b1699[_0x26667(0x24e)]=_0x4fc96a(0x6e8)+'es',_0x4b1699[_0x4fc96a(0x46f)]=function(_0x26786c,_0x14405d){return _0x26786c===_0x14405d;},_0x4b1699[_0x5e1800(0x4a7)]=_0x1e6992(0x43d),_0x4b1699[_0x1e6992(0x2b4)]=function(_0x258c7a,_0x5d36f6){return _0x258c7a!==_0x5d36f6;},_0x4b1699[_0x5e1800(0x71b)]=_0x26667(0x44d),_0x4b1699[_0x26667(0x1c3)]=_0x4fc96a(0x2de),_0x4b1699[_0x1e6992(0x688)]=function(_0x2a93c0,_0x3eedcd){return _0x2a93c0+_0x3eedcd;},_0x4b1699[_0x4fc96a(0x245)]=function(_0x33d7b6,_0xee1b7){return _0x33d7b6<=_0xee1b7;},_0x4b1699[_0x26667(0x1e9)]=_0x4fc96a(0x681)+_0x5e1800(0x6c0)+_0x1e6992(0x75d),_0x4b1699[_0x287515(0x369)]=_0x4fc96a(0x247)+'er',_0x4b1699[_0x4fc96a(0x760)]=function(_0x206d0d,_0x4fa994){return _0x206d0d>_0x4fa994;},_0x4b1699[_0x5e1800(0x62b)]=_0x4fc96a(0x610),_0x4b1699[_0x4fc96a(0x174)]=_0x5e1800(0x58b);const _0xadebc2=_0x4b1699,_0xcf2cb1=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x5284b6=new Set(),_0x5ba15f=(_0x1c2269,_0x1ece0b)=>{const _0x13a2c2=_0x4fc96a,_0x5ab516=_0x5e1800,_0x553c02=_0x1e6992,_0x5c598c=_0x5e1800,_0x271404=_0x1e6992,_0x459f7b={'KmczL':function(_0x151bb1,_0xc15efc){const _0x55eb9a=_0x54d4;return _0xadebc2[_0x55eb9a(0x3b0)](_0x151bb1,_0xc15efc);},'AbRot':function(_0x1f6b65,_0x38eb32){const _0x3ea5b2=_0x54d4;return _0xadebc2[_0x3ea5b2(0x63a)](_0x1f6b65,_0x38eb32);},'uDjpp':_0xadebc2[_0x13a2c2(0x24e)]};if(_0xadebc2[_0x13a2c2(0x46f)](_0xadebc2[_0x5ab516(0x4a7)],_0xadebc2[_0x5ab516(0x4a7)])){if(_0x5284b6[_0x5ab516(0x5e1)](_0x1ece0b)){if(_0xadebc2[_0x553c02(0x2b4)](_0xadebc2[_0x5c598c(0x71b)],_0xadebc2[_0x553c02(0x1c3)]))return _0x1c2269;else{const _0x58f71f='['+_0x437ec0++ +_0x553c02(0x31d)+_0x2094f9[_0x13a2c2(0x6b5)+'s']()[_0x5ab516(0x382)]()[_0x5c598c(0x6b5)],_0x32c6c4='[^'+_0x459f7b[_0x5c598c(0x65c)](_0x20f487,0x1a64+-0x93b*0x4+0xa89)+_0x13a2c2(0x31d)+_0x4830c6[_0x13a2c2(0x6b5)+'s']()[_0x271404(0x382)]()[_0x13a2c2(0x6b5)];_0x28ef01=_0x1a4a7c+'\x0a\x0a'+_0x32c6c4,_0x14681a[_0x13a2c2(0x6e2)+'e'](_0x34b69f[_0x5ab516(0x6b5)+'s']()[_0x271404(0x382)]()[_0x553c02(0x6b5)]);}}const _0x42b25c=_0x1ece0b[_0x5ab516(0x764)](/[;,；、，]/),_0x45891e=_0x42b25c[_0x271404(0x46b)](_0x34aae4=>'['+_0x34aae4+']')[_0x5ab516(0x370)]('\x20'),_0x5acd84=_0x42b25c[_0x271404(0x46b)](_0x58782d=>'['+_0x58782d+']')[_0x5c598c(0x370)]('\x0a');_0x42b25c[_0x553c02(0x340)+'ch'](_0x10da78=>_0x5284b6[_0x553c02(0x375)](_0x10da78)),res='\x20';for(var _0x56e3ff=_0xadebc2[_0x5ab516(0x688)](_0xadebc2[_0x5c598c(0x3b0)](_0x5284b6[_0x5ab516(0x473)],_0x42b25c[_0x13a2c2(0x36b)+'h']),-0x657*0x3+0x1bad+0x5*-0x1bb);_0xadebc2[_0x13a2c2(0x245)](_0x56e3ff,_0x5284b6[_0x553c02(0x473)]);++_0x56e3ff)res+='[^'+_0x56e3ff+']\x20';return res;}else try{_0x700989=_0x4efbcd[_0x5c598c(0x21d)](_0x459f7b[_0x13a2c2(0x41b)](_0x465996,_0x3462ab))[_0x459f7b[_0x13a2c2(0x74e)]],_0x5154a3='';}catch(_0x32a41c){_0x567b1a=_0x43cceb[_0x5c598c(0x21d)](_0x35c7d6)[_0x459f7b[_0x5ab516(0x74e)]],_0xd604d3='';}};let _0x46a188=-0x7*0x229+-0x19f1+-0x1*-0x2911,_0x39314c=_0x1c2839[_0x26667(0x234)+'ce'](_0xcf2cb1,_0x5ba15f);while(_0xadebc2[_0x5e1800(0x760)](_0x5284b6[_0x287515(0x473)],0x19*-0x122+-0x1f5e+-0x776*-0x8)){if(_0xadebc2[_0x26667(0x2b4)](_0xadebc2[_0x287515(0x62b)],_0xadebc2[_0x26667(0x174)])){const _0x3fad65='['+_0x46a188++ +_0x5e1800(0x31d)+_0x5284b6[_0x5e1800(0x6b5)+'s']()[_0x1e6992(0x382)]()[_0x26667(0x6b5)],_0x299265='[^'+_0xadebc2[_0x4fc96a(0x3b0)](_0x46a188,-0x1ba6+-0x543*-0x3+0xbde)+_0x4fc96a(0x31d)+_0x5284b6[_0x287515(0x6b5)+'s']()[_0x5e1800(0x382)]()[_0x287515(0x6b5)];_0x39314c=_0x39314c+'\x0a\x0a'+_0x299265,_0x5284b6[_0x1e6992(0x6e2)+'e'](_0x5284b6[_0x26667(0x6b5)+'s']()[_0x26667(0x382)]()[_0x1e6992(0x6b5)]);}else return function(_0x4c7390){}[_0x4fc96a(0x14c)+_0x5e1800(0x3b8)+'r'](pLKTjM[_0x4fc96a(0x1e9)])[_0x1e6992(0x2b8)](pLKTjM[_0x4fc96a(0x369)]);}return _0x39314c;}function beautify(_0x2e0de2){const _0x52d4e5=_0x2321d0,_0x5d0126=_0x476ffd,_0x5dce29=_0x3dd906,_0x40a409=_0x2321d0,_0x5e04ab=_0x49938f,_0xaff9ed={'svXqj':function(_0x2c2ea4,_0xb3e843){return _0x2c2ea4(_0xb3e843);},'OrlaH':function(_0x2ddd53,_0x502897){return _0x2ddd53+_0x502897;},'jKeSP':_0x52d4e5(0x43c)+_0x5d0126(0x3eb)+_0x5dce29(0x6b3)+_0x52d4e5(0x284),'Qpdii':_0x40a409(0x279)+_0x5e04ab(0x4d2)+_0x5e04ab(0x64a)+_0x5d0126(0x5c4)+_0x5e04ab(0x53a)+_0x5e04ab(0x2eb)+'\x20)','ODcKN':_0x5d0126(0x27c)+_0x52d4e5(0x3a8)+_0x5d0126(0x6b4),'ajRQp':_0x5d0126(0x27c)+_0x5e04ab(0x637),'LlYDo':_0x5d0126(0x28d),'TKQcT':_0x5dce29(0x5c9),'MqDWt':function(_0x24c16f,_0x2ff79d){return _0x24c16f>=_0x2ff79d;},'tSaVJ':function(_0x2f2a72,_0x16633e){return _0x2f2a72===_0x16633e;},'RiZPI':_0x5e04ab(0x4ed),'fcSTN':_0x5dce29(0x6f7),'KUMhy':_0x5e04ab(0x216),'KSmPX':function(_0x2c2ac1,_0x293a0a){return _0x2c2ac1(_0x293a0a);},'LGGZn':function(_0x55bb14,_0x503ee6){return _0x55bb14+_0x503ee6;},'qfvRW':_0x5d0126(0x133)+_0x5dce29(0x6bb)+'rl','GEtQO':_0x52d4e5(0x5bf)+'l','liCUW':function(_0x5255a1,_0x98ca87){return _0x5255a1(_0x98ca87);},'gwXxI':function(_0xa604b9,_0x9e31cd){return _0xa604b9+_0x9e31cd;},'orzbQ':function(_0x595a94,_0x5c838c){return _0x595a94(_0x5c838c);},'WpyzK':_0x40a409(0x29d)+_0x5dce29(0x3e3)+_0x5d0126(0x134),'OcfLM':function(_0x2bc728,_0xd8932f){return _0x2bc728(_0xd8932f);},'YyDPG':function(_0x5656de,_0x54b801){return _0x5656de+_0x54b801;},'qpXuK':_0x40a409(0x713),'hobyt':function(_0x182b20,_0x4c0624){return _0x182b20+_0x4c0624;},'tUwPn':function(_0x9b5e61,_0x360d8c){return _0x9b5e61(_0x360d8c);},'WrmCC':function(_0x40c727,_0x4c8fa8){return _0x40c727(_0x4c8fa8);},'gFZKS':function(_0x4d6679,_0x42191d){return _0x4d6679>=_0x42191d;},'hqanx':function(_0x7b91d5,_0x18e377){return _0x7b91d5!==_0x18e377;},'ImqqJ':_0x5e04ab(0x325),'ejQtV':function(_0x47c3e3,_0x23dfc0){return _0x47c3e3+_0x23dfc0;},'Rxqxe':_0x5dce29(0x1bb)+_0x5d0126(0x1e8)+'l','PJeAl':function(_0x434755,_0x575b10){return _0x434755(_0x575b10);},'mkMvr':function(_0x154fb5,_0xa17489){return _0x154fb5+_0xa17489;},'QizJH':_0x52d4e5(0x1bb)+_0x52d4e5(0x3f9),'nmMQR':function(_0x17406c,_0x4a4096){return _0x17406c(_0x4a4096);},'WrYtf':_0x5e04ab(0x3f9),'MKoHY':function(_0x3e8a0b,_0x44ef0f){return _0x3e8a0b(_0x44ef0f);}};new_text=_0x2e0de2[_0x40a409(0x234)+_0x40a409(0x2ae)]('（','(')[_0x40a409(0x234)+_0x5d0126(0x2ae)]('）',')')[_0x52d4e5(0x234)+_0x5e04ab(0x2ae)](',\x20',',')[_0x5d0126(0x234)+_0x5dce29(0x2ae)](_0xaff9ed[_0x5e04ab(0x679)],'')[_0x5d0126(0x234)+_0x40a409(0x2ae)](_0xaff9ed[_0x5e04ab(0x24b)],'');for(let _0x490f5e=prompt[_0x40a409(0x404)+_0x40a409(0x298)][_0x52d4e5(0x36b)+'h'];_0xaff9ed[_0x40a409(0x346)](_0x490f5e,0x111a+0x31*-0x62+-0x8*-0x35);--_0x490f5e){if(_0xaff9ed[_0x40a409(0x6f2)](_0xaff9ed[_0x5d0126(0x70f)],_0xaff9ed[_0x40a409(0x776)])){let _0x174566;try{_0x174566=biELnt[_0x5e04ab(0x6cd)](_0x12dce5,biELnt[_0x5dce29(0x28c)](biELnt[_0x5e04ab(0x28c)](biELnt[_0x5e04ab(0x3e8)],biELnt[_0x40a409(0x454)]),');'))();}catch(_0x37a471){_0x174566=_0x34e5b4;}return _0x174566;}else new_text=new_text[_0x5e04ab(0x234)+_0x40a409(0x2ae)](_0xaff9ed[_0x40a409(0x28c)](_0xaff9ed[_0x5e04ab(0x447)],_0xaff9ed[_0x5e04ab(0x155)](String,_0x490f5e)),_0xaff9ed[_0x52d4e5(0x2a4)](_0xaff9ed[_0x5e04ab(0x51a)],_0xaff9ed[_0x5e04ab(0x6cd)](String,_0x490f5e))),new_text=new_text[_0x5d0126(0x234)+_0x52d4e5(0x2ae)](_0xaff9ed[_0x52d4e5(0x28c)](_0xaff9ed[_0x5dce29(0x68f)],_0xaff9ed[_0x5d0126(0x54e)](String,_0x490f5e)),_0xaff9ed[_0x40a409(0x4ea)](_0xaff9ed[_0x52d4e5(0x51a)],_0xaff9ed[_0x52d4e5(0x67a)](String,_0x490f5e))),new_text=new_text[_0x5d0126(0x234)+_0x52d4e5(0x2ae)](_0xaff9ed[_0x5d0126(0x28c)](_0xaff9ed[_0x40a409(0x5ef)],_0xaff9ed[_0x5d0126(0x5d8)](String,_0x490f5e)),_0xaff9ed[_0x40a409(0x28c)](_0xaff9ed[_0x5d0126(0x51a)],_0xaff9ed[_0x5e04ab(0x5d8)](String,_0x490f5e))),new_text=new_text[_0x5d0126(0x234)+_0x52d4e5(0x2ae)](_0xaff9ed[_0x5dce29(0x4a9)](_0xaff9ed[_0x5e04ab(0x685)],_0xaff9ed[_0x5e04ab(0x155)](String,_0x490f5e)),_0xaff9ed[_0x5e04ab(0x76f)](_0xaff9ed[_0x5dce29(0x51a)],_0xaff9ed[_0x5e04ab(0x54b)](String,_0x490f5e)));}new_text=_0xaff9ed[_0x52d4e5(0x3f2)](replaceUrlWithFootnote,new_text);for(let _0x2eb207=prompt[_0x40a409(0x404)+_0x52d4e5(0x298)][_0x5dce29(0x36b)+'h'];_0xaff9ed[_0x52d4e5(0x5a3)](_0x2eb207,-0x1*0xb50+-0x160*-0x19+-0x2*0xb88);--_0x2eb207){if(_0xaff9ed[_0x5dce29(0x42c)](_0xaff9ed[_0x52d4e5(0x5b8)],_0xaff9ed[_0x5e04ab(0x5b8)])){_0x3e8511=0x223*0xf+-0x61*0x1+-0x2*0xfd6,_0xc1e4fd[_0x5d0126(0x42a)+_0x40a409(0x602)+_0x5dce29(0x6de)](_0xaff9ed[_0x52d4e5(0x4f0)])[_0x40a409(0x58f)][_0x5dce29(0x677)+'ay']='',_0x45742c[_0x5e04ab(0x42a)+_0x5d0126(0x602)+_0x5dce29(0x6de)](_0xaff9ed[_0x40a409(0x6ee)])[_0x52d4e5(0x58f)][_0x40a409(0x677)+'ay']='';return;}else new_text=new_text[_0x5dce29(0x234)+'ce'](_0xaff9ed[_0x5dce29(0x29f)](_0xaff9ed[_0x5d0126(0x307)],_0xaff9ed[_0x40a409(0x2d7)](String,_0x2eb207)),prompt[_0x5d0126(0x404)+_0x5dce29(0x298)][_0x2eb207]),new_text=new_text[_0x5e04ab(0x234)+'ce'](_0xaff9ed[_0x5dce29(0x3a4)](_0xaff9ed[_0x5dce29(0x4c5)],_0xaff9ed[_0x52d4e5(0x242)](String,_0x2eb207)),prompt[_0x5e04ab(0x404)+_0x5e04ab(0x298)][_0x2eb207]),new_text=new_text[_0x5dce29(0x234)+'ce'](_0xaff9ed[_0x52d4e5(0x4a9)](_0xaff9ed[_0x5dce29(0x3c2)],_0xaff9ed[_0x5d0126(0x532)](String,_0x2eb207)),prompt[_0x40a409(0x404)+_0x5dce29(0x298)][_0x2eb207]);}return new_text;}function chatmore(){const _0x55ef5d=_0x2321d0,_0x25863b=_0x49938f,_0x1e7966=_0x3aedc2,_0x58ebe1=_0x49938f,_0x30294e=_0x49938f,_0x338fee={'Ftbat':function(_0x3a94bd,_0x36a2b3){return _0x3a94bd===_0x36a2b3;},'iIDFb':_0x55ef5d(0x59f),'BnIBs':_0x25863b(0x4d1)+_0x1e7966(0x66f),'sCfLP':function(_0xe64b6a,_0x3b5501){return _0xe64b6a+_0x3b5501;},'ZISuy':function(_0x48c156,_0x5e59d3){return _0x48c156+_0x5e59d3;},'QfpXN':_0x25863b(0x756)+_0x55ef5d(0x6f0)+_0x25863b(0x71f)+_0x30294e(0x1b8)+_0x30294e(0x623)+_0x25863b(0x53d)+_0x30294e(0x45a)+_0x55ef5d(0x534)+_0x55ef5d(0x76d)+_0x1e7966(0x477)+_0x1e7966(0x305),'KLwbG':function(_0x50914e,_0x2cf38c){return _0x50914e(_0x2cf38c);},'DzqUX':_0x25863b(0x5de)+_0x25863b(0x4ac),'fynov':function(_0x49e257,_0x227a8b){return _0x49e257+_0x227a8b;},'dNEYV':_0x1e7966(0x6e8)+'es','dkDfp':function(_0x5b38b0){return _0x5b38b0();},'ayOEY':function(_0x194c30,_0x7db705){return _0x194c30!==_0x7db705;},'qUZSw':_0x58ebe1(0x54c),'nfNZR':_0x25863b(0x5a0),'cwgTr':_0x30294e(0x204),'mBQuV':function(_0x52f163,_0x3d2d8d){return _0x52f163+_0x3d2d8d;},'wmnet':function(_0x5d241e,_0x14ef86){return _0x5d241e+_0x14ef86;},'lWCPe':_0x25863b(0x4d1),'QNlgW':_0x58ebe1(0x258),'IIsfN':_0x1e7966(0x4eb)+_0x30294e(0x444)+_0x30294e(0x283)+_0x25863b(0x4d7)+_0x1e7966(0x6db)+_0x30294e(0x788)+_0x55ef5d(0x270)+_0x1e7966(0x6ec)+_0x30294e(0x285)+_0x30294e(0x6c1)+_0x55ef5d(0x3e7)+_0x1e7966(0x5dc)+_0x30294e(0x40e),'aYnOR':function(_0x45f7fb,_0x3a6131){return _0x45f7fb!=_0x3a6131;},'swOsF':function(_0x1cf3b0,_0x4811fa,_0x1d624c){return _0x1cf3b0(_0x4811fa,_0x1d624c);},'XNrUZ':_0x25863b(0x1bb)+_0x55ef5d(0x5b3)+_0x25863b(0x14d)+_0x1e7966(0x264)+_0x25863b(0x763)+_0x25863b(0x3af)},_0x4df1ca={'method':_0x338fee[_0x58ebe1(0x786)],'headers':headers,'body':_0x338fee[_0x55ef5d(0x184)](b64EncodeUnicode,JSON[_0x58ebe1(0x1d3)+_0x1e7966(0x5a2)]({'prompt':_0x338fee[_0x30294e(0x6d0)](_0x338fee[_0x30294e(0x2db)](_0x338fee[_0x30294e(0x367)](_0x338fee[_0x55ef5d(0x367)](document[_0x30294e(0x33e)+_0x1e7966(0x250)+_0x55ef5d(0x748)](_0x338fee[_0x1e7966(0x2d3)])[_0x1e7966(0x669)+_0x25863b(0x17a)][_0x55ef5d(0x234)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x1e7966(0x234)+'ce'](/<hr.*/gs,'')[_0x1e7966(0x234)+'ce'](/<[^>]+>/g,'')[_0x55ef5d(0x234)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x338fee[_0x55ef5d(0x418)]),original_search_query),_0x338fee[_0x58ebe1(0x552)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x338fee[_0x30294e(0x180)](document[_0x1e7966(0x33e)+_0x25863b(0x250)+_0x25863b(0x748)](_0x338fee[_0x1e7966(0x66c)])[_0x1e7966(0x669)+_0x30294e(0x17a)],''))return;_0x338fee[_0x30294e(0x731)](fetch,_0x338fee[_0x55ef5d(0x38e)],_0x4df1ca)[_0x30294e(0x4ad)](_0x578b72=>_0x578b72[_0x25863b(0x6c5)]())[_0x1e7966(0x4ad)](_0x40cee3=>{const _0x280d19=_0x1e7966,_0x35f074=_0x55ef5d,_0x213641=_0x30294e,_0x396937=_0x55ef5d,_0x26aeed=_0x55ef5d,_0x3e2156={'JNryx':function(_0x145840,_0x2af400){const _0xb4b5fc=_0x54d4;return _0x338fee[_0xb4b5fc(0x3ed)](_0x145840,_0x2af400);},'VTEkH':_0x338fee[_0x280d19(0x405)],'HWqKN':function(_0x160b1c){const _0x42429b=_0x280d19;return _0x338fee[_0x42429b(0x3d4)](_0x160b1c);}};_0x338fee[_0x35f074(0x75c)](_0x338fee[_0x280d19(0x560)],_0x338fee[_0x213641(0x1b9)])?JSON[_0x213641(0x21d)](_0x40cee3[_0x396937(0x6e8)+'es'][-0x962+0x1c58+-0x1*0x12f6][_0x26aeed(0x6d5)][_0x213641(0x234)+_0x35f074(0x2ae)]('\x0a',''))[_0x280d19(0x340)+'ch'](_0x88d413=>{const _0x40768d=_0x396937,_0x5be973=_0x35f074,_0x5f1aff=_0x35f074,_0x226307=_0x35f074,_0x39b3c5=_0x35f074;_0x338fee[_0x40768d(0x139)](_0x338fee[_0x5be973(0x671)],_0x338fee[_0x40768d(0x671)])?document[_0x5f1aff(0x33e)+_0x5f1aff(0x250)+_0x5be973(0x748)](_0x338fee[_0x39b3c5(0x66c)])[_0x40768d(0x669)+_0x40768d(0x17a)]+=_0x338fee[_0x5be973(0x5a1)](_0x338fee[_0x40768d(0x6d0)](_0x338fee[_0x5be973(0x40f)],_0x338fee[_0x5f1aff(0x184)](String,_0x88d413)),_0x338fee[_0x5be973(0x12b)]):(_0x20abce=_0x2d909f[_0x40768d(0x21d)](_0x3e2156[_0x226307(0x768)](_0x531c28,_0x227c1f))[_0x3e2156[_0x39b3c5(0x3ec)]],_0x51c962='');}):(_0x240893=_0xc4560f[_0x26aeed(0x3ef)+_0x35f074(0x734)+'t'],_0x3a4e5a[_0x396937(0x3a6)+'e'](),_0x3e2156[_0x35f074(0x3dd)](_0x24f66a));})[_0x30294e(0x665)](_0x329f3c=>console[_0x1e7966(0x228)](_0x329f3c)),chatTextRawPlusComment=_0x338fee[_0x30294e(0x2db)](chatTextRaw,'\x0a\x0a'),text_offset=-(-0x1f3e+0x9e*0x26+0x18f*0x5);}let chatTextRaw='',text_offset=-(-0x2*0x2af+0x1d41+-0x1*0x17e2);const _0xfa2727={};_0xfa2727[_0x3dd906(0x36a)+_0x3aedc2(0x3d9)+'pe']=_0x2321d0(0x276)+_0x476ffd(0x463)+_0x3aedc2(0x678)+'n';const headers=_0xfa2727;let prompt=JSON[_0x2321d0(0x21d)](atob(document[_0x49938f(0x33e)+_0x3aedc2(0x250)+_0x3dd906(0x748)](_0x476ffd(0x394)+'pt')[_0x49938f(0x3ef)+_0x49938f(0x734)+'t']));chatTextRawIntro='',text_offset=-(-0x4cf+-0x1*0x1643+0xef*0x1d);const _0x47c37e={};function _0x54d4(_0x323a73,_0x11e52a){const _0xe9dbef=_0x2617();return _0x54d4=function(_0x44ec09,_0x122b98){_0x44ec09=_0x44ec09-(-0xf4*-0x8+0xaf*-0x1a+0xb4b);let _0x1d4a0c=_0xe9dbef[_0x44ec09];return _0x1d4a0c;},_0x54d4(_0x323a73,_0x11e52a);}_0x47c37e[_0x2321d0(0x137)+'t']=_0x3dd906(0x457)+_0x3dd906(0x674)+_0x3aedc2(0x295)+_0x3aedc2(0x132)+_0x476ffd(0x1d8)+_0x3aedc2(0x770)+original_search_query+(_0x3aedc2(0x357)+_0x3dd906(0x4e0)+_0x3aedc2(0x52c)+_0x2321d0(0x185)+_0x3dd906(0x3bc)+_0x476ffd(0x157)+_0x476ffd(0x25a)+_0x476ffd(0x5a7)+_0x3dd906(0x6dd)+_0x49938f(0x49d)),_0x47c37e[_0x49938f(0x2bf)+_0x2321d0(0x4dc)]=0x400,_0x47c37e[_0x49938f(0x4b7)+_0x2321d0(0x2ad)+'e']=0.2,_0x47c37e[_0x49938f(0x39e)]=0x1,_0x47c37e[_0x49938f(0x64c)+_0x49938f(0x388)+_0x49938f(0x618)+'ty']=0x0,_0x47c37e[_0x3aedc2(0x188)+_0x3dd906(0x5ae)+_0x49938f(0x34f)+'y']=0.5,_0x47c37e[_0x3aedc2(0x61b)+'of']=0x1,_0x47c37e[_0x49938f(0x3c4)]=![],_0x47c37e[_0x3dd906(0x311)+_0x3aedc2(0x2af)]=0x0,_0x47c37e[_0x476ffd(0x310)+'m']=!![];const optionsIntro={'method':_0x49938f(0x204),'headers':headers,'body':b64EncodeUnicode(JSON[_0x3aedc2(0x1d3)+_0x476ffd(0x5a2)](_0x47c37e))};fetch(_0x2321d0(0x1bb)+_0x476ffd(0x5b3)+_0x2321d0(0x14d)+_0x476ffd(0x264)+_0x2321d0(0x763)+_0x3aedc2(0x3af),optionsIntro)[_0x2321d0(0x4ad)](_0x4b83b1=>{const _0x32893d=_0x476ffd,_0x420ff8=_0x3dd906,_0x4d5abc=_0x49938f,_0x433ac3=_0x476ffd,_0x2a7c25=_0x3dd906,_0x1176c4={'gvZAP':function(_0x3d2739,_0x228e91){return _0x3d2739+_0x228e91;},'vGaAF':_0x32893d(0x1cf),'jUDeQ':_0x420ff8(0x51d),'rkMke':_0x32893d(0x631)+_0x433ac3(0x72b)+'t','RYBri':function(_0xf60109,_0x1bc728){return _0xf60109!==_0x1bc728;},'FiApD':_0x4d5abc(0x640),'HIunS':_0x420ff8(0x6fb),'LfLHe':_0x420ff8(0x6e8)+'es','DYgQw':function(_0x101010,_0x13d43b){return _0x101010(_0x13d43b);},'Oixcm':_0x433ac3(0x43c)+_0x4d5abc(0x3eb)+_0x4d5abc(0x6b3)+_0x2a7c25(0x284),'LhLua':_0x2a7c25(0x279)+_0x32893d(0x4d2)+_0x4d5abc(0x64a)+_0x32893d(0x5c4)+_0x433ac3(0x53a)+_0x2a7c25(0x2eb)+'\x20)','rpTAc':function(_0x3ae3bd,_0x15cbea){return _0x3ae3bd!==_0x15cbea;},'xWILk':_0x2a7c25(0x5fe),'zsstS':_0x420ff8(0x23a),'weXOx':_0x32893d(0x4d1)+_0x32893d(0x31a)+'t','JMzGi':_0x2a7c25(0x216),'quITJ':_0x2a7c25(0x133)+_0x433ac3(0x6bb)+'rl','yyJmT':_0x32893d(0x5bf)+'l','aSLjs':_0x2a7c25(0x29d)+_0x2a7c25(0x3e3)+_0x32893d(0x134),'awNxp':_0x420ff8(0x713),'UaewM':function(_0xee3540){return _0xee3540();},'bTWKw':function(_0x3e6870,_0x535101){return _0x3e6870-_0x535101;},'qXBUq':_0x32893d(0x721),'IkPGv':_0x420ff8(0x1fd),'OQzbK':function(_0x828e03,_0x5c5aee){return _0x828e03>_0x5c5aee;},'NLArF':function(_0x3e4be3,_0x4bd748){return _0x3e4be3==_0x4bd748;},'AtpAE':_0x2a7c25(0x212)+']','Pakdq':function(_0x117d7c,_0x2f4511){return _0x117d7c===_0x2f4511;},'MlZPb':_0x433ac3(0x125),'qrrnL':_0x420ff8(0x2ec),'ZHxld':_0x4d5abc(0x27c)+_0x420ff8(0x3a8)+_0x420ff8(0x6b4),'Einwy':_0x4d5abc(0x27c)+_0x32893d(0x637),'zYmDN':_0x4d5abc(0x4c3),'hVzpP':_0x420ff8(0x779),'KqYVb':_0x2a7c25(0x408),'lJNhN':_0x32893d(0x148),'ellhF':_0x433ac3(0x65a),'QqJpX':_0x32893d(0x277),'CODiD':_0x433ac3(0x523),'UxcTZ':_0x32893d(0x62c),'iiCuy':function(_0x4fb409,_0x432fc4,_0x550541){return _0x4fb409(_0x432fc4,_0x550541);},'NGlZW':_0x433ac3(0x6f9),'RxamN':function(_0xe98539,_0x4516bc){return _0xe98539<=_0x4516bc;},'TuwDH':_0x2a7c25(0x2cf),'tEsWe':_0x4d5abc(0x517),'Ejrpt':_0x4d5abc(0x1d0),'ZjaTv':_0x433ac3(0x5b9)+':','nayDc':_0x2a7c25(0x62e),'otNAj':function(_0x2f3a27,_0x59bb69){return _0x2f3a27===_0x59bb69;},'XKXnM':_0x4d5abc(0x78c),'lWUbK':_0x420ff8(0x4d1)+_0x4d5abc(0x66f),'zMPWE':_0x32893d(0x204),'sLjHU':function(_0x50d66c,_0x599e94){return _0x50d66c+_0x599e94;},'GqCtE':_0x433ac3(0x733)+'“','csdFv':_0x32893d(0x524)+_0x2a7c25(0x300)+_0x32893d(0x777)+_0x433ac3(0x1ca)+_0x420ff8(0x5fd)+_0x420ff8(0x738)+_0x32893d(0x6aa)+_0x433ac3(0x476),'CUNhK':_0x433ac3(0x4d1),'xVhzn':_0x2a7c25(0x1bb)+_0x420ff8(0x5b3)+_0x4d5abc(0x14d)+_0x4d5abc(0x264)+_0x4d5abc(0x763)+_0x433ac3(0x3af),'Yujxm':_0x420ff8(0x20a),'SlcDw':_0x433ac3(0x3f7),'SmXXO':_0x420ff8(0x496),'lrlSE':_0x433ac3(0x3ae),'gtoqT':_0x2a7c25(0x5e8),'HwEHs':_0x433ac3(0x1cb),'RqkTD':_0x433ac3(0x512),'jHEzF':_0x2a7c25(0x515),'pRsGJ':function(_0x3f9b68,_0x1817b5){return _0x3f9b68===_0x1817b5;},'actvm':_0x2a7c25(0x1d2),'fuhpU':function(_0x578932,_0x3e4042){return _0x578932!==_0x3e4042;},'MbKfc':_0x4d5abc(0x2d1),'NrZUA':_0x433ac3(0x4f1),'lvgSB':function(_0x598147,_0x230b54){return _0x598147(_0x230b54);},'rKAoK':function(_0xcaf219,_0x3ae7f4){return _0xcaf219>_0x3ae7f4;},'qEmaB':function(_0x98c078,_0x5a3678){return _0x98c078==_0x5a3678;},'HsSPs':_0x4d5abc(0x3bb),'JjYMA':function(_0x78d9ed,_0x2b1b2e,_0x50e8af){return _0x78d9ed(_0x2b1b2e,_0x50e8af);},'vVYzh':function(_0x1ceec7,_0x34de1a){return _0x1ceec7!==_0x34de1a;},'kmQPu':_0x4d5abc(0x73e),'NVqkH':_0x420ff8(0x725),'PmQZJ':function(_0x237157,_0x796726){return _0x237157!==_0x796726;},'HnDyw':_0x433ac3(0x758),'XcHfW':_0x2a7c25(0x252),'YPhio':function(_0x44a8d2,_0x556f6b){return _0x44a8d2>_0x556f6b;},'ZvIuZ':function(_0x509864,_0x2e1473){return _0x509864-_0x2e1473;},'gfDUM':function(_0x1d7cd7,_0x37d885,_0x104681){return _0x1d7cd7(_0x37d885,_0x104681);},'KlaIj':function(_0x3e62f0,_0x623995){return _0x3e62f0+_0x623995;},'LFFjp':_0x433ac3(0x27c)+_0x433ac3(0x3ee)},_0x1f46fd=_0x4b83b1[_0x2a7c25(0x74b)][_0x420ff8(0x29b)+_0x32893d(0x785)]();let _0x31c898='',_0x5d9c48='';_0x1f46fd[_0x2a7c25(0x61a)]()[_0x32893d(0x4ad)](function _0x4df07a({done:_0x4522ff,value:_0x1dbeb1}){const _0x55916d=_0x32893d,_0x5c5743=_0x2a7c25,_0x39a26c=_0x420ff8,_0x2d308b=_0x32893d,_0x2b7468=_0x433ac3;if(_0x4522ff)return;const _0x4aea8d=new TextDecoder(_0x1176c4[_0x55916d(0x151)])[_0x5c5743(0x509)+'e'](_0x1dbeb1);return _0x4aea8d[_0x5c5743(0x4f6)]()[_0x39a26c(0x764)]('\x0a')[_0x2d308b(0x340)+'ch'](function(_0x27c271){const _0x15601f=_0x39a26c,_0x34e496=_0x2d308b,_0xd1edd2=_0x2d308b,_0x57e380=_0x55916d,_0x3eb1bc=_0x2b7468,_0x4e3220={'tSQTr':function(_0x4732be,_0x4c3bc1){const _0x1b76e7=_0x54d4;return _0x1176c4[_0x1b76e7(0x4b6)](_0x4732be,_0x4c3bc1);},'HmiyE':_0x1176c4[_0x15601f(0x5e9)],'MbiOw':_0x1176c4[_0x34e496(0x1c4)],'vOHVx':_0x1176c4[_0x15601f(0x2fb)],'XWDuW':function(_0x3a76f0,_0x360576){const _0x467d5a=_0x15601f;return _0x1176c4[_0x467d5a(0x773)](_0x3a76f0,_0x360576);},'IVwql':_0x1176c4[_0x34e496(0x643)],'raHao':_0x1176c4[_0x3eb1bc(0x5f5)],'zJLxN':function(_0x4b4068,_0x188e88){const _0x5c58e1=_0x3eb1bc;return _0x1176c4[_0x5c58e1(0x4b6)](_0x4b4068,_0x188e88);},'wfXPf':_0x1176c4[_0x3eb1bc(0x45c)],'CzmxI':function(_0x442e2a,_0x3bf6b3){const _0x33a046=_0x15601f;return _0x1176c4[_0x33a046(0x249)](_0x442e2a,_0x3bf6b3);},'tHyur':function(_0x5796ab,_0x985195){const _0x167063=_0x34e496;return _0x1176c4[_0x167063(0x4b6)](_0x5796ab,_0x985195);},'HvFwr':_0x1176c4[_0xd1edd2(0x63e)],'yCwKc':_0x1176c4[_0x34e496(0x743)],'aThtl':function(_0x329c82,_0x5e5e67){const _0x4feb39=_0x57e380;return _0x1176c4[_0x4feb39(0x1e3)](_0x329c82,_0x5e5e67);},'WECyP':_0x1176c4[_0x57e380(0x322)],'mMGNx':_0x1176c4[_0x3eb1bc(0x151)],'ypruS':function(_0x5ce6ac,_0x1031f7){const _0xebc6e5=_0x34e496;return _0x1176c4[_0xebc6e5(0x4b6)](_0x5ce6ac,_0x1031f7);},'LQQvW':_0x1176c4[_0x57e380(0x54d)],'lBxAj':function(_0x562059,_0x4cb570){const _0x5d5792=_0x34e496;return _0x1176c4[_0x5d5792(0x4b6)](_0x562059,_0x4cb570);},'TzJdz':_0x1176c4[_0x57e380(0x5b7)],'aQUNV':_0x1176c4[_0x57e380(0x3ac)],'zQOuw':_0x1176c4[_0x3eb1bc(0x718)],'Avgkk':_0x1176c4[_0x34e496(0x5c1)],'SIlYp':_0x1176c4[_0xd1edd2(0x42f)],'ciCAK':function(_0x22efca){const _0x1982c0=_0x57e380;return _0x1176c4[_0x1982c0(0x675)](_0x22efca);},'ZyFEn':function(_0x2da6e9,_0x2386c9){const _0x1ae84a=_0x15601f;return _0x1176c4[_0x1ae84a(0x366)](_0x2da6e9,_0x2386c9);},'fzESz':_0x1176c4[_0x57e380(0x254)],'MewJO':_0x1176c4[_0xd1edd2(0x428)],'DjogN':function(_0x15872a,_0x20afc0){const _0x4ae48f=_0x15601f;return _0x1176c4[_0x4ae48f(0x3fd)](_0x15872a,_0x20afc0);},'EJLLl':function(_0x369748,_0x2bcac6){const _0x57cb91=_0x57e380;return _0x1176c4[_0x57cb91(0x403)](_0x369748,_0x2bcac6);},'iFYbT':_0x1176c4[_0x3eb1bc(0x14e)],'goGpG':function(_0x4a2ab2,_0x110ea6){const _0x505869=_0x3eb1bc;return _0x1176c4[_0x505869(0x20d)](_0x4a2ab2,_0x110ea6);},'EWbRd':_0x1176c4[_0x15601f(0x1be)],'TnJhS':_0x1176c4[_0x34e496(0x4fc)],'iXwcc':_0x1176c4[_0x3eb1bc(0x3b3)],'CYoOz':_0x1176c4[_0x57e380(0x177)],'BrOEq':_0x1176c4[_0x15601f(0x20b)],'SWCtf':_0x1176c4[_0x15601f(0x49f)],'ucNyR':_0x1176c4[_0x34e496(0x414)],'CryRa':_0x1176c4[_0x15601f(0x717)],'XdjcB':_0x1176c4[_0xd1edd2(0x73d)],'kxhMD':_0x1176c4[_0x3eb1bc(0x4fb)],'XTsyt':_0x1176c4[_0x15601f(0x331)],'BPrSY':_0x1176c4[_0x34e496(0x1dd)],'UuksT':function(_0x52df3c,_0x3cc1c8,_0x75f41c){const _0x5dd208=_0x3eb1bc;return _0x1176c4[_0x5dd208(0x2e3)](_0x52df3c,_0x3cc1c8,_0x75f41c);},'xNPNo':_0x1176c4[_0x57e380(0x1d1)],'qWjmA':function(_0x362700,_0x4364f8){const _0x5ced95=_0x3eb1bc;return _0x1176c4[_0x5ced95(0x6fd)](_0x362700,_0x4364f8);},'ipTdB':_0x1176c4[_0x34e496(0x682)],'RERTb':_0x1176c4[_0x3eb1bc(0x2ef)],'nAzQF':_0x1176c4[_0x3eb1bc(0x4a3)],'uHksi':_0x1176c4[_0x3eb1bc(0x3d6)],'atahJ':_0x1176c4[_0x15601f(0x33d)],'xoVbJ':function(_0x224046,_0x455f63){const _0x46439a=_0x34e496;return _0x1176c4[_0x46439a(0x4bf)](_0x224046,_0x455f63);},'omKqw':_0x1176c4[_0x3eb1bc(0x467)],'fklLV':_0x1176c4[_0x15601f(0x585)],'vxeoP':function(_0x3c5397){const _0x374543=_0x34e496;return _0x1176c4[_0x374543(0x675)](_0x3c5397);},'njQva':_0x1176c4[_0x15601f(0x30b)],'gowKc':function(_0xc92db6,_0x53f1f7){const _0x7708a0=_0x15601f;return _0x1176c4[_0x7708a0(0x28b)](_0xc92db6,_0x53f1f7);},'oZtLW':_0x1176c4[_0x3eb1bc(0x6e7)],'HoDZR':_0x1176c4[_0x3eb1bc(0x761)],'WpgMQ':_0x1176c4[_0x57e380(0x1a9)],'wqOmF':_0x1176c4[_0xd1edd2(0x69f)],'ufGxp':_0x1176c4[_0x3eb1bc(0x14a)],'zcOsH':_0x1176c4[_0x3eb1bc(0x736)],'bbUDb':function(_0x530fd2,_0x2e7e92){const _0x2de835=_0xd1edd2;return _0x1176c4[_0x2de835(0x20d)](_0x530fd2,_0x2e7e92);},'bzfgB':_0x1176c4[_0x34e496(0x538)],'HeeIy':_0x1176c4[_0x15601f(0x501)],'CYXAn':function(_0x183973,_0x3bc0d6){const _0x3872ed=_0xd1edd2;return _0x1176c4[_0x3872ed(0x28b)](_0x183973,_0x3bc0d6);},'VIXmg':_0x1176c4[_0x3eb1bc(0x4ab)],'zuUbG':_0x1176c4[_0x3eb1bc(0x2b2)],'TPshP':_0x1176c4[_0xd1edd2(0x450)],'nlQpv':function(_0x78e4f8,_0x180851){const _0xee304d=_0xd1edd2;return _0x1176c4[_0xee304d(0x3fd)](_0x78e4f8,_0x180851);},'KQFwj':_0x1176c4[_0x3eb1bc(0x2c1)],'UFbsd':function(_0x214db7,_0x295c86){const _0x53341e=_0x15601f;return _0x1176c4[_0x53341e(0x249)](_0x214db7,_0x295c86);},'kTpIR':function(_0x9cc62a,_0x5b993a){const _0x44e9de=_0x15601f;return _0x1176c4[_0x44e9de(0x604)](_0x9cc62a,_0x5b993a);},'UJBnk':_0x1176c4[_0x15601f(0x19b)],'BZhHs':function(_0x679117,_0x67c895){const _0x538bea=_0x34e496;return _0x1176c4[_0x538bea(0x3c3)](_0x679117,_0x67c895);},'oNjvx':_0x1176c4[_0x15601f(0x650)],'iiqgw':_0x1176c4[_0x15601f(0x3c1)],'DNaHf':function(_0x2e5a0e,_0x3bd4ee){const _0x5155a0=_0x34e496;return _0x1176c4[_0x5155a0(0x647)](_0x2e5a0e,_0x3bd4ee);},'QNgku':function(_0x1dbf37,_0x400244){const _0xad1ea3=_0xd1edd2;return _0x1176c4[_0xad1ea3(0x28b)](_0x1dbf37,_0x400244);}};if(_0x1176c4[_0x3eb1bc(0x3f1)](_0x27c271[_0x34e496(0x36b)+'h'],-0x15dc*-0x1+-0xb0+-0x1526))_0x31c898=_0x27c271[_0x34e496(0x551)](0x114b+0xe5a*0x1+-0x1f9f);if(_0x1176c4[_0x3eb1bc(0x52b)](_0x31c898,_0x1176c4[_0x57e380(0x14e)])){if(_0x1176c4[_0x3eb1bc(0x20d)](_0x1176c4[_0xd1edd2(0x57b)],_0x1176c4[_0x57e380(0x57b)])){text_offset=-(0x1*0x1c43+0xa8*-0x20+-0x742);const _0x1e6a63={'method':_0x1176c4[_0x15601f(0x30b)],'headers':headers,'body':_0x1176c4[_0xd1edd2(0x647)](b64EncodeUnicode,JSON[_0x34e496(0x1d3)+_0x34e496(0x5a2)](prompt[_0x3eb1bc(0x6b2)]))};_0x1176c4[_0x57e380(0x158)](fetch,_0x1176c4[_0x57e380(0x69f)],_0x1e6a63)[_0x15601f(0x4ad)](_0x4de81d=>{const _0x20468e=_0xd1edd2,_0x48fb9c=_0x15601f,_0x47eb59=_0xd1edd2,_0x47ebc5=_0x34e496,_0x6dfb=_0xd1edd2,_0x1c060c={'pyUXS':function(_0x4d9c8f,_0x4fddd3){const _0x2db8c4=_0x54d4;return _0x4e3220[_0x2db8c4(0x390)](_0x4d9c8f,_0x4fddd3);},'krunU':_0x4e3220[_0x20468e(0x683)],'WziXB':function(_0xed39bf,_0x5197c8){const _0x286c90=_0x20468e;return _0x4e3220[_0x286c90(0x2f4)](_0xed39bf,_0x5197c8);},'BIKMI':_0x4e3220[_0x20468e(0x44b)],'BctQP':function(_0x276db2,_0x5118ae){const _0x9a02ac=_0x20468e;return _0x4e3220[_0x9a02ac(0x4e5)](_0x276db2,_0x5118ae);},'KMZNX':_0x4e3220[_0x20468e(0x60f)],'dllQx':_0x4e3220[_0x47eb59(0x484)],'SilhA':_0x4e3220[_0x6dfb(0x378)],'LAkfE':_0x4e3220[_0x20468e(0x167)],'iJohQ':_0x4e3220[_0x6dfb(0x3d7)],'GCdFw':_0x4e3220[_0x47ebc5(0x52e)],'dRtIk':function(_0x12d681){const _0x146d00=_0x47ebc5;return _0x4e3220[_0x146d00(0x2e0)](_0x12d681);},'PGlLO':_0x4e3220[_0x20468e(0x45e)],'vczRi':function(_0x10042b,_0x1bc01e){const _0x56fbbb=_0x47ebc5;return _0x4e3220[_0x56fbbb(0x22a)](_0x10042b,_0x1bc01e);},'UXdep':function(_0x43e7bc,_0x59c2e4){const _0x172c17=_0x20468e;return _0x4e3220[_0x172c17(0x1f5)](_0x43e7bc,_0x59c2e4);},'hxOWk':_0x4e3220[_0x20468e(0x73f)],'gocJV':_0x4e3220[_0x47eb59(0x259)],'wBKjm':function(_0x4671f8,_0x250a83){const _0x5ce10c=_0x6dfb;return _0x4e3220[_0x5ce10c(0x442)](_0x4671f8,_0x250a83);},'wGtda':function(_0x3c24d9,_0x73c9f0){const _0x36f9f3=_0x20468e;return _0x4e3220[_0x36f9f3(0x735)](_0x3c24d9,_0x73c9f0);},'vVIee':_0x4e3220[_0x47ebc5(0x6ba)],'gLCFt':function(_0x5dd960,_0x5b5c60){const _0x3fae0a=_0x47ebc5;return _0x4e3220[_0x3fae0a(0x48f)](_0x5dd960,_0x5b5c60);},'DkNQY':_0x4e3220[_0x48fb9c(0x302)],'HwkPY':_0x4e3220[_0x20468e(0x70a)],'ROKSt':_0x4e3220[_0x47ebc5(0x2b9)],'sAwOk':_0x4e3220[_0x6dfb(0x37f)],'ARrxq':_0x4e3220[_0x20468e(0x42b)],'HUXLT':_0x4e3220[_0x47eb59(0x16a)],'eegEw':_0x4e3220[_0x47ebc5(0x21e)],'IDGnT':_0x4e3220[_0x47ebc5(0x30e)],'wtGlK':_0x4e3220[_0x6dfb(0x420)],'KadVd':_0x4e3220[_0x48fb9c(0x726)],'XyeIb':_0x4e3220[_0x47ebc5(0x261)],'jdvpZ':_0x4e3220[_0x6dfb(0x4f7)],'jLtFH':function(_0x3cbae4,_0x2372e9,_0x131805){const _0x1a3cf2=_0x20468e;return _0x4e3220[_0x1a3cf2(0x1c1)](_0x3cbae4,_0x2372e9,_0x131805);},'sMgur':_0x4e3220[_0x20468e(0x3e0)],'HSUHN':function(_0x363665,_0x257c22){const _0x24c025=_0x47ebc5;return _0x4e3220[_0x24c025(0x5cc)](_0x363665,_0x257c22);},'VtrVy':function(_0x23ac31,_0x26d42b){const _0x2cfbe7=_0x47eb59;return _0x4e3220[_0x2cfbe7(0x22a)](_0x23ac31,_0x26d42b);},'TovLe':function(_0x55f88c,_0x5456f7){const _0x11c7c9=_0x6dfb;return _0x4e3220[_0x11c7c9(0x238)](_0x55f88c,_0x5456f7);},'rtEpo':_0x4e3220[_0x48fb9c(0x3de)],'OyPkf':_0x4e3220[_0x20468e(0x51c)],'VioBM':_0x4e3220[_0x20468e(0x6b0)],'ZPsiI':_0x4e3220[_0x48fb9c(0x66b)],'ZZoyN':_0x4e3220[_0x47ebc5(0x159)],'LAvnW':_0x4e3220[_0x48fb9c(0x4fa)],'MHzyU':function(_0x36bae4,_0x569a41){const _0x3f789a=_0x47eb59;return _0x4e3220[_0x3f789a(0x442)](_0x36bae4,_0x569a41);},'JlgYm':function(_0x5b887f,_0x175633){const _0x5480fc=_0x47eb59;return _0x4e3220[_0x5480fc(0x30c)](_0x5b887f,_0x175633);},'zEewZ':_0x4e3220[_0x20468e(0x29c)],'VxLij':_0x4e3220[_0x47eb59(0x520)],'PaXkd':function(_0x467195){const _0xaa64f2=_0x6dfb;return _0x4e3220[_0xaa64f2(0x541)](_0x467195);},'hCwJc':_0x4e3220[_0x6dfb(0x236)],'evpEZ':function(_0x345f47,_0x10219c){const _0x551a62=_0x47ebc5;return _0x4e3220[_0x551a62(0x4e5)](_0x345f47,_0x10219c);},'UuzrM':function(_0x2270f5,_0x56bab8){const _0xdaab93=_0x48fb9c;return _0x4e3220[_0xdaab93(0x65b)](_0x2270f5,_0x56bab8);},'TreYf':function(_0x513f62,_0x40683d){const _0x20b016=_0x20468e;return _0x4e3220[_0x20b016(0x4ae)](_0x513f62,_0x40683d);},'JyzRR':function(_0x2ccca3,_0x55d5f7){const _0x231903=_0x20468e;return _0x4e3220[_0x231903(0x1ef)](_0x2ccca3,_0x55d5f7);},'yLgjK':_0x4e3220[_0x47eb59(0x265)],'IscME':_0x4e3220[_0x20468e(0x318)],'GZwSb':_0x4e3220[_0x6dfb(0x446)],'lPDXm':_0x4e3220[_0x47eb59(0x696)],'Bthtb':function(_0x37200a,_0x5663a9){const _0x486c02=_0x47eb59;return _0x4e3220[_0x486c02(0x210)](_0x37200a,_0x5663a9);},'HVaOs':_0x4e3220[_0x48fb9c(0x280)],'pwrCE':_0x4e3220[_0x47eb59(0x344)],'khRXe':function(_0x3c3c95,_0xf3f3f9){const _0x1da86a=_0x20468e;return _0x4e3220[_0x1da86a(0x676)](_0x3c3c95,_0xf3f3f9);},'TMNel':_0x4e3220[_0x48fb9c(0x4b4)],'WKEPq':_0x4e3220[_0x6dfb(0x500)],'EBXQe':function(_0x54000c,_0x2bdf07){const _0xe5eed6=_0x47ebc5;return _0x4e3220[_0xe5eed6(0x65e)](_0x54000c,_0x2bdf07);},'zVlCx':_0x4e3220[_0x48fb9c(0x741)],'ceyAX':_0x4e3220[_0x20468e(0x6ea)],'FbkHI':_0x4e3220[_0x47ebc5(0x2cb)],'KaMjx':function(_0x2bc2df,_0x3a21d4){const _0x40ce37=_0x47ebc5;return _0x4e3220[_0x40ce37(0x548)](_0x2bc2df,_0x3a21d4);},'CVGmu':_0x4e3220[_0x6dfb(0x693)],'otXlL':function(_0x2ce6c7,_0x3b5171,_0x2ff535){const _0x6a095b=_0x47eb59;return _0x4e3220[_0x6a095b(0x1c1)](_0x2ce6c7,_0x3b5171,_0x2ff535);},'NBNWa':function(_0x5048c3,_0x31e7be){const _0x5f0f4f=_0x6dfb;return _0x4e3220[_0x5f0f4f(0x364)](_0x5048c3,_0x31e7be);}};if(_0x4e3220[_0x47eb59(0x363)](_0x4e3220[_0x47eb59(0x37a)],_0x4e3220[_0x20468e(0x37a)])){const _0xd661c4=_0x4de81d[_0x20468e(0x74b)][_0x6dfb(0x29b)+_0x48fb9c(0x785)]();let _0x458ced='',_0x151820='';_0xd661c4[_0x20468e(0x61a)]()[_0x47ebc5(0x4ad)](function _0xf36295({done:_0x4d980a,value:_0x2048aa}){const _0x2995b4=_0x6dfb,_0x5d4d51=_0x47eb59,_0x32ef92=_0x47ebc5,_0x38da99=_0x47eb59,_0x43b071=_0x47eb59,_0x50d994={'Ticay':function(_0x4fceae,_0x4580a6){const _0x221111=_0x54d4;return _0x4e3220[_0x221111(0x5cc)](_0x4fceae,_0x4580a6);},'wRqff':_0x4e3220[_0x2995b4(0x753)],'IjZJJ':_0x4e3220[_0x5d4d51(0x51f)],'QXRXN':_0x4e3220[_0x5d4d51(0x2a1)],'aSDlZ':function(_0x3dc893,_0x1ddca9){const _0x3f2973=_0x32ef92;return _0x4e3220[_0x3f2973(0x210)](_0x3dc893,_0x1ddca9);},'WVZMh':_0x4e3220[_0x2995b4(0x26b)],'ONbzE':_0x4e3220[_0x5d4d51(0x4c1)],'mAXdH':function(_0x352e94,_0x1a3da0){const _0x1fa0e1=_0x2995b4;return _0x4e3220[_0x1fa0e1(0x4ae)](_0x352e94,_0x1a3da0);},'KRAmP':_0x4e3220[_0x2995b4(0x45e)],'vrGXz':function(_0x1b6c89,_0xd9abdb){const _0x2c7637=_0x32ef92;return _0x4e3220[_0x2c7637(0x4e5)](_0x1b6c89,_0xd9abdb);},'GSjPf':function(_0x5a2f2a,_0x534332){const _0x48c862=_0x43b071;return _0x4e3220[_0x48c862(0x1ef)](_0x5a2f2a,_0x534332);},'AHYpR':_0x4e3220[_0x2995b4(0x3d7)],'UOTEL':_0x4e3220[_0x38da99(0x52e)]};if(_0x4e3220[_0x32ef92(0x1f5)](_0x4e3220[_0x5d4d51(0x78d)],_0x4e3220[_0x38da99(0x78d)]))(function(){return![];}[_0x38da99(0x14c)+_0x2995b4(0x3b8)+'r'](JVCnox[_0x43b071(0x129)](JVCnox[_0x5d4d51(0x2d0)],JVCnox[_0x43b071(0x4aa)]))[_0x43b071(0x2b8)](JVCnox[_0x43b071(0x288)]));else{if(_0x4d980a)return;const _0x25cad9=new TextDecoder(_0x4e3220[_0x43b071(0x6b0)])[_0x32ef92(0x509)+'e'](_0x2048aa);return _0x25cad9[_0x2995b4(0x4f6)]()[_0x43b071(0x764)]('\x0a')[_0x38da99(0x340)+'ch'](function(_0x1e4409){const _0x2e68c7=_0x5d4d51,_0x2538a4=_0x2995b4,_0x32832c=_0x2995b4,_0x5185dd=_0x38da99,_0x482070=_0x43b071,_0x2cce68={'VGZjr':function(_0x26e5fc,_0x562858){const _0x3946f7=_0x54d4;return _0x1c060c[_0x3946f7(0x68c)](_0x26e5fc,_0x562858);},'tetBe':_0x1c060c[_0x2e68c7(0x355)],'UFMyW':function(_0x2bd5da,_0x2826e0){const _0x2d49f5=_0x2e68c7;return _0x1c060c[_0x2d49f5(0x3f6)](_0x2bd5da,_0x2826e0);},'HQFUW':_0x1c060c[_0x2538a4(0x27d)],'ssNKn':function(_0x452123,_0x204d08){const _0x30b4e1=_0x2538a4;return _0x1c060c[_0x30b4e1(0x39d)](_0x452123,_0x204d08);},'DUtjg':_0x1c060c[_0x32832c(0x4e9)],'kwiIS':_0x1c060c[_0x2538a4(0x452)],'nBTjx':_0x1c060c[_0x2538a4(0x46e)],'fOWrx':function(_0x15e6e3,_0x488722){const _0x1e4064=_0x5185dd;return _0x1c060c[_0x1e4064(0x39d)](_0x15e6e3,_0x488722);},'PixOR':_0x1c060c[_0x2e68c7(0x37b)],'GJTWJ':_0x1c060c[_0x32832c(0x518)],'FSJhb':_0x1c060c[_0x482070(0x143)],'TtNvy':function(_0x49a55b){const _0xa603cd=_0x2e68c7;return _0x1c060c[_0xa603cd(0x525)](_0x49a55b);},'EbLBu':_0x1c060c[_0x482070(0x309)],'SvpWQ':function(_0x44639d,_0x865bd1){const _0x199e84=_0x32832c;return _0x1c060c[_0x199e84(0x220)](_0x44639d,_0x865bd1);},'wjYIS':function(_0x71c1c4,_0xce71f2){const _0x19acd2=_0x32832c;return _0x1c060c[_0x19acd2(0x475)](_0x71c1c4,_0xce71f2);},'LwXvK':_0x1c060c[_0x482070(0x299)],'HqeSq':_0x1c060c[_0x482070(0x152)],'FMQkZ':function(_0x2a4b08,_0x5637c0){const _0x32fb93=_0x32832c;return _0x1c060c[_0x32fb93(0x47b)](_0x2a4b08,_0x5637c0);},'mRbbU':function(_0x22650e,_0x1fbe00){const _0x4d888f=_0x5185dd;return _0x1c060c[_0x4d888f(0x6af)](_0x22650e,_0x1fbe00);},'DzHRR':_0x1c060c[_0x32832c(0x4cf)],'MkGZq':function(_0x34127c,_0x302981){const _0x2a1468=_0x2e68c7;return _0x1c060c[_0x2a1468(0x43e)](_0x34127c,_0x302981);},'WLztI':_0x1c060c[_0x2538a4(0x740)],'UYHQd':_0x1c060c[_0x5185dd(0x39b)],'kKPWH':_0x1c060c[_0x482070(0x77e)],'rFmpd':_0x1c060c[_0x5185dd(0x421)],'jFlIW':_0x1c060c[_0x482070(0x17d)],'qRBFU':_0x1c060c[_0x32832c(0x5d0)],'nplMz':_0x1c060c[_0x2538a4(0x395)],'RJnsY':_0x1c060c[_0x482070(0x50a)],'dVcOg':_0x1c060c[_0x2538a4(0x40c)],'xAlTG':_0x1c060c[_0x2538a4(0x35b)],'pTvUQ':_0x1c060c[_0x5185dd(0x1d4)],'kVTot':function(_0x33fe5b,_0x128d8f){const _0x1a56e1=_0x482070;return _0x1c060c[_0x1a56e1(0x43e)](_0x33fe5b,_0x128d8f);},'lAHVP':_0x1c060c[_0x5185dd(0x33c)],'sQJLZ':function(_0x3fef8a,_0x4c1c83,_0x9082d9){const _0x407ad3=_0x32832c;return _0x1c060c[_0x407ad3(0x136)](_0x3fef8a,_0x4c1c83,_0x9082d9);},'Ppwak':_0x1c060c[_0x2538a4(0x17b)],'gjRqL':function(_0x363527,_0x14d51e){const _0x4ed289=_0x5185dd;return _0x1c060c[_0x4ed289(0x251)](_0x363527,_0x14d51e);},'Emial':function(_0x30024a,_0x47e616){const _0x1dbf3a=_0x482070;return _0x1c060c[_0x1dbf3a(0x371)](_0x30024a,_0x47e616);},'kfLxa':function(_0x310cca,_0x33bd3f){const _0x69b0d6=_0x2e68c7;return _0x1c060c[_0x69b0d6(0x73b)](_0x310cca,_0x33bd3f);},'XQYEE':_0x1c060c[_0x2538a4(0x415)],'SuOYE':_0x1c060c[_0x482070(0x178)],'mkdic':_0x1c060c[_0x2538a4(0x6d3)],'mieaQ':_0x1c060c[_0x5185dd(0x6f1)],'aWyOT':_0x1c060c[_0x482070(0x59b)],'ujebW':function(_0x37f15e,_0x353eed){const _0x257dfe=_0x482070;return _0x1c060c[_0x257dfe(0x73b)](_0x37f15e,_0x353eed);}};if(_0x1c060c[_0x2e68c7(0x475)](_0x1c060c[_0x32832c(0x654)],_0x1c060c[_0x32832c(0x654)])){const _0x2110c4=_0x136264?function(){const _0x3e46d4=_0x5185dd;if(_0xb0995e){const _0x21cb2=_0x5405eb[_0x3e46d4(0x2b8)](_0x7a327e,arguments);return _0x1b91fa=null,_0x21cb2;}}:function(){};return _0xb7a798=![],_0x2110c4;}else{if(_0x1c060c[_0x32832c(0x506)](_0x1e4409[_0x2e68c7(0x36b)+'h'],-0x29*0x4+-0x1129+-0x15f*-0xd))_0x458ced=_0x1e4409[_0x2538a4(0x551)](0x6b*-0x41+-0x2*0xa8b+0x2d7*0x11);if(_0x1c060c[_0x2e68c7(0x6af)](_0x458ced,_0x1c060c[_0x32832c(0x4cf)])){if(_0x1c060c[_0x5185dd(0x3ba)](_0x1c060c[_0x482070(0x41c)],_0x1c060c[_0x2538a4(0x41c)])){document[_0x2538a4(0x33e)+_0x2e68c7(0x250)+_0x5185dd(0x748)](_0x1c060c[_0x32832c(0x27a)])[_0x32832c(0x669)+_0x482070(0x17a)]='',_0x1c060c[_0x482070(0x25f)](chatmore);const _0x566ee5={'method':_0x1c060c[_0x2e68c7(0x626)],'headers':headers,'body':_0x1c060c[_0x2538a4(0x727)](b64EncodeUnicode,JSON[_0x2e68c7(0x1d3)+_0x2e68c7(0x5a2)]({'prompt':_0x1c060c[_0x2e68c7(0x2e6)](_0x1c060c[_0x2538a4(0x251)](_0x1c060c[_0x482070(0x360)](_0x1c060c[_0x482070(0x465)](_0x1c060c[_0x482070(0x128)],original_search_query),_0x1c060c[_0x5185dd(0x2df)]),document[_0x482070(0x33e)+_0x2538a4(0x250)+_0x32832c(0x748)](_0x1c060c[_0x482070(0x2d5)])[_0x2e68c7(0x669)+_0x32832c(0x17a)][_0x2e68c7(0x234)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x482070(0x234)+'ce'](/<hr.*/gs,'')[_0x2e68c7(0x234)+'ce'](/<[^>]+>/g,'')[_0x5185dd(0x234)+'ce'](/\n\n/g,'\x0a')),'\x0a'),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':!![]}))};_0x1c060c[_0x32832c(0x136)](fetch,_0x1c060c[_0x2e68c7(0x611)],_0x566ee5)[_0x482070(0x4ad)](_0x1720e8=>{const _0xcc9fa6=_0x482070,_0x4c153c=_0x32832c,_0x314b49=_0x2538a4,_0x4592c9=_0x482070,_0xf3410c=_0x2e68c7;if(_0x50d994[_0xcc9fa6(0x2f2)](_0x50d994[_0x4c153c(0x1aa)],_0x50d994[_0xcc9fa6(0x3ff)])){const _0x2e50b6=_0x1720e8[_0x4c153c(0x74b)][_0x314b49(0x29b)+_0xcc9fa6(0x785)]();let _0x142bbf='',_0x541ee5='';_0x2e50b6[_0xcc9fa6(0x61a)]()[_0x4592c9(0x4ad)](function _0x411c53({done:_0x4dd621,value:_0x5cb6bd}){const _0x483d94=_0x314b49,_0x3eb213=_0x4592c9,_0x4cb8e3=_0x314b49,_0x1d479d=_0x4c153c,_0x3af1f8=_0x4592c9,_0x2e8905={'GnrpE':function(_0x5d5840,_0x40d498){const _0x2c623b=_0x54d4;return _0x2cce68[_0x2c623b(0x1ab)](_0x5d5840,_0x40d498);},'hdutG':_0x2cce68[_0x483d94(0x2da)],'vOrYS':function(_0x5dc1e5,_0x11ead1){const _0x2ce44e=_0x483d94;return _0x2cce68[_0x2ce44e(0x63b)](_0x5dc1e5,_0x11ead1);},'hoiMX':_0x2cce68[_0x3eb213(0x70d)],'schLe':function(_0x5891d5,_0x34ca4d){const _0x52a80e=_0x483d94;return _0x2cce68[_0x52a80e(0x225)](_0x5891d5,_0x34ca4d);},'bJJVs':_0x2cce68[_0x483d94(0x469)],'MHMFQ':_0x2cce68[_0x3eb213(0x4c6)],'qIMpS':_0x2cce68[_0x1d479d(0x181)],'fMAMl':function(_0x9373f1,_0x3c3137){const _0x3ca946=_0x483d94;return _0x2cce68[_0x3ca946(0x1c5)](_0x9373f1,_0x3c3137);},'sduCZ':function(_0x35e3e7,_0x5363b8){const _0x9f3401=_0x483d94;return _0x2cce68[_0x9f3401(0x1ab)](_0x35e3e7,_0x5363b8);},'ueugb':_0x2cce68[_0x3af1f8(0x75b)],'dWmeI':_0x2cce68[_0x3eb213(0x222)],'YojNM':_0x2cce68[_0x3eb213(0x3e5)],'rqjRB':function(_0x49e0f4){const _0x4b983f=_0x3af1f8;return _0x2cce68[_0x4b983f(0x422)](_0x49e0f4);},'vxtDT':_0x2cce68[_0x4cb8e3(0x26e)],'qIaCj':function(_0x24b51e,_0x220e91){const _0x15cd8d=_0x1d479d;return _0x2cce68[_0x15cd8d(0x6e1)](_0x24b51e,_0x220e91);},'rRKzF':function(_0x18a4ae,_0x5029b1){const _0x20f980=_0x1d479d;return _0x2cce68[_0x20f980(0x6c4)](_0x18a4ae,_0x5029b1);},'WNTiP':_0x2cce68[_0x1d479d(0x22d)],'rPMHd':_0x2cce68[_0x4cb8e3(0x634)],'SZEoa':function(_0x59d404,_0x5ef024){const _0x48755b=_0x3af1f8;return _0x2cce68[_0x48755b(0x2f3)](_0x59d404,_0x5ef024);},'KbNHd':function(_0x9f9ee4,_0x4205ce){const _0x502a8d=_0x1d479d;return _0x2cce68[_0x502a8d(0x723)](_0x9f9ee4,_0x4205ce);},'cvNnW':_0x2cce68[_0x1d479d(0x389)],'sicHz':function(_0x1b3884,_0x42fdc7){const _0x556d33=_0x4cb8e3;return _0x2cce68[_0x556d33(0x32d)](_0x1b3884,_0x42fdc7);},'riETd':_0x2cce68[_0x1d479d(0x268)],'eUaug':_0x2cce68[_0x4cb8e3(0x411)],'BHhbA':_0x2cce68[_0x3eb213(0x638)],'ivDZr':_0x2cce68[_0x483d94(0x336)],'kvUGs':function(_0x395432,_0x49c3b9){const _0x62890=_0x483d94;return _0x2cce68[_0x62890(0x32d)](_0x395432,_0x49c3b9);},'ZLkov':_0x2cce68[_0x4cb8e3(0x57d)],'lDLGJ':_0x2cce68[_0x1d479d(0x4dd)],'gJQan':_0x2cce68[_0x4cb8e3(0x2a6)],'EhCwe':function(_0x1f2748,_0x3deb6f){const _0x542170=_0x3eb213;return _0x2cce68[_0x542170(0x63b)](_0x1f2748,_0x3deb6f);},'acmrj':_0x2cce68[_0x483d94(0x601)],'CRXpM':_0x2cce68[_0x4cb8e3(0x72f)],'cblwJ':_0x2cce68[_0x1d479d(0x12a)],'GLLtj':_0x2cce68[_0x483d94(0x6a2)],'hXYuQ':function(_0x5ec42e,_0x446d3f){const _0xe034ae=_0x1d479d;return _0x2cce68[_0xe034ae(0x2f3)](_0x5ec42e,_0x446d3f);},'tIroV':function(_0xfa349e,_0x56021d){const _0x501e14=_0x1d479d;return _0x2cce68[_0x501e14(0x31b)](_0xfa349e,_0x56021d);},'vQqih':_0x2cce68[_0x3af1f8(0x2b1)],'nVpAD':function(_0x419c36,_0x4fb418,_0xc8ee38){const _0x3171de=_0x3eb213;return _0x2cce68[_0x3171de(0x632)](_0x419c36,_0x4fb418,_0xc8ee38);},'IwYxW':function(_0x30be74,_0x17508f){const _0x213e66=_0x1d479d;return _0x2cce68[_0x213e66(0x225)](_0x30be74,_0x17508f);},'JaEyy':_0x2cce68[_0x3eb213(0x3ca)],'WFTEB':function(_0x51787c,_0x550b5b){const _0x56d879=_0x4cb8e3;return _0x2cce68[_0x56d879(0x2ce)](_0x51787c,_0x550b5b);},'cwAql':function(_0x1033dc,_0x597765){const _0x2b2a4a=_0x1d479d;return _0x2cce68[_0x2b2a4a(0x4f2)](_0x1033dc,_0x597765);},'WNVMS':function(_0xdbe772,_0x306701){const _0x45047d=_0x1d479d;return _0x2cce68[_0x45047d(0x2e2)](_0xdbe772,_0x306701);}};if(_0x2cce68[_0x4cb8e3(0x6c4)](_0x2cce68[_0x1d479d(0x406)],_0x2cce68[_0x3eb213(0x480)])){if(_0x4dd621)return;const _0x58b173=new TextDecoder(_0x2cce68[_0x3eb213(0x397)])[_0x4cb8e3(0x509)+'e'](_0x5cb6bd);return _0x58b173[_0x4cb8e3(0x4f6)]()[_0x3eb213(0x764)]('\x0a')[_0x4cb8e3(0x340)+'ch'](function(_0x22b108){const _0x278817=_0x483d94,_0x5be370=_0x3af1f8,_0x40085c=_0x3eb213,_0x13df3c=_0x4cb8e3,_0x39178e=_0x3af1f8,_0x16332e={'RiNQz':function(_0x3b00c2,_0x148d0e){const _0x187507=_0x54d4;return _0x2e8905[_0x187507(0x1d9)](_0x3b00c2,_0x148d0e);},'nQiTg':_0x2e8905[_0x278817(0x34d)],'vhwma':function(_0x591fe7,_0xfff7bb){const _0x3b7427=_0x278817;return _0x2e8905[_0x3b7427(0x5bb)](_0x591fe7,_0xfff7bb);},'VaCTx':_0x2e8905[_0x278817(0x689)],'cRwQr':function(_0x429ff7,_0x10c317){const _0x47ae6f=_0x278817;return _0x2e8905[_0x47ae6f(0x772)](_0x429ff7,_0x10c317);},'NMznB':_0x2e8905[_0x278817(0x23d)],'ExGMv':function(_0x4f4f30,_0x1ad37e){const _0x4892ce=_0x278817;return _0x2e8905[_0x4892ce(0x5bb)](_0x4f4f30,_0x1ad37e);},'BQYKU':_0x2e8905[_0x40085c(0x684)],'AXqfx':function(_0x20467f,_0x321d11){const _0x45f949=_0x5be370;return _0x2e8905[_0x45f949(0x772)](_0x20467f,_0x321d11);},'YYBbK':_0x2e8905[_0x39178e(0x53b)],'QbAVg':function(_0x5d5287,_0x39f7e9){const _0x1352b1=_0x40085c;return _0x2e8905[_0x1352b1(0x4f9)](_0x5d5287,_0x39f7e9);},'uZulN':function(_0x3d00df,_0x1fe47c){const _0x5e2e89=_0x40085c;return _0x2e8905[_0x5e2e89(0x1b1)](_0x3d00df,_0x1fe47c);},'NgQxQ':_0x2e8905[_0x5be370(0x262)],'VjwEg':function(_0x453626,_0x57c6cf){const _0x340110=_0x39178e;return _0x2e8905[_0x340110(0x5bb)](_0x453626,_0x57c6cf);},'xUJNS':_0x2e8905[_0x278817(0x720)],'DFaav':_0x2e8905[_0x5be370(0x3b2)],'ZLNCQ':function(_0x3546ce){const _0x1ee21a=_0x278817;return _0x2e8905[_0x1ee21a(0x319)](_0x3546ce);},'YprJS':_0x2e8905[_0x278817(0x18f)],'oxfWv':function(_0x1f718d,_0x580bb8){const _0x2bd250=_0x5be370;return _0x2e8905[_0x2bd250(0x1dc)](_0x1f718d,_0x580bb8);}};if(_0x2e8905[_0x40085c(0x150)](_0x2e8905[_0x39178e(0x349)],_0x2e8905[_0x39178e(0x666)])){if(_0x2e8905[_0x40085c(0x591)](_0x22b108[_0x40085c(0x36b)+'h'],0x4e4+0x1dc6+-0x22a4))_0x142bbf=_0x22b108[_0x278817(0x551)](0x1*-0xe5f+-0x40*-0x16+0x9*0xfd);if(_0x2e8905[_0x278817(0x6d7)](_0x142bbf,_0x2e8905[_0x13df3c(0x4b1)])){if(_0x2e8905[_0x39178e(0x2a3)](_0x2e8905[_0x5be370(0x13c)],_0x2e8905[_0x5be370(0x326)])){_0xf91894+=_0x16332e[_0x39178e(0x483)](_0x237889,_0x18d288),_0xb4f1ec=-0xb8a*0x2+0x1d*0x1d+-0x13cb*-0x1,_0x40c5c5[_0x278817(0x33e)+_0x278817(0x250)+_0x13df3c(0x748)](_0x16332e[_0x40085c(0x376)])[_0x40085c(0x6b5)]='';return;}else{lock_chat=-0x152*0x3+0xf9*0x23+-0x1e15,document[_0x278817(0x42a)+_0x13df3c(0x602)+_0x13df3c(0x6de)](_0x2e8905[_0x39178e(0x3c8)])[_0x5be370(0x58f)][_0x5be370(0x677)+'ay']='',document[_0x40085c(0x42a)+_0x278817(0x602)+_0x40085c(0x6de)](_0x2e8905[_0x40085c(0x3a3)])[_0x13df3c(0x58f)][_0x5be370(0x677)+'ay']='';return;}}let _0x1663ef;try{if(_0x2e8905[_0x13df3c(0x27e)](_0x2e8905[_0x40085c(0x656)],_0x2e8905[_0x5be370(0x656)]))try{_0x2e8905[_0x13df3c(0x2a3)](_0x2e8905[_0x13df3c(0x60a)],_0x2e8905[_0x39178e(0x5f7)])?(_0x189813=_0x1691cf[_0x5be370(0x234)+_0x40085c(0x2ae)](_0x16332e[_0x39178e(0x3e2)](_0x16332e[_0x5be370(0x479)],_0x16332e[_0x39178e(0x474)](_0x109a7a,_0x3cbc1b)),_0x16332e[_0x40085c(0x483)](_0x16332e[_0x40085c(0x20f)],_0x16332e[_0x39178e(0x474)](_0x121b07,_0x34c7b2))),_0x54faa9=_0x5e131f[_0x40085c(0x234)+_0x5be370(0x2ae)](_0x16332e[_0x5be370(0x73a)](_0x16332e[_0x278817(0x6bf)],_0x16332e[_0x13df3c(0x2bc)](_0x1eb6a6,_0x818c5)),_0x16332e[_0x40085c(0x3e2)](_0x16332e[_0x39178e(0x20f)],_0x16332e[_0x5be370(0x2bc)](_0x5a117c,_0x12ab0c))),_0x42d16f=_0x58a454[_0x13df3c(0x234)+_0x13df3c(0x2ae)](_0x16332e[_0x13df3c(0x73a)](_0x16332e[_0x40085c(0x3e4)],_0x16332e[_0x5be370(0x398)](_0x3dadc8,_0x53eb5b)),_0x16332e[_0x5be370(0x2bd)](_0x16332e[_0x13df3c(0x20f)],_0x16332e[_0x39178e(0x398)](_0x3f6263,_0x1f621f))),_0x57862e=_0x4af874[_0x5be370(0x234)+_0x39178e(0x2ae)](_0x16332e[_0x13df3c(0x483)](_0x16332e[_0x40085c(0x6da)],_0x16332e[_0x39178e(0x398)](_0x2e93e8,_0x11562f)),_0x16332e[_0x5be370(0x2bd)](_0x16332e[_0x278817(0x20f)],_0x16332e[_0x278817(0x474)](_0x28ffc0,_0x4066b0)))):(_0x1663ef=JSON[_0x40085c(0x21d)](_0x2e8905[_0x5be370(0x728)](_0x541ee5,_0x142bbf))[_0x2e8905[_0x5be370(0x18f)]],_0x541ee5='');}catch(_0x48aa06){if(_0x2e8905[_0x5be370(0x150)](_0x2e8905[_0x40085c(0x13e)],_0x2e8905[_0x5be370(0x31c)]))_0x1663ef=JSON[_0x13df3c(0x21d)](_0x142bbf)[_0x2e8905[_0x39178e(0x18f)]],_0x541ee5='';else{if(_0x44aadc){const _0x43a060=_0x2ae0d6[_0x278817(0x2b8)](_0x50f2a4,arguments);return _0x41b63b=null,_0x43a060;}}}else{const _0x41df6b=function(){const _0x441edf=_0x40085c,_0x14b23f=_0x278817,_0xfd4c88=_0x40085c,_0x56a0d1=_0x278817,_0x2725eb=_0x278817;let _0xadd895;try{_0xadd895=iPmLdY[_0x441edf(0x398)](_0x4c82a5,iPmLdY[_0x14b23f(0x199)](iPmLdY[_0x14b23f(0x199)](iPmLdY[_0xfd4c88(0x320)],iPmLdY[_0xfd4c88(0x39f)]),');'))();}catch(_0xa16e51){_0xadd895=_0x359abb;}return _0xadd895;},_0x285861=iPmLdY[_0x40085c(0x448)](_0x41df6b);_0x285861[_0x5be370(0x2c7)+_0x278817(0x4c4)+'l'](_0x56a937,0x1f*0xd6+-0x19aa+0xf60);}}catch(_0x1088cc){if(_0x2e8905[_0x40085c(0x150)](_0x2e8905[_0x5be370(0x491)],_0x2e8905[_0x39178e(0x71d)]))_0x541ee5+=_0x142bbf;else return _0x5e55a4;}_0x1663ef&&_0x2e8905[_0x40085c(0x591)](_0x1663ef[_0x13df3c(0x36b)+'h'],0x80e+0x1229*-0x1+0xa1b)&&_0x2e8905[_0x40085c(0x6fc)](_0x1663ef[-0xf8b+-0x1628+0x25b3][_0x40085c(0x311)+_0x13df3c(0x2af)][_0x278817(0x754)+_0x13df3c(0x536)+'t'][-0x2*0x2fa+0x3*0xc4d+-0x3*0xa51],text_offset)&&(_0x2e8905[_0x278817(0x5da)](_0x2e8905[_0x5be370(0x21b)],_0x2e8905[_0x13df3c(0x21b)])?(chatTextRawPlusComment+=_0x1663ef[-0x1041+0x522+0xb1f][_0x5be370(0x6d5)],text_offset=_0x1663ef[-0x48f*-0x5+-0x9ef+-0xcdc][_0x5be370(0x311)+_0x5be370(0x2af)][_0x13df3c(0x754)+_0x40085c(0x536)+'t'][_0x2e8905[_0x278817(0x1dc)](_0x1663ef[-0x1b1*-0xd+-0x1*-0x11f2+-0x27ef][_0x278817(0x311)+_0x13df3c(0x2af)][_0x13df3c(0x754)+_0x40085c(0x536)+'t'][_0x39178e(0x36b)+'h'],-0xd36+-0xeb8+0x1*0x1bef)]):(_0x565ba3=_0x5466d3[_0x39178e(0x21d)](_0x32ace4)[_0x16332e[_0x13df3c(0x5d2)]],_0x35f66e='')),_0x2e8905[_0x13df3c(0x239)](markdownToHtml,_0x2e8905[_0x278817(0x71c)](beautify,chatTextRawPlusComment),document[_0x278817(0x42a)+_0x40085c(0x602)+_0x40085c(0x6de)](_0x2e8905[_0x13df3c(0x70b)]));}else _0x446075+=_0x2498c2[0xb5d+-0x3*0x815+0xce2][_0x5be370(0x6d5)],_0x1f5643=_0x12398a[0x2129+0x1625+-0x374e][_0x278817(0x311)+_0x39178e(0x2af)][_0x278817(0x754)+_0x13df3c(0x536)+'t'][_0x16332e[_0x13df3c(0x4d8)](_0x5dac8e[0x1830+-0x4b3*0x5+-0xb1][_0x39178e(0x311)+_0x40085c(0x2af)][_0x13df3c(0x754)+_0x40085c(0x536)+'t'][_0x278817(0x36b)+'h'],-0x2f*-0xa6+-0x275*-0x7+-0xfe4*0x3)];}),_0x2e50b6[_0x3eb213(0x61a)]()[_0x3eb213(0x4ad)](_0x411c53);}else{if(_0x9b00f1[_0x483d94(0x5e1)](_0x31f43a))return _0x535709;const _0x1b12c4=_0x3e0f49[_0x483d94(0x764)](/[;,；、，]/),_0x5a5e73=_0x1b12c4[_0x3eb213(0x46b)](_0x40cd45=>'['+_0x40cd45+']')[_0x3af1f8(0x370)]('\x20'),_0x2c2583=_0x1b12c4[_0x483d94(0x46b)](_0x21ce9d=>'['+_0x21ce9d+']')[_0x3af1f8(0x370)]('\x0a');_0x1b12c4[_0x4cb8e3(0x340)+'ch'](_0xd52e90=>_0x575586[_0x4cb8e3(0x375)](_0xd52e90)),_0x2ab81c='\x20';for(var _0x373d8b=_0x2e8905[_0x483d94(0x1f9)](_0x2e8905[_0x483d94(0x2f9)](_0x586989[_0x4cb8e3(0x473)],_0x1b12c4[_0x4cb8e3(0x36b)+'h']),-0x1d2f+0x14e5+-0x1*-0x84b);_0x2e8905[_0x1d479d(0x3c7)](_0x373d8b,_0x14dc10[_0x4cb8e3(0x473)]);++_0x373d8b)_0x2471dc+='[^'+_0x373d8b+']\x20';return _0x303d69;}});}else{const _0x3429a4=_0xeca713[_0x4592c9(0x2b8)](_0x259d02,arguments);return _0x13b2c0=null,_0x3429a4;}})[_0x2538a4(0x665)](_0x1a46af=>{const _0x2c2806=_0x2e68c7,_0x50f7c1=_0x2538a4,_0xb84a6e=_0x5185dd,_0x36a916=_0x2538a4,_0x4b91cd=_0x5185dd;if(_0x2cce68[_0x2c2806(0x6c4)](_0x2cce68[_0x50f7c1(0x492)],_0x2cce68[_0xb84a6e(0x492)]))try{_0x67cc87=_0x21223b[_0x2c2806(0x21d)](_0x2cce68[_0x36a916(0x63b)](_0x5d68ee,_0x52ce47))[_0x2cce68[_0x2c2806(0x26e)]],_0x2e6ec3='';}catch(_0x403cfb){_0x5a770a=_0x3ea8f5[_0xb84a6e(0x21d)](_0x31c80e)[_0x2cce68[_0x50f7c1(0x26e)]],_0x1fbd0f='';}else console[_0xb84a6e(0x228)](_0x2cce68[_0x36a916(0x4af)],_0x1a46af);});return;}else return _0x37fac8;}let _0x57155c;try{if(_0x1c060c[_0x32832c(0x13d)](_0x1c060c[_0x2538a4(0x74d)],_0x1c060c[_0x2e68c7(0x186)]))try{_0x1c060c[_0x482070(0x68e)](_0x1c060c[_0x2538a4(0x5e3)],_0x1c060c[_0x2e68c7(0x1f3)])?(_0x140df6=_0x3bbdaa[_0x482070(0x21d)](_0x50d994[_0x5185dd(0x76c)](_0x3df18b,_0xe6530c))[_0x50d994[_0x2e68c7(0x513)]],_0x45ddce=''):(_0x57155c=JSON[_0x482070(0x21d)](_0x1c060c[_0x2e68c7(0x72e)](_0x151820,_0x458ced))[_0x1c060c[_0x482070(0x309)]],_0x151820='');}catch(_0x44ebe7){if(_0x1c060c[_0x2e68c7(0x43e)](_0x1c060c[_0x5185dd(0x692)],_0x1c060c[_0x2e68c7(0x692)]))_0x57155c=JSON[_0x5185dd(0x21d)](_0x458ced)[_0x1c060c[_0x482070(0x309)]],_0x151820='';else{const _0x16da62=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x26cf61=new _0x9fe7b(),_0x55aa10=(_0x391e68,_0xa7c6b0)=>{const _0x2cd2cb=_0x2e68c7,_0x7b868d=_0x482070,_0x1d509e=_0x2e68c7,_0x847bce=_0x5185dd,_0x251620=_0x482070;if(_0x26cf61[_0x2cd2cb(0x5e1)](_0xa7c6b0))return _0x391e68;const _0x2fcd0a=_0xa7c6b0[_0x2cd2cb(0x764)](/[;,；、，]/),_0xee147b=_0x2fcd0a[_0x7b868d(0x46b)](_0x4bd956=>'['+_0x4bd956+']')[_0x7b868d(0x370)]('\x20'),_0x223ad7=_0x2fcd0a[_0x1d509e(0x46b)](_0x4faf73=>'['+_0x4faf73+']')[_0x251620(0x370)]('\x0a');_0x2fcd0a[_0x251620(0x340)+'ch'](_0x2d44c5=>_0x26cf61[_0x1d509e(0x375)](_0x2d44c5)),_0x1ba9e8='\x20';for(var _0x38bf7e=_0x2cce68[_0x251620(0x1ab)](_0x2cce68[_0x2cd2cb(0x4f2)](_0x26cf61[_0x251620(0x473)],_0x2fcd0a[_0x251620(0x36b)+'h']),0x208a+0x18df+-0x3968);_0x2cce68[_0x2cd2cb(0x2c2)](_0x38bf7e,_0x26cf61[_0x2cd2cb(0x473)]);++_0x38bf7e)_0x2f5ee8+='[^'+_0x38bf7e+']\x20';return _0x46157a;};let _0x1c4585=-0x6*0x4f+0x373*-0xa+0x2459,_0xa87bf=_0x152fd8[_0x32832c(0x234)+'ce'](_0x16da62,_0x55aa10);while(_0x2cce68[_0x5185dd(0x2f3)](_0x26cf61[_0x32832c(0x473)],0x93*-0x21+-0x1d*-0x5c+0x25*0x3b)){const _0x59f0bd='['+_0x1c4585++ +_0x5185dd(0x31d)+_0x26cf61[_0x32832c(0x6b5)+'s']()[_0x2e68c7(0x382)]()[_0x2538a4(0x6b5)],_0x46456d='[^'+_0x2cce68[_0x2538a4(0x6e1)](_0x1c4585,0xd35+-0x10*0x20e+-0x13ac*-0x1)+_0x2538a4(0x31d)+_0x26cf61[_0x2538a4(0x6b5)+'s']()[_0x2538a4(0x382)]()[_0x5185dd(0x6b5)];_0xa87bf=_0xa87bf+'\x0a\x0a'+_0x46456d,_0x26cf61[_0x2e68c7(0x6e2)+'e'](_0x26cf61[_0x2e68c7(0x6b5)+'s']()[_0x2e68c7(0x382)]()[_0x5185dd(0x6b5)]);}return _0xa87bf;}}else{let _0x46fa30;try{_0x46fa30=JVCnox[_0x2538a4(0x230)](_0xc53e2a,JVCnox[_0x482070(0x129)](JVCnox[_0x482070(0x5ed)](JVCnox[_0x32832c(0x4c7)],JVCnox[_0x2538a4(0x497)]),');'))();}catch(_0x34394d){_0x46fa30=_0x25cfc9;}return _0x46fa30;}}catch(_0x1a60f5){if(_0x1c060c[_0x32832c(0x475)](_0x1c060c[_0x482070(0x410)],_0x1c060c[_0x2538a4(0x352)]))_0x151820+=_0x458ced;else{const _0x3b70f4=_0x439d34[_0x482070(0x14c)+_0x5185dd(0x3b8)+'r'][_0x5185dd(0x782)+_0x5185dd(0x160)][_0x2538a4(0x384)](_0x10f4ab),_0x57b555=_0x59bd08[_0x475ed3],_0x1fa60a=_0x3d1def[_0x57b555]||_0x3b70f4;_0x3b70f4[_0x5185dd(0x6c3)+_0x32832c(0x208)]=_0x30e86f[_0x32832c(0x384)](_0x2a7d21),_0x3b70f4[_0x32832c(0x303)+_0x5185dd(0x2ac)]=_0x1fa60a[_0x32832c(0x303)+_0x5185dd(0x2ac)][_0x2e68c7(0x384)](_0x1fa60a),_0x41b880[_0x57b555]=_0x3b70f4;}}_0x57155c&&_0x1c060c[_0x482070(0x47b)](_0x57155c[_0x482070(0x36b)+'h'],0x185*0xf+0x38b+-0x1a56)&&_0x1c060c[_0x5185dd(0x438)](_0x57155c[0x3db+-0x1*0xa07+0x316*0x2][_0x32832c(0x311)+_0x2e68c7(0x2af)][_0x32832c(0x754)+_0x32832c(0x536)+'t'][-0x1b4*0x3+-0x15e5*-0x1+-0x1*0x10c9],text_offset)&&(_0x1c060c[_0x5185dd(0x68e)](_0x1c060c[_0x482070(0x70e)],_0x1c060c[_0x32832c(0x70e)])?(chatTextRaw+=_0x57155c[-0xf32+-0x20b2+0x17f2*0x2][_0x32832c(0x6d5)],text_offset=_0x57155c[0x6e1+0x404*0x5+-0x1*0x1af5][_0x32832c(0x311)+_0x2538a4(0x2af)][_0x2538a4(0x754)+_0x2e68c7(0x536)+'t'][_0x1c060c[_0x2538a4(0x220)](_0x57155c[-0x10a0*-0x2+0x7*-0xbf+-0x1c07][_0x5185dd(0x311)+_0x32832c(0x2af)][_0x482070(0x754)+_0x2538a4(0x536)+'t'][_0x2e68c7(0x36b)+'h'],0x1476+0x21f5+-0x18e*0x23)]):(_0x4ac86c=_0xfa54f7[_0x5185dd(0x21d)](_0xd64547)[_0x50d994[_0x32832c(0x513)]],_0x1cfa3d='')),_0x1c060c[_0x5185dd(0x255)](markdownToHtml,_0x1c060c[_0x5185dd(0x77d)](beautify,chatTextRaw),document[_0x5185dd(0x42a)+_0x2538a4(0x602)+_0x5185dd(0x6de)](_0x1c060c[_0x2e68c7(0x17b)]));}}),_0xd661c4[_0x5d4d51(0x61a)]()[_0x2995b4(0x4ad)](_0xf36295);}});}else{if(_0x5f4191){const _0x26de0b=_0x1f76d0[_0x20468e(0x2b8)](_0x50e5fc,arguments);return _0x2c6e24=null,_0x26de0b;}}})[_0x15601f(0x665)](_0x19b546=>{const _0x49b52c=_0x34e496,_0xf05f48=_0x34e496,_0x578a37=_0x34e496,_0x3eee3b=_0xd1edd2,_0x4dbd06=_0x34e496;_0x4e3220[_0x49b52c(0x566)](_0x4e3220[_0x49b52c(0x203)],_0x4e3220[_0x49b52c(0x37e)])?console[_0x578a37(0x228)](_0x4e3220[_0xf05f48(0x159)],_0x19b546):_0x3a66d6=_0x1d6068;});return;}else _0x1dc145=_0x440f13[_0x34e496(0x21d)](_0x4e3220[_0x57e380(0x65e)](_0x29d978,_0x4342f3))[_0x4e3220[_0x57e380(0x45e)]],_0x29159c='';}let _0xb209fe;try{if(_0x1176c4[_0x3eb1bc(0x15c)](_0x1176c4[_0x15601f(0x1ae)],_0x1176c4[_0xd1edd2(0x1ae)])){const _0x2756fc=_0x1a8a10?function(){const _0x546556=_0xd1edd2;if(_0x993d89){const _0x3ffcf5=_0x4713ca[_0x546556(0x2b8)](_0x4c3149,arguments);return _0x36ac0c=null,_0x3ffcf5;}}:function(){};return _0x21f07c=![],_0x2756fc;}else try{if(_0x1176c4[_0x34e496(0x3c3)](_0x1176c4[_0x15601f(0x614)],_0x1176c4[_0x57e380(0x614)])){if(_0x28e97e)return _0x342676;else pTKcyx[_0x34e496(0x619)](_0x537d58,-0x9*-0x226+-0x7d4+-0xb82);}else _0xb209fe=JSON[_0x34e496(0x21d)](_0x1176c4[_0x15601f(0x4b6)](_0x5d9c48,_0x31c898))[_0x1176c4[_0x34e496(0x45c)]],_0x5d9c48='';}catch(_0x299eec){_0x1176c4[_0x57e380(0x3a0)](_0x1176c4[_0x34e496(0x4cc)],_0x1176c4[_0x15601f(0x4cc)])?(_0x4c2136=_0xa0cd4[_0x57e380(0x21d)](_0x4e3220[_0x34e496(0x504)](_0x5caa0b,_0x2152f6))[_0x4e3220[_0x15601f(0x45e)]],_0x538f63=''):(_0xb209fe=JSON[_0x15601f(0x21d)](_0x31c898)[_0x1176c4[_0xd1edd2(0x45c)]],_0x5d9c48='');}}catch(_0x2cd1a8){_0x1176c4[_0x34e496(0x604)](_0x1176c4[_0x34e496(0x5cd)],_0x1176c4[_0x15601f(0x5cd)])?_0x5d9c48+=_0x31c898:_0x2430cf=_0x94addd;}_0xb209fe&&_0x1176c4[_0xd1edd2(0x766)](_0xb209fe[_0x57e380(0x36b)+'h'],0x1252+0x752*0x2+-0x20f6)&&_0x1176c4[_0x57e380(0x3f1)](_0xb209fe[0xd9c+0x5ba+-0xa*0x1ef][_0x3eb1bc(0x311)+_0x34e496(0x2af)][_0x57e380(0x754)+_0xd1edd2(0x536)+'t'][-0x3*0x85f+0xb74+0xda9*0x1],text_offset)&&(chatTextRawIntro+=_0xb209fe[-0x2*0x494+0x1793+-0x1*0xe6b][_0x57e380(0x6d5)],text_offset=_0xb209fe[-0x1*-0xcdf+-0x1*0x3e6+-0x1*0x8f9][_0x15601f(0x311)+_0x3eb1bc(0x2af)][_0x15601f(0x754)+_0x57e380(0x536)+'t'][_0x1176c4[_0xd1edd2(0x19e)](_0xb209fe[0x949+0x1c3c+-0x2585][_0x15601f(0x311)+_0x15601f(0x2af)][_0x3eb1bc(0x754)+_0x34e496(0x536)+'t'][_0x15601f(0x36b)+'h'],-0x1b37+0x1ca8+-0x170)]),_0x1176c4[_0x15601f(0x1e0)](markdownToHtml,_0x1176c4[_0x15601f(0x647)](beautify,_0x1176c4[_0x57e380(0x67c)](chatTextRawIntro,'\x0a')),document[_0x34e496(0x42a)+_0x34e496(0x602)+_0x3eb1bc(0x6de)](_0x1176c4[_0x15601f(0x253)]));}),_0x1f46fd[_0x2b7468(0x61a)]()[_0x39a26c(0x4ad)](_0x4df07a);});})[_0x3dd906(0x665)](_0x13c5bb=>{const _0x47a498=_0x476ffd,_0x41f814=_0x2321d0,_0x15731b=_0x3aedc2,_0x53612b=_0x3aedc2,_0x1e778e={};_0x1e778e[_0x47a498(0x140)]=_0x47a498(0x5b9)+':';const _0x290148=_0x1e778e;console[_0x15731b(0x228)](_0x290148[_0x41f814(0x140)],_0x13c5bb);});function _0x323a73(_0x86a724){const _0xda55e7=_0x2321d0,_0x2c12fa=_0x3dd906,_0x29fb1b=_0x476ffd,_0x55cd36=_0x476ffd,_0x4cfcc5=_0x3dd906,_0x7e9531={'ueHMv':function(_0x373b65,_0x3f1c0c){return _0x373b65===_0x3f1c0c;},'nRAAH':_0xda55e7(0x1d3)+'g','pPdqp':_0xda55e7(0x681)+_0x29fb1b(0x6c0)+_0xda55e7(0x75d),'WTbeg':_0xda55e7(0x247)+'er','NONck':function(_0x290b8a,_0x259e59){return _0x290b8a!==_0x259e59;},'xuqoT':function(_0x30d6c6,_0x67f0b4){return _0x30d6c6+_0x67f0b4;},'prgqr':function(_0x57f4fe,_0x59d4e2){return _0x57f4fe/_0x59d4e2;},'aiUlZ':_0xda55e7(0x36b)+'h','ljgKF':function(_0x148373,_0x36628a){return _0x148373%_0x36628a;},'yzucR':_0x29fb1b(0x1cf),'LPfhH':_0xda55e7(0x51d),'HpLvX':_0x29fb1b(0x549)+'n','RaQla':_0xda55e7(0x631)+_0x29fb1b(0x72b)+'t','rikax':function(_0x4267d5,_0x49d496){return _0x4267d5(_0x49d496);}};function _0x3068fd(_0x4d22ea){const _0x491894=_0xda55e7,_0x4046b8=_0x4cfcc5,_0x4b9cb8=_0x2c12fa,_0x10f2ce=_0x2c12fa,_0x4da4f5=_0x2c12fa;if(_0x7e9531[_0x491894(0x598)](typeof _0x4d22ea,_0x7e9531[_0x491894(0x5ac)]))return function(_0x423912){}[_0x4046b8(0x14c)+_0x4046b8(0x3b8)+'r'](_0x7e9531[_0x491894(0x780)])[_0x4da4f5(0x2b8)](_0x7e9531[_0x491894(0x4d6)]);else _0x7e9531[_0x4b9cb8(0x59c)](_0x7e9531[_0x4b9cb8(0x3d1)]('',_0x7e9531[_0x4b9cb8(0x435)](_0x4d22ea,_0x4d22ea))[_0x7e9531[_0x10f2ce(0x440)]],0x6*0x419+-0xfad+-0x8e8)||_0x7e9531[_0x491894(0x598)](_0x7e9531[_0x4da4f5(0x55d)](_0x4d22ea,0x1*0x16dd+0xa6d*0x2+-0x2ba3*0x1),-0x15*0x16a+0xe80+-0x5*-0x30a)?function(){return!![];}[_0x4b9cb8(0x14c)+_0x4da4f5(0x3b8)+'r'](_0x7e9531[_0x4b9cb8(0x3d1)](_0x7e9531[_0x491894(0x670)],_0x7e9531[_0x491894(0x1cd)]))[_0x491894(0x2a9)](_0x7e9531[_0x4b9cb8(0x55b)]):function(){return![];}[_0x10f2ce(0x14c)+_0x491894(0x3b8)+'r'](_0x7e9531[_0x4da4f5(0x3d1)](_0x7e9531[_0x491894(0x670)],_0x7e9531[_0x4b9cb8(0x1cd)]))[_0x10f2ce(0x2b8)](_0x7e9531[_0x4b9cb8(0x1b0)]);_0x7e9531[_0x491894(0x574)](_0x3068fd,++_0x4d22ea);}try{if(_0x86a724)return _0x3068fd;else _0x7e9531[_0x4cfcc5(0x574)](_0x3068fd,-0x22be+-0x1b7f+0x3e3d);}catch(_0x10f4b0){}}
</script>
                '''
                # for i in range(1,16):
                #     gpt = gpt.replace("["+str(i)+"] http","[^"+str(i)+"]: http").replace("["+str(i)+"]http","[^"+str(i)+"]: http").replace("["+str(i)+"]","[^"+str(i)+"]")
                # rgpt = gpt
                # gpt =  markdown.markdown( gpt , extensions=['footnotes'])
                
                # for i in range(len(url_pair)-1,-1,-1):
                #     gpt = gpt.replace("#fn:"+str(i),url_pair[i])
                #     gpt = gpt.replace("#fn:url"+str(i),url_pair[i])
                # gpt = re.sub(r'<div class="footnote">(.*?)</div>', '', gpt, flags=re.DOTALL)
                # gpt = gpt + '''<style>
                # a.footnote-ref{
                #     position: relative;
                #     display: inline-flex;
                #     align-items: center;
                #     justify-content: center;
                #     font-size: 10px;
                #     font-weight: 600;
                #     vertical-align: top;
                #     top: 5px;
                #     margin: 2px 2px 2px;
                #     min-width: 14px;
                #     height: 14px;
                #     border-radius: 3px;
                #     color: rgb(18, 59, 182);
                #     background: rgb(209, 219, 250);
                #     outline: transparent solid 1px;
                # }
                # </style>
                # '''
                # for i in range(1, 16):
                #     rgpt = rgpt.replace(f"[{i}]", "")
                #     rgpt = rgpt.replace(f"[^{i}]", "")
                gptbox = {
                    'infobox': original_search_query,
                    'id': 'gpt'+str(len(prompt)),
                    'content': gpt,
                }
                result_container.infoboxes.append(gptbox)
    except Exception as ee:
        logger.exception(ee, exc_info=True)


    # checkin for a external bang
    if result_container.redirect_url:
        return redirect(result_container.redirect_url)

    # Server-Timing header
    request.timings = result_container.get_timings()  # pylint: disable=assigning-non-slot

    current_template = None
    previous_result = None

    # output
    for result in results:
        if output_format == 'html':
            if 'content' in result and result['content']:
                result['content'] = highlight_content(escape(result['content'][:1024]), search_query.query)
            if 'title' in result and result['title']:
                result['title'] = highlight_content(escape(result['title'] or ''), search_query.query)
        else:
            if result.get('content'):
                result['content'] = html_to_text(result['content']).strip()
            # removing html content and whitespace duplications
            result['title'] = ' '.join(html_to_text(result['title']).strip().split())

        if 'url' in result:
            result['pretty_url'] = prettify_url(result['url'])

        if result.get('publishedDate'):  # do not try to get a date from an empty string or a None type
            try:  # test if publishedDate >= 1900 (datetime module bug)
                result['pubdate'] = result['publishedDate'].strftime('%Y-%m-%d %H:%M:%S%z')
            except ValueError:
                result['publishedDate'] = None
            else:
                result['publishedDate'] = searxng_l10n_timespan(result['publishedDate'])

        # set result['open_group'] = True when the template changes from the previous result
        # set result['close_group'] = True when the template changes on the next result
        if current_template != result.get('template'):
            result['open_group'] = True
            if previous_result:
                previous_result['close_group'] = True  # pylint: disable=unsupported-assignment-operation
        current_template = result.get('template')
        previous_result = result

    if previous_result:
        previous_result['close_group'] = True

    if output_format == 'json':
        x = {
            # 'query': search_query.query,
            # 'number_of_results': number_of_results,
            # 'results': results,
            # 'answers': list(result_container.answers),
            # 'corrections': list(result_container.corrections),
            'infoboxes': result_container.infoboxes,
            # 'suggestions': list(result_container.suggestions),
            # 'unresponsive_engines': __get_translated_errors(result_container.unresponsive_engines),
        }
        response = json.dumps(x, default=lambda item: list(item) if isinstance(item, set) else item)
        return Response(response, mimetype='application/json')

    if output_format == 'csv':
        csv = UnicodeWriter(StringIO())
        keys = ('title', 'url', 'content', 'host', 'engine', 'score', 'type')
        csv.writerow(keys)
        for row in results:
            row['host'] = row['parsed_url'].netloc
            row['type'] = 'result'
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.answers:
            row = {'title': a, 'type': 'answer'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.suggestions:
            row = {'title': a, 'type': 'suggestion'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.corrections:
            row = {'title': a, 'type': 'correction'}
            csv.writerow([row.get(key, '') for key in keys])
        csv.stream.seek(0)
        response = Response(csv.stream.read(), mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx_-_{0}.csv'.format(search_query.query)
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=results,
            answers=result_container.answers,
            corrections=result_container.corrections,
            suggestions=result_container.suggestions,
            q=request.form['q'],
            number_of_results=number_of_results,
        )
        return Response(response_rss, mimetype='text/xml')

    # HTML output format

    # suggestions: use RawTextQuery to get the suggestion URLs with the same bang
    suggestion_urls = list(
        map(
            lambda suggestion: {'url': raw_text_query.changeQuery(suggestion).getFullQuery(), 'title': suggestion},
            result_container.suggestions,
        )
    )

    correction_urls = list(
        map(
            lambda correction: {'url': raw_text_query.changeQuery(correction).getFullQuery(), 'title': correction},
            result_container.corrections,
        )
    )

    # search_query.lang contains the user choice (all, auto, en, ...)
    # when the user choice is "auto", search.search_query.lang contains the detected language
    # otherwise it is equals to search_query.lang
    return render(
        # fmt: off
        'results.html',
        results = results,
        q=request.form['q'],
        selected_categories = search_query.categories,
        pageno = search_query.pageno,
        time_range = search_query.time_range or '',
        number_of_results = format_decimal(number_of_results),
        suggestions = suggestion_urls,
        answers = result_container.answers,
        corrections = correction_urls,
        infoboxes = result_container.infoboxes,
        engine_data = result_container.engine_data,
        paging = result_container.paging,
        unresponsive_engines = __get_translated_errors(
            result_container.unresponsive_engines
        ),
        current_locale = request.preferences.get_value("locale"),
        current_language = match_language(
            search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        search_language = match_language(
            search.search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        timeout_limit = request.form.get('timeout_limit', None)
        # fmt: on
    )


def __get_translated_errors(unresponsive_engines: Iterable[UnresponsiveEngine]):
    translated_errors = []

    # make a copy unresponsive_engines to avoid "RuntimeError: Set changed size
    # during iteration" it happens when an engine modifies the ResultContainer
    # after the search_multiple_requests method has stopped waiting

    for unresponsive_engine in unresponsive_engines:
        error_user_text = exception_classname_to_text.get(unresponsive_engine.error_type)
        if not error_user_text:
            error_user_text = exception_classname_to_text[None]
        error_msg = gettext(error_user_text)
        if unresponsive_engine.suspended:
            error_msg = gettext('Suspended') + ': ' + error_msg
        translated_errors.append((unresponsive_engine.engine, error_msg))

    return sorted(translated_errors, key=lambda e: e[0])


@app.route('/about', methods=['GET'])
def about():
    """Redirect to about page"""
    # custom_url_for is going to add the locale
    return redirect(custom_url_for('info', pagename='about'))


@app.route('/info/<locale>/<pagename>', methods=['GET'])
def info(pagename, locale):
    """Render page of online user documentation"""
    page = _INFO_PAGES.get_page(pagename, locale)
    if page is None:
        flask.abort(404)

    user_locale = request.preferences.get_value('locale')
    return render(
        'info.html',
        all_pages=_INFO_PAGES.iter_pages(user_locale, fallback_to_default=True),
        active_page=page,
        active_pagename=pagename,
    )


@app.route('/autocompleter', methods=['GET', 'POST'])
def autocompleter():
    """Return autocompleter results"""

    # run autocompleter
    results = []

    # set blocked engines
    disabled_engines = request.preferences.engines.get_disabled()

    # parse query
    raw_text_query = RawTextQuery(request.form.get('q', ''), disabled_engines)
    sug_prefix = raw_text_query.getQuery()

    # normal autocompletion results only appear if no inner results returned
    # and there is a query part
    if len(raw_text_query.autocomplete_list) == 0 and len(sug_prefix) > 0:

        # get language from cookie
        language = request.preferences.get_value('language')
        if not language or language == 'all':
            language = 'en'
        else:
            language = language.split('-')[0]

        # run autocompletion
        raw_results = search_autocomplete(request.preferences.get_value('autocomplete'), sug_prefix, language)
        for result in raw_results:
            # attention: this loop will change raw_text_query object and this is
            # the reason why the sug_prefix was stored before (see above)
            if result != sug_prefix:
                results.append(raw_text_query.changeQuery(result).getFullQuery())

    if len(raw_text_query.autocomplete_list) > 0:
        for autocomplete_text in raw_text_query.autocomplete_list:
            results.append(raw_text_query.get_autocomplete_full_query(autocomplete_text))

    for answers in ask(raw_text_query):
        for answer in answers:
            results.append(str(answer['answer']))

    if request.headers.get('X-Requested-With') == 'XMLHttpRequest':
        # the suggestion request comes from the searx search form
        suggestions = json.dumps(results)
        mimetype = 'application/json'
    else:
        # the suggestion request comes from browser's URL bar
        suggestions = json.dumps([sug_prefix, results])
        mimetype = 'application/x-suggestions+json'

    suggestions = escape(suggestions, False)
    return Response(suggestions, mimetype=mimetype)


@app.route('/preferences', methods=['GET', 'POST'])
def preferences():
    """Render preferences page && save user preferences"""

    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # save preferences using the link the /preferences?preferences=...&save=1
    if request.args.get('save') == '1':
        resp = make_response(redirect(url_for('index', _external=True)))
        return request.preferences.save(resp)

    # save preferences
    if request.method == 'POST':
        resp = make_response(redirect(url_for('index', _external=True)))
        try:
            request.preferences.parse_form(request.form)
        except ValidationException:
            request.errors.append(gettext('Invalid settings, please edit your preferences'))
            return resp
        return request.preferences.save(resp)

    # render preferences
    image_proxy = request.preferences.get_value('image_proxy')  # pylint: disable=redefined-outer-name
    disabled_engines = request.preferences.engines.get_disabled()
    allowed_plugins = request.preferences.plugins.get_enabled()

    # stats for preferences page
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))

    engines_by_category = {}

    for c in categories:  # pylint: disable=consider-using-dict-items
        engines_by_category[c] = [e for e in categories[c] if e.name in filtered_engines]
        # sort the engines alphabetically since the order in settings.yml is meaningless.
        list.sort(engines_by_category[c], key=lambda e: e.name)

    # get first element [0], the engine time,
    # and then the second element [1] : the time (the first one is the label)
    stats = {}  # pylint: disable=redefined-outer-name
    max_rate95 = 0
    for _, e in filtered_engines.items():
        h = histogram('engine', e.name, 'time', 'total')
        median = round(h.percentage(50), 1) if h.count > 0 else None
        rate80 = round(h.percentage(80), 1) if h.count > 0 else None
        rate95 = round(h.percentage(95), 1) if h.count > 0 else None

        max_rate95 = max(max_rate95, rate95 or 0)

        result_count_sum = histogram('engine', e.name, 'result', 'count').sum
        successful_count = counter('engine', e.name, 'search', 'count', 'successful')
        result_count = int(result_count_sum / float(successful_count)) if successful_count else 0

        stats[e.name] = {
            'time': median,
            'rate80': rate80,
            'rate95': rate95,
            'warn_timeout': e.timeout > settings['outgoing']['request_timeout'],
            'supports_selected_language': _is_selected_language_supported(e, request.preferences),
            'result_count': result_count,
        }
    # end of stats

    # reliabilities
    reliabilities = {}
    engine_errors = get_engine_errors(filtered_engines)
    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )
    for _, e in filtered_engines.items():
        checker_result = checker_results.get(e.name, {})
        checker_success = checker_result.get('success', True)
        errors = engine_errors.get(e.name) or []
        if counter('engine', e.name, 'search', 'count', 'sent') == 0:
            # no request
            reliablity = None
        elif checker_success and not errors:
            reliablity = 100
        elif 'simple' in checker_result.get('errors', {}):
            # the basic (simple) test doesn't work: the engine is broken accoding to the checker
            # even if there is no exception
            reliablity = 0
        else:
            # pylint: disable=consider-using-generator
            reliablity = 100 - sum([error['percentage'] for error in errors if not error.get('secondary')])

        reliabilities[e.name] = {
            'reliablity': reliablity,
            'errors': [],
            'checker': checker_results.get(e.name, {}).get('errors', {}).keys(),
        }
        # keep the order of the list checker_results[e.name]['errors'] and deduplicate.
        # the first element has the highest percentage rate.
        reliabilities_errors = []
        for error in errors:
            error_user_text = None
            if error.get('secondary') or 'exception_classname' not in error:
                continue
            error_user_text = exception_classname_to_text.get(error.get('exception_classname'))
            if not error:
                error_user_text = exception_classname_to_text[None]
            if error_user_text not in reliabilities_errors:
                reliabilities_errors.append(error_user_text)
        reliabilities[e.name]['errors'] = reliabilities_errors

    # supports
    supports = {}
    for _, e in filtered_engines.items():
        supports_selected_language = _is_selected_language_supported(e, request.preferences)
        safesearch = e.safesearch
        time_range_support = e.time_range_support
        for checker_test_name in checker_results.get(e.name, {}).get('errors', {}):
            if supports_selected_language and checker_test_name.startswith('lang_'):
                supports_selected_language = '?'
            elif safesearch and checker_test_name == 'safesearch':
                safesearch = '?'
            elif time_range_support and checker_test_name == 'time_range':
                time_range_support = '?'
        supports[e.name] = {
            'supports_selected_language': supports_selected_language,
            'safesearch': safesearch,
            'time_range_support': time_range_support,
        }

    return render(
        # fmt: off
        'preferences.html',
        selected_categories = get_selected_categories(request.preferences, request.form),
        locales = LOCALE_NAMES,
        current_locale = request.preferences.get_value("locale"),
        image_proxy = image_proxy,
        engines_by_category = engines_by_category,
        stats = stats,
        max_rate95 = max_rate95,
        reliabilities = reliabilities,
        supports = supports,
        answerers = [
            {'info': a.self_info(), 'keywords': a.keywords}
            for a in answerers
        ],
        disabled_engines = disabled_engines,
        autocomplete_backends = autocomplete_backends,
        shortcuts = {y: x for x, y in engine_shortcuts.items()},
        themes = themes,
        plugins = plugins,
        doi_resolvers = settings['doi_resolvers'],
        current_doi_resolver = get_doi_resolver(request.preferences),
        allowed_plugins = allowed_plugins,
        preferences_url_params = request.preferences.get_as_url_params(),
        locked_preferences = settings['preferences']['lock'],
        preferences = True
        # fmt: on
    )


def _is_selected_language_supported(engine, preferences: Preferences):  # pylint: disable=redefined-outer-name
    language = preferences.get_value('language')
    if language == 'all':
        return True
    x = match_language(
        language, getattr(engine, 'supported_languages', []), getattr(engine, 'language_aliases', {}), None
    )
    return bool(x)


@app.route('/image_proxy', methods=['GET'])
def image_proxy():
    # pylint: disable=too-many-return-statements, too-many-branches

    url = request.args.get('url')
    if not url:
        return '', 400

    if not is_hmac_of(settings['server']['secret_key'], url.encode(), request.args.get('h', '')):
        return '', 400

    maximum_size = 5 * 1024 * 1024
    forward_resp = False
    resp = None
    try:
        request_headers = {
            'User-Agent': gen_useragent(),
            'Accept': 'image/webp,*/*',
            'Accept-Encoding': 'gzip, deflate',
            'Sec-GPC': '1',
            'DNT': '1',
        }
        set_context_network_name('image_proxy')
        resp, stream = http_stream(method='GET', url=url, headers=request_headers, allow_redirects=True)
        content_length = resp.headers.get('Content-Length')
        if content_length and content_length.isdigit() and int(content_length) > maximum_size:
            return 'Max size', 400

        if resp.status_code != 200:
            logger.debug('image-proxy: wrong response code: %i', resp.status_code)
            if resp.status_code >= 400:
                return '', resp.status_code
            return '', 400

        if not resp.headers.get('Content-Type', '').startswith('image/') and not resp.headers.get(
            'Content-Type', ''
        ).startswith('binary/octet-stream'):
            logger.debug('image-proxy: wrong content-type: %s', resp.headers.get('Content-Type', ''))
            return '', 400

        forward_resp = True
    except httpx.HTTPError:
        logger.exception('HTTP error')
        return '', 400
    finally:
        if resp and not forward_resp:
            # the code is about to return an HTTP 400 error to the browser
            # we make sure to close the response between searxng and the HTTP server
            try:
                resp.close()
            except httpx.HTTPError:
                logger.exception('HTTP error on closing')

    def close_stream():
        nonlocal resp, stream
        try:
            if resp:
                resp.close()
            del resp
            del stream
        except httpx.HTTPError as e:
            logger.debug('Exception while closing response', e)

    try:
        headers = dict_subset(resp.headers, {'Content-Type', 'Content-Encoding', 'Content-Length', 'Length'})
        response = Response(stream, mimetype=resp.headers['Content-Type'], headers=headers, direct_passthrough=True)
        response.call_on_close(close_stream)
        return response
    except httpx.HTTPError:
        close_stream()
        return '', 400


@app.route('/engine_descriptions.json', methods=['GET'])
def engine_descriptions():
    locale = get_locale().split('_')[0]
    result = ENGINE_DESCRIPTIONS['en'].copy()
    if locale != 'en':
        for engine, description in ENGINE_DESCRIPTIONS.get(locale, {}).items():
            result[engine] = description
    for engine, description in result.items():
        if len(description) == 2 and description[1] == 'ref':
            ref_engine, ref_lang = description[0].split(':')
            description = ENGINE_DESCRIPTIONS[ref_lang][ref_engine]
        if isinstance(description, str):
            description = [description, 'wikipedia']
        result[engine] = description

    # overwrite by about:description (from settings)
    for engine_name, engine_mod in engines.items():
        descr = getattr(engine_mod, 'about', {}).get('description', None)
        if descr is not None:
            result[engine_name] = [descr, "SearXNG config"]

    return jsonify(result)


@app.route('/stats', methods=['GET'])
def stats():
    """Render engine statistics page."""
    sort_order = request.args.get('sort', default='name', type=str)
    selected_engine_name = request.args.get('engine', default=None, type=str)

    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    if selected_engine_name:
        if selected_engine_name not in filtered_engines:
            selected_engine_name = None
        else:
            filtered_engines = [selected_engine_name]

    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )

    engine_stats = get_engines_stats(filtered_engines)
    engine_reliabilities = get_reliabilities(filtered_engines, checker_results)

    if sort_order not in STATS_SORT_PARAMETERS:
        sort_order = 'name'

    reverse, key_name, default_value = STATS_SORT_PARAMETERS[sort_order]

    def get_key(engine_stat):
        reliability = engine_reliabilities.get(engine_stat['name'], {}).get('reliablity', 0)
        reliability_order = 0 if reliability else 1
        if key_name == 'reliability':
            key = reliability
            reliability_order = 0
        else:
            key = engine_stat.get(key_name) or default_value
            if reverse:
                reliability_order = 1 - reliability_order
        return (reliability_order, key, engine_stat['name'])

    engine_stats['time'] = sorted(engine_stats['time'], reverse=reverse, key=get_key)
    return render(
        # fmt: off
        'stats.html',
        sort_order = sort_order,
        engine_stats = engine_stats,
        engine_reliabilities = engine_reliabilities,
        selected_engine_name = selected_engine_name,
        searx_git_branch = GIT_BRANCH,
        # fmt: on
    )


@app.route('/stats/errors', methods=['GET'])
def stats_errors():
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    result = get_engine_errors(filtered_engines)
    return jsonify(result)


@app.route('/stats/checker', methods=['GET'])
def stats_checker():
    result = checker_get_result()
    return jsonify(result)


@app.route('/robots.txt', methods=['GET'])
def robots():
    return Response(
        """User-agent: *
Allow: /info/en/about
Disallow: /stats
Disallow: /image_proxy
Disallow: /preferences
Disallow: /*?*q=*
""",
        mimetype='text/plain',
    )


@app.route('/opensearch.xml', methods=['GET'])
def opensearch():
    method = request.preferences.get_value('method')
    autocomplete = request.preferences.get_value('autocomplete')

    # chrome/chromium only supports HTTP GET....
    if request.headers.get('User-Agent', '').lower().find('webkit') >= 0:
        method = 'GET'

    if method not in ('POST', 'GET'):
        method = 'POST'

    ret = render('opensearch.xml', opensearch_method=method, autocomplete=autocomplete)
    resp = Response(response=ret, status=200, mimetype="application/opensearchdescription+xml")
    return resp


@app.route('/favicon.ico')
def favicon():
    theme = request.preferences.get_value("theme")
    return send_from_directory(
        os.path.join(app.root_path, settings['ui']['static_path'], 'themes', theme, 'img'),  # pyright: ignore
        'favicon.png',
        mimetype='image/vnd.microsoft.icon',
    )


@app.route('/clear_cookies')
def clear_cookies():
    resp = make_response(redirect(url_for('index', _external=True)))
    for cookie_name in request.cookies:
        resp.delete_cookie(cookie_name)
    return resp


@app.route('/config')
def config():
    """Return configuration in JSON format."""
    _engines = []
    for name, engine in engines.items():
        if not request.preferences.validate_token(engine):
            continue

        supported_languages = engine.supported_languages
        if isinstance(engine.supported_languages, dict):
            supported_languages = list(engine.supported_languages.keys())

        _engines.append(
            {
                'name': name,
                'categories': engine.categories,
                'shortcut': engine.shortcut,
                'enabled': not engine.disabled,
                'paging': engine.paging,
                'language_support': engine.language_support,
                'supported_languages': supported_languages,
                'safesearch': engine.safesearch,
                'time_range_support': engine.time_range_support,
                'timeout': engine.timeout,
            }
        )

    _plugins = []
    for _ in plugins:
        _plugins.append({'name': _.name, 'enabled': _.default_on})

    return jsonify(
        {
            'categories': list(categories.keys()),
            'engines': _engines,
            'plugins': _plugins,
            'instance_name': settings['general']['instance_name'],
            'locales': LOCALE_NAMES,
            'default_locale': settings['ui']['default_locale'],
            'autocomplete': settings['search']['autocomplete'],
            'safe_search': settings['search']['safe_search'],
            'default_theme': settings['ui']['default_theme'],
            'version': VERSION_STRING,
            'brand': {
                'PRIVACYPOLICY_URL': get_setting('general.privacypolicy_url'),
                'CONTACT_URL': get_setting('general.contact_url'),
                'GIT_URL': GIT_URL,
                'GIT_BRANCH': GIT_BRANCH,
                'DOCS_URL': get_setting('brand.docs_url'),
            },
            'doi_resolvers': list(settings['doi_resolvers'].keys()),
            'default_doi_resolver': settings['default_doi_resolver'],
        }
    )


@app.errorhandler(404)
def page_not_found(_e):
    return render('404.html'), 404


# see https://flask.palletsprojects.com/en/1.1.x/cli/
# True if "FLASK_APP=searx/webapp.py FLASK_ENV=development flask run"
flask_run_development = (
    os.environ.get("FLASK_APP") is not None and os.environ.get("FLASK_ENV") == 'development' and is_flask_run_cmdline()
)

# True if reload feature is activated of werkzeug, False otherwise (including uwsgi, etc..)
#  __name__ != "__main__" if searx.webapp is imported (make test, make docs, uwsgi...)
# see run() at the end of this file : searx_debug activates the reload feature.
werkzeug_reloader = flask_run_development or (searx_debug and __name__ == "__main__")

# initialize the engines except on the first run of the werkzeug server.
if not werkzeug_reloader or (werkzeug_reloader and os.environ.get("WERKZEUG_RUN_MAIN") == "true"):
    locales_initialize()
    _INFO_PAGES = infopage.InfoPageSet()
    redis_initialize()
    plugin_initialize(app)
    search_initialize(enable_checker=True, check_network=True, enable_metrics=settings['general']['enable_metrics'])


def run():
    logger.debug('starting webserver on %s:%s', settings['server']['bind_address'], settings['server']['port'])
    app.run(
        debug=searx_debug,
        use_debugger=searx_debug,
        port=settings['server']['port'],
        host=settings['server']['bind_address'],
        threaded=True,
        extra_files=[get_default_settings_path()],
    )


application = app
patch_application(app)

if __name__ == "__main__":
    run()
